package com.jiuqi.syntax;

import java.math.BigDecimal;
import java.text.DateFormat;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.util.HashMap;
import java.util.List;
import java.util.Stack;

/* loaded from: com_jiuqi_syntax.jar:com/jiuqi/syntax/SyntaxParser.class */
public final class SyntaxParser {
    public static final int OP_PLUS = 1;
    public static final int OP_MINUS = 2;
    public static final int OP_SMINUS = 3;
    public static final int OP_PRODUCT = 4;
    public static final int OP_DIV = 5;
    public static final int OP_CPLUS = 6;
    public static final int OP_EQU = 7;
    public static final int OP_WEQU = 8;
    public static final int OP_NEQ = 9;
    public static final int OP_GLT = 10;
    public static final int OP_BLT = 11;
    public static final int OP_GLE = 12;
    public static final int OP_BLE = 13;
    public static final int OP_AND = 14;
    public static final int OP_OR = 15;
    public static final int OP_NOT = 16;
    public static final int OP_ASSIGN = 17;
    public static final int OP_IF = 18;
    public static final int OP_THEN = 19;
    public static final int OP_ELSE = 20;
    public static final String OP_PLUS_NAME = "+";
    public static final String OP_MINUS_NAME = "-";
    public static final String OP_SMINUS_NAME = "-";
    public static final String OP_PRODUCT_NAME = "*";
    public static final String OP_DIV_NAME = "/";
    public static final String OP_CPLUS_NAME = "&";
    public static final String OP_EQU_NAME = "=";
    public static final String OP_WEQU_NAME = "==";
    public static final String OP_NEQ_NAME = "<>";
    public static final String OP_GLT_NAME = ">";
    public static final String OP_BLT_NAME = "<";
    public static final String OP_GLE_NAME = ">=";
    public static final String OP_BLE_NAME = "<=";
    public static final String OP_AND_NAME = "AND";
    public static final String OP_OR_NAME = "OR";
    public static final String OP_NOT_NAME = "NOT";
    public static final String OP_ASSIGN_NAME = "=";
    public static final String OP_IF_NAME = "IF";
    public static final String OP_THEN_NAME = "THEN";
    public static final String OP_ELSE_NAME = "ELSE";
    public static final int SY_OK = 0;
    public static final int SY_UNKNOWN = 1;
    public static final int SY_LACK_LEFT_SMALL_BRACKET = 2;
    public static final int SY_LACK_RIGHT_SMALL_BRACKET = 3;
    public static final int SY_LACK_LEFT_MIDDLE_BRACKET = 4;
    public static final int SY_LACK_RIGHT_MIDDLE_BRACKET = 5;
    public static final int SY_LACK_LEFT_BIG_BRACKET = 6;
    public static final int SY_LACK_RIGHT_BIG_BRACKET = 7;
    public static final int SY_LACK_SIGN = 8;
    public static final int SY_LACK_CHAR = 9;
    public static final int SY_LACK_DIGIT = 10;
    public static final int SY_LACK_LETTER = 11;
    public static final int SY_LACK_QUOTE = 12;
    public static final int SY_LACK_EQUAL = 13;
    public static final int SY_LACK_COMMA = 14;
    public static final int SY_LACK_INT = 15;
    public static final int SY_LACK_REAL = 16;
    public static final int SY_LACK_STRING = 17;
    public static final int SY_LACK_DATE = 18;
    public static final int SY_LACK_BOOL = 19;
    public static final int SY_LACK_AND = 20;
    public static final int SY_LACK_OR = 21;
    public static final int SY_LACK_NOT = 22;
    public static final int SY_LACK_THEN = 23;
    public static final int SY_LACK_ELSE = 24;
    public static final int SY_BRACKET_OVERLOAD = 51;
    public static final int SY_BRACKET_NO_MATCH = 52;
    public static final int SY_QUOTE_BAD_USE = 53;
    public static final int SY_BIG_BRACKET_BAD_USE = 54;
    public static final int SY_INTERVAL_OUTOF_ORDER = 55;
    public static final int SY_INTERVAL_SET_AT_END = 56;
    public static final int SY_NEED_OF_INTERVALSET = 57;
    public static final int SY_EXIST_SPARE_CHAR = 101;
    public static final int SY_INVALID_CHAR = 102;
    public static final int SY_NEED_IF_EXP = 103;
    public static final int SY_NEED_THEN_EXP = 104;
    public static final int SY_NEED_ELSE_EXP = 105;
    public static final int SY_OVELLAP_OPERATOR = 151;
    public static final int SY_TYPE_NO_MATCH = 152;
    public static final int SY_CPLUS_BAD_USE = 153;
    public static final int SY_CPLUS_OUTOF_ORDER = 154;
    public static final int SY_INT_OVER_BORDER = 155;
    public static final int SY_BAD_CELL_EXP = 156;
    public static final int SY_BAD_SIGN = 157;
    public static final int SY_OVERLAP_CONDITION = 158;
    public static final int SY_BAD_CONDITION = 159;
    public static final int SY_OVERLAP_KIND = 160;
    public static final int SY_NO_SUPPORT_STAR = 161;
    public static final int SY_OVERLAP_STAT = 162;
    public static final int SY_OVERLAP_DIMEN = 163;
    public static final int SY_FUNC_NO_EXIST = 201;
    public static final int SY_FUNC_BAD_PARAM = 202;
    public static final int SY_INTERNAL_ERROR = 1001;
    public static final int SY_UNEXPECTED_ERROR = 1002;
    public static final int SY_UNSUPPORT_ERROR = 1003;
    public static final int SY_PARAMS_ERROR = 1004;
    public static final int SY_FORMULA_ERROR = 1005;
    public static final int SY_TASK_NOT_EXIST = 1011;
    public static final int SY_ZB_NOT_EXIST = 1012;
    public static final int SY_TABLE_NOT_EXIST = 1013;
    public static final int SY_CELL_NOT_EXIST = 1014;
    public static final int SY_DICT_NOT_EXIST = 1015;
    public static final int SY_MEAN_NOT_EXIST = 1016;
    public static final int SY_TERM_NEEDED = 1021;
    public static final int SY_TERM_NOT_SUPPORT = 1022;
    public static final int SY_TERM_OVER_BORDER = 1023;
    public static final int SY_ZB_CAN_NOT_READ = 1031;
    public static final int SY_ZB_CAN_NOT_WRITE = 1032;
    public static final int SY_KEY_ZB_READONLY = 1035;
    public static final int SY_MIXED_ZB_READONLY = 1036;
    public static final int SY_OTHRE_TASK_READONLY = 1037;
    public static final int SY_OTHER_TERM_READONLY = 1038;
    public static final int SY_EXPR_ZBMAP_READONLY = 1039;
    public static final int SY_CONDITION_NOT_SUPPORT = 1041;
    public static final int SY_STATISTIC_NOT_SUPPORT = 1042;
    public static final int SY_CONDITION_CONFLICT = 1043;
    public static final int SY_STATISTIC_TYPE_ERROR = 1044;
    public static final int SY_LJ_NOT_SUPPORT = 1045;
    public static final int SY_INVALID_DEST_CELL = 1046;
    public static final int SY_DIMENSION_NOT_EXIST = 1051;
    public static final int SY_DIMENSION_VALUE_ERROR = 1052;
    public static final int SY_DIMENSION_VALUE_MISS = 1053;
    public static final int SY_DIMENSION_STAT_CONFLICT = 1054;
    public static final int SY_DIMENSION_VALUE_RECUR = 1055;
    public static final int SY_TASK_NOT_INSCOPE = 1061;
    public static final int SY_ZB_NOT_INSCOPE = 1062;
    public static final int SY_TABLE_NOT_INSCOPE = 1063;
    public static final int SY_CELL_NOT_INSCOPE = 1064;
    public static final int SY_DICT_NOT_INSCOPE = 1065;
    public static final int SY_TERM_NOT_INSCOPE = 1066;
    public static final int SY_EXTERNAL_EXCEPTION = 9999;
    public static final int SY_CUSTOM_FIRST = 10000;
    public static final double MIN_VALUE = 1.0E-5d;
    public static final int MAX_SIGN_LENGTH = 50;
    public static final int SYNTAX_JUDGE = 0;
    public static final int SYNTAX_EVALUATE = 1;
    public static final int SYNTAX_ATTRACT = 2;
    public static final int FLOATCOPYTYPE_ENUM = 0;
    public static final int FLOATCOPYTYPE_SUM = 1;
    public static final int FLOATCOPYTYPE_UPDATE = 2;
    public static final int FLOATCOPYTYPE_MAX_VALUE = 100;
    public static final String[] COMPARE_OPS;
    public static final String[] COMPARE_CONJ;
    private NiporlanParser niporlanParser;
    public static String exceptionMessage;
    private int thenPos;
    private int elsePos;
    private boolean canAssignValue;
    private boolean ifThenTrue;
    private boolean judgeResult;
    private static final int NI_IF_ITEM = 0;
    private static final int NI_THEN_ITEM = 1;
    private static final int NI_ELSE_ITEM = 2;
    public static HashMap RESERVED_SIGNS;
    public static String OP_PLUS_CHINA_NAME = "加";
    public static String OP_MINUS_CHINA_NAME = "减";
    public static String OP_SMINUS_CHINA_NAME = "单目减";
    public static String OP_PRODUCT_CHINA_NAME = "乘";
    public static String OP_DIV_CHINA_NAME = "除";
    public static String OP_CPLUS_CHINA_NAME = "连加";
    public static String OP_EQU_CHINA_NAME = "等于";
    public static String OP_WEQU_CHINA_NAME = "模糊等";
    public static String OP_NEQ_CHINA_NAME = "不等于";
    public static String OP_GLT_CHINA_NAME = "大于";
    public static String OP_BLT_CHINA_NAME = "小于";
    public static String OP_GLE_CHINA_NAME = "大于等于";
    public static String OP_BLE_CHINA_NAME = "小于等于";
    public static String OP_AND_CHINA_NAME = "并且";
    public static String OP_OR_CHINA_NAME = "或者";
    public static String OP_NOT_CHINA_NAME = "否";
    public static String OP_ASSIGN_CHINA_NAME = "等于";
    public static String OP_IF_CHINA_NAME = "如果";
    public static String OP_THEN_CHINA_NAME = "那么";
    public static String OP_ELSE_CHINA_NAME = "否则";
    private static final FunctionListeners globalFunctionListeners = new FunctionListeners();
    private static final CommonFunctionListener commonFunctionListener = new CommonFunctionListener();
    NiporlanItemFactory niFactory = null;
    private OptimizeListener optListener = null;
    public boolean hasStarSyntax = true;
    public boolean hasCellSyntax = true;
    public boolean hasMakeNiporlan = true;
    public boolean hasExpDescription = true;
    public boolean hasExpVision = true;
    public boolean hasExpVisionBanlance = true;
    public boolean isCheckMode = false;
    public boolean isIgnoreControl = false;
    private SyntaxListener syntaxListener = null;
    private FunctionListeners localFunctionListeners = new FunctionListeners();
    private int estimateType = 0;
    private boolean inParseCell = false;
    private boolean inEffectCheck = false;
    private int expi = 0;
    private String expStr = "";
    private String wholeExpStr = "";
    private char ch = 0;
    private int ret = 0;
    private SyntaxData estimateData = new SyntaxData();
    private Niporlan niporlan = null;
    private String expDescription = "";
    private String defineExpDescription = "";
    private String expVision = "";
    private String defineExpVision = "";
    private int[] hNumArray = new int[2000];
    private int[] lNumArray = new int[2000];
    private SyntaxData tempSyData = new SyntaxData();
    private StringBuffer tmpStrBuffer = new StringBuffer();
    private String tmpStr = "";
    private String tmpStr2 = "";
    private double tempReal = 0.0d;
    private int tmpInt = 0;
    private boolean tmpBool = false;
    private double decPos = 0.0d;
    private String ifExpStr = "";
    private String thenExpStr = "";
    private String elseExpStr = "";
    private CommonData attractResult = new CommonData();
    private int niporlanItemType = 1;
    private Stack unUsedSyntaxDatas = new Stack();
    private double balanceDifferenceValue = 1.0E-5d;

    static {
        globalFunctionListeners.add((FunctionListener) commonFunctionListener);
        COMPARE_OPS = new String[]{OP_NEQ_NAME, OP_GLE_NAME, OP_BLE_NAME, "=", OP_GLT_NAME, OP_BLT_NAME};
        COMPARE_CONJ = new String[]{OP_AND_NAME, OP_OR_NAME};
        exceptionMessage = null;
        RESERVED_SIGNS = new HashMap();
        RESERVED_SIGNS.put("T", null);
        RESERVED_SIGNS.put("TRUE", null);
        RESERVED_SIGNS.put("F", null);
        RESERVED_SIGNS.put("FALSE", null);
        RESERVED_SIGNS.put(OP_NOT_NAME, null);
        RESERVED_SIGNS.put("ABS", null);
        RESERVED_SIGNS.put("INT", null);
        RESERVED_SIGNS.put("ROUND", null);
        RESERVED_SIGNS.put("MOD", null);
        RESERVED_SIGNS.put("POWER", null);
        RESERVED_SIGNS.put("TAN", null);
        RESERVED_SIGNS.put("ATAN", null);
        RESERVED_SIGNS.put("LN", null);
        RESERVED_SIGNS.put("LOG10", null);
        RESERVED_SIGNS.put("LOG", null);
        RESERVED_SIGNS.put("VAL", null);
        RESERVED_SIGNS.put("STR", null);
        RESERVED_SIGNS.put("L$", null);
        RESERVED_SIGNS.put("M$", null);
        RESERVED_SIGNS.put("R$", null);
        RESERVED_SIGNS.put("POS", null);
        RESERVED_SIGNS.put("IDC", null);
        RESERVED_SIGNS.put("ISDIGIT", null);
        RESERVED_SIGNS.put("LEN", null);
        RESERVED_SIGNS.put("ISNULL", null);
        RESERVED_SIGNS.put("EXISTCHINESE", null);
        RESERVED_SIGNS.put("INLIST", null);
        RESERVED_SIGNS.put("DICTVALUE", null);
        RESERVED_SIGNS.put("DV", null);
        RESERVED_SIGNS.put("GETMEANING", null);
        RESERVED_SIGNS.put("STATE", null);
        RESERVED_SIGNS.put("FLOATSTAT", null);
        RESERVED_SIGNS.put("FLOATCOPY", null);
        RESERVED_SIGNS.put("DATEVALUE", null);
        RESERVED_SIGNS.put("FORMATDATE", null);
        RESERVED_SIGNS.put("DATE", null);
        RESERVED_SIGNS.put("YEAR", null);
        RESERVED_SIGNS.put("MONTH", null);
        RESERVED_SIGNS.put("DAY", null);
        RESERVED_SIGNS.put("TODAY", null);
        RESERVED_SIGNS.put("NULLBLOB", null);
        RESERVED_SIGNS.put("LINKPLUS", null);
        RESERVED_SIGNS.put("AUTOSUM", null);
        RESERVED_SIGNS.put("SUM", null);
        RESERVED_SIGNS.put("MAX", null);
        RESERVED_SIGNS.put("MIN", null);
        RESERVED_SIGNS.put("AVG", null);
        RESERVED_SIGNS.put("COUNT", null);
        RESERVED_SIGNS.put("FIRST", null);
        RESERVED_SIGNS.put("LAST", null);
    }

    public SyntaxParser() {
        this.niporlanParser = null;
        this.niporlanParser = new NiporlanParser(this);
    }

    public void setNIFactory(NiporlanItemFactory niFactory) {
        this.niFactory = niFactory;
    }

    public NiporlanItemFactory getNIFactory() {
        return this.niFactory;
    }

    public OptimizeListener getOptimizeListener() {
        return this.optListener;
    }

    public void setOptimizeListener(OptimizeListener optListener) {
        this.optListener = optListener;
        if (optListener != null) {
            setNIFactory(NiporlanItemFactory.getFactory());
            this.niporlanParser.setUseDataLocator(true);
        }
    }

    public void setShareDataCell() {
        setNIFactory(NiporlanItemFactory.getFactory());
    }

    public SyntaxListener getSyntaxListener() {
        return this.syntaxListener;
    }

    public void setSyntaxListener(SyntaxListener syntaxListener) {
        this.syntaxListener = syntaxListener;
    }

    public static final FunctionListeners getGlobalFunctionListeners() {
        return globalFunctionListeners;
    }

    public FunctionListeners getLocalFunctionListeners() {
        return this.localFunctionListeners;
    }

    public FunctionListener getFunctionListener(String funcName) {
        for (int i = 0; i < this.localFunctionListeners.size(); i++) {
            if (this.localFunctionListeners.getListener(i).funcExists(funcName)) {
                return this.localFunctionListeners.getListener(i);
            }
        }
        for (int i2 = 0; i2 < globalFunctionListeners.size(); i2++) {
            if (globalFunctionListeners.getListener(i2).funcExists(funcName)) {
                return globalFunctionListeners.getListener(i2);
            }
        }
        return null;
    }

    public Function getFunctionByName(String funcName) {
        for (int i = 0; i < this.localFunctionListeners.size(); i++) {
            if (this.localFunctionListeners.getListener(i).funcExists(funcName)) {
                return this.localFunctionListeners.getListener(i).funcByName(funcName);
            }
        }
        for (int i2 = 0; i2 < globalFunctionListeners.size(); i2++) {
            if (globalFunctionListeners.getListener(i2).funcExists(funcName)) {
                return globalFunctionListeners.getListener(i2).funcByName(funcName);
            }
        }
        return null;
    }

    public String getListenerCodeMessage(int retCode) {
        for (int i = 0; i < this.localFunctionListeners.size(); i++) {
            if (!this.localFunctionListeners.getListener(i).getCodeMessage(retCode).equals("")) {
                return this.localFunctionListeners.getListener(i).getCodeMessage(retCode);
            }
        }
        for (int i2 = 0; i2 < globalFunctionListeners.size(); i2++) {
            if (globalFunctionListeners.getListener(i2).getCodeMessage(retCode).equals("")) {
                return globalFunctionListeners.getListener(i2).getCodeMessage(retCode);
            }
        }
        return "";
    }

    public String transNiporlanToJavaScript(Niporlan niporlan, boolean isCalculateFormula, TransJavaScriptListener transJavaScriptListener) {
        boolean isOK;
        StringBuffer jsBuffer = new StringBuffer();
        try {
            if (!niporlan.isEmpty()) {
                jsBuffer.setLength(0);
                if (niporlan.ifExist()) {
                    jsBuffer.append("if (");
                    isOK = transNiporlanItemsToJavaScript(niporlan.getIfItems(), false, transJavaScriptListener, jsBuffer);
                    if (isOK) {
                        jsBuffer.append(") ");
                        isOK = transNiporlanItemsToJavaScript(niporlan.getThenItems(), isCalculateFormula, transJavaScriptListener, jsBuffer);
                        if (isOK) {
                            jsBuffer.append(";");
                        }
                        if (isOK && niporlan.elseExist()) {
                            jsBuffer.append(" else ");
                            isOK = transNiporlanItemsToJavaScript(niporlan.getElseItems(), isCalculateFormula, transJavaScriptListener, jsBuffer);
                            if (isOK) {
                                jsBuffer.append(";");
                            }
                        }
                    }
                } else {
                    isOK = transNiporlanItemsToJavaScript(niporlan.getThenItems(), isCalculateFormula, transJavaScriptListener, jsBuffer);
                    if (isOK) {
                        jsBuffer.append(";");
                    }
                }
                if (!isOK) {
                    jsBuffer.append("//" + transJavaScriptListener.getErrorMessage());
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            jsBuffer.append("//转换公式成JavaScript出现错误：").append(e.getMessage());
        }
        return jsBuffer.toString();
    }

    private boolean transNiporlanItemsToJavaScript(ArrayList niporlanItems, boolean isCalculateFormula, TransJavaScriptListener transJavaScriptListener, StringBuffer jsBuffer) {
        Stack stack = new Stack();
        DataCell SaveSetDataCell = null;
        String rightItem = null;
        String leftItem = null;
        String param1 = "";
        String param2 = "";
        String param3 = "";
        String param4 = "";
        for (int i = 0; i < niporlanItems.size(); i++) {
            NiporlanItem item = (NiporlanItem) niporlanItems.get(i);
            switch (item.getType()) {
                case 0:
                    switch (item.getOp()) {
                        case 1:
                            rightItem = (String) stack.pop();
                            String leftItem2 = (String) stack.pop();
                            leftItem = "(" + leftItem2 + OP_PLUS_NAME + rightItem + ")";
                            break;
                        case 2:
                            rightItem = (String) stack.pop();
                            String leftItem3 = (String) stack.pop();
                            leftItem = "(" + leftItem3 + "-" + rightItem + ")";
                            break;
                        case 3:
                            String leftItem4 = (String) stack.pop();
                            leftItem = "-" + leftItem4;
                            break;
                        case 4:
                            rightItem = (String) stack.pop();
                            String leftItem5 = (String) stack.pop();
                            leftItem = "(" + leftItem5 + OP_PRODUCT_NAME + rightItem + ")";
                            break;
                        case 5:
                            rightItem = (String) stack.pop();
                            String leftItem6 = (String) stack.pop();
                            leftItem = "(" + leftItem6 + OP_DIV_NAME + rightItem + ")";
                            break;
                        case 6:
                        default:
                            return false;
                        case 7:
                            rightItem = (String) stack.pop();
                            String leftItem7 = (String) stack.pop();
                            leftItem = "(" + leftItem7 + OP_WEQU_NAME + rightItem + ")";
                            break;
                        case 8:
                            break;
                        case 9:
                            rightItem = (String) stack.pop();
                            String leftItem8 = (String) stack.pop();
                            leftItem = "(" + leftItem8 + "!=" + rightItem + ")";
                            break;
                        case 10:
                            rightItem = (String) stack.pop();
                            String leftItem9 = (String) stack.pop();
                            leftItem = "(" + leftItem9 + OP_GLT_NAME + rightItem + ")";
                            break;
                        case 11:
                            rightItem = (String) stack.pop();
                            String leftItem10 = (String) stack.pop();
                            leftItem = "(" + leftItem10 + OP_BLT_NAME + rightItem + ")";
                            break;
                        case 12:
                            rightItem = (String) stack.pop();
                            String leftItem11 = (String) stack.pop();
                            leftItem = "(" + leftItem11 + OP_GLE_NAME + rightItem + ")";
                            break;
                        case 13:
                            rightItem = (String) stack.pop();
                            String leftItem12 = (String) stack.pop();
                            leftItem = "(" + leftItem12 + OP_BLE_NAME + rightItem + ")";
                            break;
                        case 14:
                            rightItem = (String) stack.pop();
                            String leftItem13 = (String) stack.pop();
                            leftItem = "(" + leftItem13 + " && " + rightItem + ")";
                            break;
                        case 15:
                            rightItem = (String) stack.pop();
                            String leftItem14 = (String) stack.pop();
                            leftItem = "(" + leftItem14 + " || " + rightItem + ")";
                            break;
                        case 16:
                            leftItem = " !" + rightItem;
                            break;
                        case 17:
                            rightItem = (String) stack.pop();
                            if (rightItem.indexOf("\"") >= 0) {
                                StringBuffer strBuffer = new StringBuffer();
                                for (int j = 0; j < rightItem.length(); j++) {
                                    if (rightItem.charAt(j) == '\"') {
                                        strBuffer.append('\\').append('\"');
                                    } else {
                                        strBuffer.append(rightItem.charAt(j));
                                    }
                                }
                                rightItem = strBuffer.toString();
                            }
                            leftItem = transJavaScriptListener.getSetCellValueJS(SaveSetDataCell, rightItem);
                            break;
                    }
                case 1:
                    FunctionListener funcListener = getFunctionListener(item.getFuncName());
                    if (funcListener == null) {
                        System.out.println("没有找到函数“" + item.getFuncName() + "”的侦听器！");
                        return false;
                    }
                    Function func = funcListener.funcByName(item.getFuncName());
                    if (!func.isInfiniteParam) {
                        for (int j2 = 0; j2 < func.params.size(); j2++) {
                            String s = (String) stack.pop();
                            if ((func.params.size() - j2) - 1 == 0) {
                                param1 = s;
                            }
                            if ((func.params.size() - j2) - 1 == 1) {
                                param2 = s;
                            }
                            if ((func.params.size() - j2) - 1 == 2) {
                                param3 = s;
                            }
                            if ((func.params.size() - j2) - 1 == 3) {
                                param4 = s;
                            }
                        }
                        leftItem = transJavaScriptListener.getFunctionJS(item.getFuncName(), param1, param2, param3, param4);
                        break;
                    } else {
                        String leftItem15 = (String) stack.pop();
                        int paramCount = Integer.valueOf(leftItem15).intValue();
                        String[] params = new String[paramCount];
                        for (int j3 = 0; j3 < paramCount; j3++) {
                            params[(paramCount - j3) - 1] = (String) stack.pop();
                        }
                        leftItem = transJavaScriptListener.getFunctionJS(item.getFuncName(), params);
                        break;
                    }
                case 2:
                    leftItem = item.getCommonData().toString();
                    if (item.getCommonData().type == 3) {
                        leftItem = "\"" + leftItem + "\"";
                        break;
                    } else {
                        break;
                    }
                case 3:
                    if (isCalculateFormula && stack.size() == 0) {
                        SaveSetDataCell = item.getDataCell();
                        leftItem = "";
                        break;
                    } else {
                        leftItem = transJavaScriptListener.getGetCellValueJS(item.getDataCell());
                        break;
                    }
                    break;
                default:
                    return false;
            }
            stack.push(leftItem);
        }
        String js = (String) stack.pop();
        jsBuffer.append(js);
        return true;
    }

    public static final Functions getFunctions() {
        return commonFunctionListener.getFunctions();
    }

    public int judge(String expStr, CommonData resultData) {
        this.estimateType = 0;
        int syResult = estimate(expStr, this.estimateData);
        resultData.assign(this.estimateData);
        return syResult;
    }

    public int evaluate(String expStr) {
        this.estimateType = 1;
        int syResult = estimate(expStr, this.estimateData);
        return syResult;
    }

    public int attract(String expStr, CommonData resultData) {
        this.estimateType = 2;
        int syResult = estimate(expStr, this.estimateData);
        resultData.assign(this.estimateData);
        return syResult;
    }

    public boolean judge(Niporlan niporlan) {
        return this.niporlanParser.judge(niporlan);
    }

    public void evaluate(Niporlan niporlan) {
        this.niporlanParser.evaluate(niporlan);
    }

    public void attract(Niporlan niporlan, CommonData resultData) {
        this.niporlanParser.attract(niporlan, resultData);
    }

    public static int extendPos(String subStr, String mainStr) {
        boolean strStart = false;
        int findPos = -1;
        int i = 0;
        while (true) {
            if (i >= (mainStr.length() - subStr.length()) + 1) {
                break;
            }
            if (mainStr.charAt(i) == '\"') {
                strStart = !strStart;
            }
            if (!strStart) {
                boolean foundOk = true;
                int j = 0;
                while (true) {
                    if (j >= subStr.length()) {
                        break;
                    }
                    if (subStr.charAt(j) == mainStr.charAt(i + j)) {
                        j++;
                    } else {
                        foundOk = false;
                        break;
                    }
                }
                if (foundOk) {
                    findPos = i;
                    break;
                }
            }
            i++;
        }
        return findPos;
    }

    public static int extendPos2(String subStr, String mainStr) {
        boolean strStart = false;
        int findPos = -1;
        int i = 0;
        while (true) {
            if (i >= (mainStr.length() - subStr.length()) + 1) {
                break;
            }
            if (mainStr.charAt(i) == '\'') {
                strStart = !strStart;
            }
            if (!strStart) {
                boolean foundOk = true;
                int j = 0;
                while (true) {
                    if (j >= subStr.length()) {
                        break;
                    }
                    if (subStr.charAt(j) == mainStr.charAt(i + j)) {
                        j++;
                    } else {
                        foundOk = false;
                        break;
                    }
                }
                if (foundOk) {
                    findPos = i;
                    break;
                }
            }
            i++;
        }
        return findPos;
    }

    public static int syntaxPos(String subString, String searchString) {
        int subLength;
        if (subString == null || (subLength = subString.length()) <= 0 || searchString == null) {
            return -1;
        }
        String subString2 = subString.toUpperCase();
        String searchString2 = searchString.toUpperCase();
        boolean strStart = false;
        boolean rawStart = false;
        int searchStart = searchString2.length() - subLength;
        for (int i = 0; i <= searchStart; i++) {
            char ch = searchString2.charAt(i);
            if (!rawStart) {
                if (ch == '\"') {
                    strStart = !strStart;
                } else if (strStart) {
                    continue;
                }
            }
            if (ch == '\'') {
                rawStart = !rawStart;
            } else if (!rawStart && ch == subString2.charAt(0) && subString2.equals(searchString2.substring(i, i + subLength))) {
                return i;
            }
        }
        return -1;
    }

    public static int visionSyntaxPos(String subString, String searchString) {
        int subLength;
        if (subString == null || (subLength = subString.length()) <= 0 || searchString == null) {
            return -1;
        }
        String subString2 = subString.toUpperCase();
        String searchString2 = searchString.toUpperCase();
        boolean strStart = false;
        boolean rawStart = false;
        boolean bracketStart = false;
        int searchStart = searchString2.length() - subLength;
        for (int i = 0; i <= searchStart; i++) {
            char ch = searchString2.charAt(i);
            if (!rawStart) {
                if (ch == '\"') {
                    strStart = !strStart;
                } else if (strStart) {
                    continue;
                } else if (ch == '[') {
                    bracketStart = true;
                } else if (ch == ']') {
                    bracketStart = false;
                } else if (bracketStart) {
                    continue;
                }
            }
            if (ch == '\'') {
                rawStart = !rawStart;
            } else if (!rawStart && ch == subString2.charAt(0) && subString2.equals(searchString2.substring(i, i + subLength))) {
                return i;
            }
        }
        return -1;
    }

    public static void splitExp(String expStr, List list) {
        int pos1 = syntaxPos(COMPARE_CONJ[0], expStr);
        if (pos1 < 1) {
            int pos2 = syntaxPos(COMPARE_CONJ[1], expStr);
            if (pos2 < 1) {
                list.add(expStr.trim());
                return;
            } else {
                splitExp(expStr.substring(0, pos2), list);
                splitExp(expStr.substring(pos2 + COMPARE_CONJ[1].length(), expStr.length()), list);
                return;
            }
        }
        splitExp(expStr.substring(0, pos1), list);
        splitExp(expStr.substring(pos1 + COMPARE_CONJ[0].length(), expStr.length()), list);
    }

    public static String makeLeftExp(String expStr) {
        String result = "";
        int i = 0;
        while (true) {
            if (i >= COMPARE_OPS.length) {
                break;
            }
            int pos = visionSyntaxPos(COMPARE_OPS[i], expStr);
            if (pos <= 0) {
                i++;
            } else {
                result = expStr.substring(0, pos);
                break;
            }
        }
        return result;
    }

    public static String makeRightExp(String expStr) {
        String result = "";
        int i = 0;
        while (true) {
            if (i >= COMPARE_OPS.length) {
                break;
            }
            int pos = visionSyntaxPos(COMPARE_OPS[i], expStr);
            if (pos <= 0) {
                i++;
            } else {
                result = expStr.substring(pos + COMPARE_OPS[i].length());
                break;
            }
        }
        return result;
    }

    public static String makeBanlanceExp(String expStr) {
        String result = "";
        int i = 0;
        while (true) {
            if (i >= COMPARE_OPS.length) {
                break;
            }
            int pos = visionSyntaxPos(COMPARE_OPS[i], expStr);
            if (pos <= 0) {
                i++;
            } else {
                result = String.valueOf(expStr.substring(0, pos)) + "-(" + expStr.substring(pos + COMPARE_OPS[i].length()) + ")";
                break;
            }
        }
        return result;
    }

    /* JADX WARN: Removed duplicated region for block: B:150:0x069c  */
    /* JADX WARN: Removed duplicated region for block: B:153:0x06bf A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:158:0x075a  */
    /* JADX WARN: Removed duplicated region for block: B:164:0x0765 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:385:0x00b7  */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    public static java.lang.String transExpCellInfo(java.lang.String r5, int r6, int r7, int r8, int r9) {
        /*
            Method dump skipped, instructions count: 2113
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.syntax.SyntaxParser.transExpCellInfo(java.lang.String, int, int, int, int):java.lang.String");
    }

    public static boolean isDigitChar(char c) {
        return c >= '0' && c <= '9';
    }

    public static boolean isLetterChar(char c) {
        if (c < 'A' || c > 'Z') {
            return c >= 'a' && c < 'z';
        }
        return true;
    }

    public static boolean isSignChar(char c) {
        return isLetterChar(c) || isDigitChar(c) || c == '_' || isChinaChar(c);
    }

    public static boolean isFirstSignChar(char c) {
        return isLetterChar(c) || c == '_' || isChinaChar(c);
    }

    public static boolean isChinaChar(char c) {
        return c > 255;
    }

    public static boolean isCompareChar(char c) {
        return c == '=' || c == '>' || c == '<';
    }

    public static boolean isDigit(String s) {
        if (s.length() > 0) {
            for (int i = 0; i < s.length(); i++) {
                if (!isDigitChar(s.charAt(i))) {
                    return false;
                }
            }
            return true;
        }
        return true;
    }

    public static boolean isSign(String s) {
        if (s.length() > 0) {
            for (int i = 0; i < s.length(); i++) {
                if (!isSignChar(s.charAt(i))) {
                    return false;
                }
            }
            return s.charAt(0) < '0' || s.charAt(0) > '9';
        }
        return false;
    }

    public static int signPos(String signStr, String mainStr) {
        int findPos = -1;
        String signStr2 = signStr.toUpperCase();
        String mainStr2 = mainStr.toUpperCase();
        if (!isSign(signStr2)) {
            return -1;
        }
        boolean strStart = false;
        int i = 0;
        while (true) {
            if (i >= (mainStr2.length() - signStr2.length()) + 1) {
                break;
            }
            if (mainStr2.charAt(i) == '\"') {
                strStart = !strStart;
                i++;
            } else if (strStart) {
                i++;
            } else if (mainStr2.charAt(i) < 'A' || mainStr2.charAt(i) > 'Z') {
                i++;
            } else {
                int starti = i;
                while (i < mainStr2.length() && isSignChar(mainStr2.charAt(i))) {
                    i++;
                }
                if (signStr2.equals(mainStr2.substring(starti, i))) {
                    findPos = starti;
                    break;
                }
            }
        }
        return findPos;
    }

    public static int asciiLength(String s) {
        int len = 0;
        for (int i = 0; i < s.length(); i++) {
            len = isChinaChar(s.charAt(i)) ? len + 2 : len + 1;
        }
        return len;
    }

    public static int asciiPos(String subStr, String mainStr) {
        int pos = mainStr.indexOf(subStr) + 1;
        if (pos > 0) {
            int len = 0;
            for (int i = 0; i < pos - 1; i++) {
                len = isChinaChar(mainStr.charAt(i)) ? len + 2 : len + 1;
            }
            pos = len + 1;
        }
        return pos;
    }

    public static String asciiCopy(String s, int index, int count) {
        byte[] bytes = s.getBytes();
        if (index <= 0 || index > bytes.length) {
            return "";
        }
        if ((index + count) - 1 > bytes.length) {
            count = (bytes.length - index) + 1;
        }
        byte[] copyBytes = new byte[count];
        for (int i = 0; i < count; i++) {
            copyBytes[i] = bytes[(i + index) - 1];
        }
        return new String(copyBytes);
    }

    public static boolean existChinese(String s) {
        for (int i = 0; i < s.length(); i++) {
            if (isChinaChar(s.charAt(i))) {
                return true;
            }
        }
        return false;
    }

    public static long trunc(double value) {
        return (long) value;
    }

    public static double roundFloat(double value, int decPos) {
        double value2;
        long decValue = (long) Math.pow(10.0d, decPos);
        if (Math.abs((value * decValue) - trunc(value * decValue)) - 0.5d <= -1.0E-5d) {
            value2 = trunc(value * decValue) / decValue;
        } else if (value < 0.0d) {
            value2 = (trunc(value * decValue) - 1.0d) / decValue;
        } else {
            value2 = (trunc(value * decValue) + 1.0d) / decValue;
        }
        return value2;
    }

    public static double floatMod(double base, double divisor) {
        if (divisor == 0.0d) {
            return 0.0d;
        }
        return base - (trunc((base / divisor) + 1.0E-5d) * divisor);
    }

    public static double safeStrToFloat(String s) {
        try {
            return Double.parseDouble(s);
        } catch (Exception unused) {
            return 0.0d;
        }
    }

    public static String FloatToStr(double value, int decPos, boolean thousand) {
        if (decPos == 0) {
            return thousand ? new DecimalFormat("#,##0.######").format(value) : new DecimalFormat("0.######").format(value);
        }
        StringBuffer formatStr = new StringBuffer();
        if (thousand) {
            formatStr.append("#,##0.");
        } else {
            formatStr.append("0.");
        }
        for (int i = 0; i < decPos; i++) {
            formatStr.append('0');
        }
        return new DecimalFormat(formatStr.toString()).format(value);
    }

    public static String datetimeToStr(Calendar date) {
        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return df.format(date.getTime());
    }

    private static int idcGetCharNum(char c) {
        if (c >= '0' && c <= '9') {
            return c - '0';
        }
        if (c == '#') {
            return 36;
        }
        return Character.toUpperCase(c) - '7';
    }

    public static char idc(String s) {
        if (s.length() != 8) {
            return (char) 0;
        }
        for (int v = 0; v < s.length(); v++) {
            if (!isDigitChar(s.charAt(v)) && !isLetterChar(s.charAt(v)) && s.charAt(v) != '#') {
                return (char) 0;
            }
        }
        int v2 = 11 - (((((((((idcGetCharNum(s.charAt(0)) * 3) + (idcGetCharNum(s.charAt(1)) * 7)) + (idcGetCharNum(s.charAt(2)) * 9)) + (idcGetCharNum(s.charAt(3)) * 10)) + (idcGetCharNum(s.charAt(4)) * 5)) + (idcGetCharNum(s.charAt(5)) * 8)) + (idcGetCharNum(s.charAt(6)) * 4)) + (idcGetCharNum(s.charAt(7)) * 2)) % 11);
        switch (v2) {
            case 10:
                return 'X';
            case 11:
                return '0';
            default:
                return (char) (v2 + 48);
        }
    }

    public static boolean safeStrToDate(Calendar calendar, String s, String format) {
        if (format != null) {
            try {
                if (!format.equals("")) {
                    SimpleDateFormat df = new SimpleDateFormat(format);
                    df.setLenient(true);
                    df.toPattern();
                    calendar.getTime().setTime(0L);
                    calendar.setTime(df.parse(s));
                    return true;
                }
            } catch (Exception unused) {
                calendar.getTime().setTime(0L);
                calendar.set(1, 1899);
                calendar.set(2, 1);
                calendar.set(5, 1);
                return false;
            }
        }
        DateFormat df2 = DateFormat.getDateInstance();
        df2.setLenient(true);
        calendar.getTime().setTime(0L);
        calendar.setTime(df2.parse(s));
        return true;
    }

    public static String formatDate(Calendar calendar, String format) {
        try {
            if (format.equals("")) {
                format = "yyyy-MM-dd";
            }
            SimpleDateFormat df = new SimpleDateFormat(format);
            return df.format(calendar.getTime());
        } catch (Exception unused) {
            return "";
        }
    }

    public static void safeEncodeDate(Calendar calendar, int year, int month, int day) {
        calendar.getTime().setTime(0L);
        calendar.set(year, month - 1, day);
    }

    public static int minusDate(Calendar date1, Calendar date2) {
        if (date1 == null || date2 == null) {
            return 0;
        }
        int totalDays1 = 0;
        int totalDays2 = 0;
        int year1 = date1.get(1);
        int year2 = date2.get(1);
        int startYear = Math.min(year1, year2);
        for (int i = startYear; i <= year1 - 1; i++) {
            Calendar calendar = new GregorianCalendar();
            calendar.set(i, 0, 1);
            totalDays1 += calendar.getActualMaximum(6);
        }
        for (int i2 = startYear; i2 <= year2 - 1; i2++) {
            Calendar calendar2 = new GregorianCalendar();
            calendar2.set(i2, 0, 1);
            totalDays2 += calendar2.getMaximum(6);
        }
        return (totalDays1 + date1.get(6)) - (totalDays2 + date2.get(6));
    }

    public int getRetCode() {
        return this.ret;
    }

    public String getErrorMessage() {
        return getErrorMessage(getRetCode());
    }

    public String getExpDescription() {
        if (this.defineExpDescription != null && !this.defineExpDescription.equals("")) {
            return this.defineExpDescription;
        }
        return this.expDescription;
    }

    public String getDefineExpDescription() {
        return this.defineExpDescription;
    }

    public void setDefineExpDescription(String s) {
        this.defineExpDescription = s;
    }

    public String getExpVision() {
        return this.expVision;
    }

    public String getDefineExpVision() {
        return this.defineExpVision;
    }

    public void setDefineExpVision(String s) {
        this.defineExpVision = s;
    }

    public Niporlan getNiporlan() {
        return this.niporlan;
    }

    public String getExpStr() {
        return this.wholeExpStr;
    }

    public String getExpStrIfPart() {
        return this.ifExpStr;
    }

    public String getExpStrThenPart() {
        return this.thenExpStr.equals("") ? this.wholeExpStr : this.thenExpStr;
    }

    public String getExpStrElsePart() {
        return this.elseExpStr;
    }

    public String getErrorMessage(int retCode) {
        StringBuffer message = new StringBuffer();
        message.append(getCodeMessage(retCode)).append("\n").append(this.expStr).append("\n");
        for (int i = 1; i < this.expi; i++) {
            message.append(' ');
        }
        message.append('!');
        return message.toString();
    }

    public double getBalanceDifferenceValue() {
        return this.balanceDifferenceValue;
    }

    public void setBalanceDifferenceValue(double value) {
        this.balanceDifferenceValue = value + 1.0E-5d;
    }

    public String getCodeMessage(int retCode) {
        switch (retCode) {
            case 0:
                return "公式语法正确";
            case 1:
                return "未知语法或语法不支持";
            case 2:
                return "缺少左小括号“(”";
            case 3:
                return "缺少右小括号“)”";
            case 4:
                return "缺少左中括号“[”";
            case 5:
                return "缺少右中括号“]”";
            case 6:
                return "缺少左大括号“{”";
            case 7:
                return "缺少右大括号“}”";
            case 8:
                return "缺少标识符";
            case 9:
                return "缺少字符";
            case 10:
                return "缺少数字";
            case 11:
                return "缺少字母";
            case 12:
                return "缺少双引号“\"”";
            case 13:
                return "缺少等于号“=”";
            case 14:
                return "缺少逗号“,”";
            case 15:
                return "缺少整数";
            case 16:
                return "缺少数值";
            case 17:
                return "缺少字符串";
            case 18:
                return "缺少日期型";
            case 19:
                return "缺少布尔值";
            case 20:
                return "缺少 AND 操作符";
            case SY_LACK_OR /* 21 */:
                return "缺少 OR 操作符";
            case SY_LACK_NOT /* 22 */:
                return "缺少 NOT 操作符";
            case SY_LACK_THEN /* 23 */:
                return "缺少 THEN 操作符";
            case SY_LACK_ELSE /* 24 */:
                return "缺少 ELSE 操作符";
            case SY_BRACKET_OVERLOAD /* 51 */:
                return "括号太多";
            case SY_BRACKET_NO_MATCH /* 52 */:
                return "括号不匹配";
            case SY_QUOTE_BAD_USE /* 53 */:
                return "双引号使用错误";
            case SY_BIG_BRACKET_BAD_USE /* 54 */:
                return "大括号使用错误";
            case SY_INTERVAL_OUTOF_ORDER /* 55 */:
                return "错误的行栏区间设定, 终点小于起点";
            case SY_INTERVAL_SET_AT_END /* 56 */:
                return "行栏区间设置必须在末尾";
            case SY_NEED_OF_INTERVALSET /* 57 */:
                return "需要单元区间设置";
            case SY_EXIST_SPARE_CHAR /* 101 */:
                return "存在多余的字符";
            case SY_INVALID_CHAR /* 102 */:
                return "不合法的字符";
            case SY_NEED_IF_EXP /* 103 */:
                return "需要 IF 表达式";
            case SY_NEED_THEN_EXP /* 104 */:
                return "需要 THEN 表达式";
            case SY_NEED_ELSE_EXP /* 105 */:
                return "需要 ELSE 表达式";
            case SY_OVELLAP_OPERATOR /* 151 */:
                return "操作符重叠";
            case SY_TYPE_NO_MATCH /* 152 */:
                return "数据类型不匹配";
            case SY_CPLUS_BAD_USE /* 153 */:
                return "连加符“&”使用错误";
            case SY_CPLUS_OUTOF_ORDER /* 154 */:
                return "连加符&终点小于起点";
            case SY_INT_OVER_BORDER /* 155 */:
                return "整数值越界";
            case SY_BAD_CELL_EXP /* 156 */:
                return "错误的单元表达式";
            case SY_BAD_SIGN /* 157 */:
                return "错误的标识符";
            case SY_OVERLAP_CONDITION /* 158 */:
                return "条件设置重复";
            case SY_BAD_CONDITION /* 159 */:
                return "条件设置错误";
            case SY_OVERLAP_KIND /* 160 */:
                return "时期设置重复";
            case SY_NO_SUPPORT_STAR /* 161 */:
                return "不支持单元格通配符“*”";
            case SY_OVERLAP_STAT /* 162 */:
                return "统计模式设置重复";
            case SY_OVERLAP_DIMEN /* 163 */:
                return "维度设置重复";
            case SY_FUNC_NO_EXIST /* 201 */:
                return "函数不存在";
            case SY_FUNC_BAD_PARAM /* 202 */:
                return "错误的函数参数";
            case SY_INTERNAL_ERROR /* 1001 */:
                return "内部错误";
            case SY_UNEXPECTED_ERROR /* 1002 */:
                return "未预料错误";
            case SY_UNSUPPORT_ERROR /* 1003 */:
                return "功能不被支持";
            case SY_PARAMS_ERROR /* 1004 */:
                return "任务参数错误";
            case SY_FORMULA_ERROR /* 1005 */:
                return "未知公式错误";
            case SY_TASK_NOT_EXIST /* 1011 */:
                return "任务不存在";
            case SY_ZB_NOT_EXIST /* 1012 */:
                return "指标不存在";
            case SY_TABLE_NOT_EXIST /* 1013 */:
                return "报表不存在";
            case SY_CELL_NOT_EXIST /* 1014 */:
                return "单元格不存在";
            case SY_DICT_NOT_EXIST /* 1015 */:
                return "枚举字典不存在";
            case SY_MEAN_NOT_EXIST /* 1016 */:
                return "枚举字典含义列不存在";
            case SY_TERM_NEEDED /* 1021 */:
                return "需要明确指定时期";
            case SY_TERM_NOT_SUPPORT /* 1022 */:
                return "不支持跨时期";
            case SY_TERM_OVER_BORDER /* 1023 */:
                return "时期越界";
            case SY_ZB_CAN_NOT_READ /* 1031 */:
                return "不能读取指标";
            case SY_ZB_CAN_NOT_WRITE /* 1032 */:
                return "不能修改指标";
            case SY_KEY_ZB_READONLY /* 1035 */:
                return "不能修改关键指标";
            case SY_MIXED_ZB_READONLY /* 1036 */:
                return "不能修改计算指标、统计指标";
            case SY_OTHRE_TASK_READONLY /* 1037 */:
                return "不能修改其他任务数据";
            case SY_OTHER_TERM_READONLY /* 1038 */:
                return "不能修改其他时期数据";
            case SY_EXPR_ZBMAP_READONLY /* 1039 */:
                return "不能修改表达式类型映射关系";
            case SY_CONDITION_NOT_SUPPORT /* 1041 */:
                return "不能设置条件";
            case SY_STATISTIC_NOT_SUPPORT /* 1042 */:
                return "不能设置统计方式";
            case SY_CONDITION_CONFLICT /* 1043 */:
                return "统计条件不在所属关系内";
            case SY_STATISTIC_TYPE_ERROR /* 1044 */:
                return "指定统计方式与指标数据类型不匹配";
            case SY_LJ_NOT_SUPPORT /* 1045 */:
                return "不支持指标累计值";
            case SY_INVALID_DEST_CELL /* 1046 */:
                return "无效的目标单元";
            case SY_DIMENSION_NOT_EXIST /* 1051 */:
                return "维度不存在";
            case SY_DIMENSION_VALUE_ERROR /* 1052 */:
                return "维度值设置错误";
            case SY_DIMENSION_VALUE_MISS /* 1053 */:
                return "维度值设置不全面";
            case SY_DIMENSION_STAT_CONFLICT /* 1054 */:
                return "维度值设置和统计条件冲突";
            case SY_DIMENSION_VALUE_RECUR /* 1055 */:
                return "维度值设置重复出现";
            case SY_TASK_NOT_INSCOPE /* 1061 */:
                return "任务与公式作用域冲突，不可访问";
            case SY_ZB_NOT_INSCOPE /* 1062 */:
                return "指标与公式作用域冲突，不可访问";
            case SY_TABLE_NOT_INSCOPE /* 1063 */:
                return "报表与公式作用域冲突，不可访问";
            case SY_CELL_NOT_INSCOPE /* 1064 */:
                return "单元格与公式作用域冲突，不可访问";
            case SY_DICT_NOT_INSCOPE /* 1065 */:
                return "枚举字典与公式作用域冲突，不可访问";
            case SY_TERM_NOT_INSCOPE /* 1066 */:
                return "浮动指标、维度不全指标不允许跨时期取数";
            case 9999:
                return exceptionMessage == null ? "外部异常错误" : exceptionMessage;
            default:
                String codeMessage = getListenerCodeMessage(retCode);
                return !codeMessage.equals("") ? codeMessage : "未定义的错误";
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:101:0x021d, code lost:
    
        if (r6.ch != '{') goto L148;
     */
    /* JADX WARN: Code restructure failed: missing block: B:102:0x0220, code lost:
    
        getChar();
        skipSpaces();
     */
    /* JADX WARN: Code restructure failed: missing block: B:103:0x022e, code lost:
    
        if (r6.ch != '}') goto L96;
     */
    /* JADX WARN: Code restructure failed: missing block: B:104:0x0231, code lost:
    
        r14 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:105:0x0343, code lost:
    
        r0 = r6.expi;
        getChar();
     */
    /* JADX WARN: Code restructure failed: missing block: B:106:0x0353, code lost:
    
        if (r6.ch != ' ') goto L142;
     */
    /* JADX WARN: Code restructure failed: missing block: B:107:0x0356, code lost:
    
        skipSpaces();
     */
    /* JADX WARN: Code restructure failed: missing block: B:109:0x0360, code lost:
    
        if (r6.ch == '{') goto L148;
     */
    /* JADX WARN: Code restructure failed: missing block: B:111:0x0367, code lost:
    
        if (r6.ch == 0) goto L148;
     */
    /* JADX WARN: Code restructure failed: missing block: B:112:0x036a, code lost:
    
        r6.expi = r0;
        r6.ret = 56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:113:0x037a, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:114:0x0237, code lost:
    
        r16 = r6.expi;
        wholeExp(r8);
     */
    /* JADX WARN: Code restructure failed: missing block: B:115:0x0246, code lost:
    
        if (r6.ret != 0) goto L326;
     */
    /* JADX WARN: Code restructure failed: missing block: B:117:0x024e, code lost:
    
        if (r8.type == 1) goto L102;
     */
    /* JADX WARN: Code restructure failed: missing block: B:118:0x0262, code lost:
    
        r0 = r8.cdInt;
     */
    /* JADX WARN: Code restructure failed: missing block: B:119:0x026e, code lost:
    
        if (r6.ch != '~') goto L119;
     */
    /* JADX WARN: Code restructure failed: missing block: B:120:0x0271, code lost:
    
        getChar();
        r16 = r6.expi;
        wholeExp(r8);
     */
    /* JADX WARN: Code restructure failed: missing block: B:121:0x0284, code lost:
    
        if (r6.ret != 0) goto L325;
     */
    /* JADX WARN: Code restructure failed: missing block: B:123:0x028c, code lost:
    
        if (r8.type == 1) goto L110;
     */
    /* JADX WARN: Code restructure failed: missing block: B:124:0x02a0, code lost:
    
        r0 = r8.cdInt;
     */
    /* JADX WARN: Code restructure failed: missing block: B:125:0x02aa, code lost:
    
        if (r0 >= r0) goto L114;
     */
    /* JADX WARN: Code restructure failed: missing block: B:126:0x02be, code lost:
    
        r19 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:128:0x02d8, code lost:
    
        if (r19 <= r0) goto L115;
     */
    /* JADX WARN: Code restructure failed: missing block: B:129:0x02c5, code lost:
    
        r14 = r14 + 1;
        r6.hNumArray[r14] = r19;
        r19 = r19 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:132:0x02f0, code lost:
    
        if (r6.ch == ',') goto L128;
     */
    /* JADX WARN: Code restructure failed: missing block: B:134:0x02f7, code lost:
    
        if (r6.ch == 0) goto L128;
     */
    /* JADX WARN: Code restructure failed: missing block: B:136:0x0300, code lost:
    
        if (r6.ch == '}') goto L128;
     */
    /* JADX WARN: Code restructure failed: missing block: B:138:0x0303, code lost:
    
        r6.ret = com.jiuqi.syntax.SyntaxParser.SY_INVALID_CHAR;
     */
    /* JADX WARN: Code restructure failed: missing block: B:139:0x030d, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:141:0x0312, code lost:
    
        if (r6.ch != 0) goto L132;
     */
    /* JADX WARN: Code restructure failed: missing block: B:143:0x032c, code lost:
    
        if (r6.ch != ',') goto L135;
     */
    /* JADX WARN: Code restructure failed: missing block: B:144:0x032f, code lost:
    
        getChar();
     */
    /* JADX WARN: Code restructure failed: missing block: B:146:0x0339, code lost:
    
        if (r6.ch == '}') goto L331;
     */
    /* JADX WARN: Code restructure failed: missing block: B:148:0x0340, code lost:
    
        if (r6.ch != 0) goto L332;
     */
    /* JADX WARN: Code restructure failed: missing block: B:153:0x0315, code lost:
    
        r6.ret = 7;
        r6.expi = r16;
     */
    /* JADX WARN: Code restructure failed: missing block: B:154:0x0325, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:156:0x02ad, code lost:
    
        r6.expi = r16;
        r6.ret = 55;
     */
    /* JADX WARN: Code restructure failed: missing block: B:157:0x02bd, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:159:0x028f, code lost:
    
        r6.expi = r16;
        r6.ret = 15;
     */
    /* JADX WARN: Code restructure failed: missing block: B:160:0x029f, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:162:0x02de, code lost:
    
        r14 = r14 + 1;
        r6.hNumArray[r14] = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:164:0x0251, code lost:
    
        r6.expi = r16;
        r6.ret = 15;
     */
    /* JADX WARN: Code restructure failed: missing block: B:165:0x0261, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:168:0x0381, code lost:
    
        if (r6.ch != '{') goto L203;
     */
    /* JADX WARN: Code restructure failed: missing block: B:169:0x0384, code lost:
    
        getChar();
        skipSpaces();
     */
    /* JADX WARN: Code restructure failed: missing block: B:170:0x0392, code lost:
    
        if (r6.ch != '}') goto L153;
     */
    /* JADX WARN: Code restructure failed: missing block: B:171:0x0395, code lost:
    
        r15 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:172:0x04a7, code lost:
    
        r0 = r6.expi;
        getChar();
     */
    /* JADX WARN: Code restructure failed: missing block: B:173:0x04b7, code lost:
    
        if (r6.ch != ' ') goto L199;
     */
    /* JADX WARN: Code restructure failed: missing block: B:174:0x04ba, code lost:
    
        skipSpaces();
     */
    /* JADX WARN: Code restructure failed: missing block: B:176:0x04c2, code lost:
    
        if (r6.ch == 0) goto L203;
     */
    /* JADX WARN: Code restructure failed: missing block: B:177:0x04c5, code lost:
    
        r6.expi = r0;
        r6.ret = 56;
     */
    /* JADX WARN: Code restructure failed: missing block: B:178:0x04d5, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:179:0x039b, code lost:
    
        r16 = r6.expi;
        wholeExp(r8);
     */
    /* JADX WARN: Code restructure failed: missing block: B:180:0x03aa, code lost:
    
        if (r6.ret != 0) goto L339;
     */
    /* JADX WARN: Code restructure failed: missing block: B:182:0x03b2, code lost:
    
        if (r8.type == 1) goto L159;
     */
    /* JADX WARN: Code restructure failed: missing block: B:183:0x03c6, code lost:
    
        r0 = r8.cdInt;
     */
    /* JADX WARN: Code restructure failed: missing block: B:184:0x03d2, code lost:
    
        if (r6.ch != '~') goto L176;
     */
    /* JADX WARN: Code restructure failed: missing block: B:185:0x03d5, code lost:
    
        getChar();
        r16 = r6.expi;
        wholeExp(r8);
     */
    /* JADX WARN: Code restructure failed: missing block: B:186:0x03e8, code lost:
    
        if (r6.ret != 0) goto L338;
     */
    /* JADX WARN: Code restructure failed: missing block: B:188:0x03f0, code lost:
    
        if (r8.type == 1) goto L167;
     */
    /* JADX WARN: Code restructure failed: missing block: B:189:0x0404, code lost:
    
        r0 = r8.cdInt;
     */
    /* JADX WARN: Code restructure failed: missing block: B:190:0x040e, code lost:
    
        if (r0 >= r0) goto L171;
     */
    /* JADX WARN: Code restructure failed: missing block: B:191:0x0422, code lost:
    
        r19 = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:193:0x043c, code lost:
    
        if (r19 <= r0) goto L172;
     */
    /* JADX WARN: Code restructure failed: missing block: B:194:0x0429, code lost:
    
        r15 = r15 + 1;
        r6.lNumArray[r15] = r19;
        r19 = r19 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:197:0x0454, code lost:
    
        if (r6.ch == ',') goto L185;
     */
    /* JADX WARN: Code restructure failed: missing block: B:199:0x045b, code lost:
    
        if (r6.ch == 0) goto L185;
     */
    /* JADX WARN: Code restructure failed: missing block: B:201:0x0464, code lost:
    
        if (r6.ch == '}') goto L185;
     */
    /* JADX WARN: Code restructure failed: missing block: B:203:0x0467, code lost:
    
        r6.ret = com.jiuqi.syntax.SyntaxParser.SY_INVALID_CHAR;
     */
    /* JADX WARN: Code restructure failed: missing block: B:204:0x0471, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:206:0x0476, code lost:
    
        if (r6.ch != 0) goto L189;
     */
    /* JADX WARN: Code restructure failed: missing block: B:208:0x0490, code lost:
    
        if (r6.ch != ',') goto L192;
     */
    /* JADX WARN: Code restructure failed: missing block: B:209:0x0493, code lost:
    
        getChar();
     */
    /* JADX WARN: Code restructure failed: missing block: B:211:0x049d, code lost:
    
        if (r6.ch == '}') goto L335;
     */
    /* JADX WARN: Code restructure failed: missing block: B:213:0x04a4, code lost:
    
        if (r6.ch != 0) goto L343;
     */
    /* JADX WARN: Code restructure failed: missing block: B:218:0x0479, code lost:
    
        r6.ret = 7;
        r6.expi = r16;
     */
    /* JADX WARN: Code restructure failed: missing block: B:219:0x0489, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:221:0x0411, code lost:
    
        r6.expi = r16;
        r6.ret = 55;
     */
    /* JADX WARN: Code restructure failed: missing block: B:222:0x0421, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:224:0x03f3, code lost:
    
        r6.expi = r16;
        r6.ret = 15;
     */
    /* JADX WARN: Code restructure failed: missing block: B:225:0x0403, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:227:0x0442, code lost:
    
        r15 = r15 + 1;
        r6.lNumArray[r15] = r0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:229:0x03b5, code lost:
    
        r6.expi = r16;
        r6.ret = 15;
     */
    /* JADX WARN: Code restructure failed: missing block: B:230:0x03c5, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:232:0x04d6, code lost:
    
        r6.expi = 0;
        r0 = extendPos("{", r6.expStr);
     */
    /* JADX WARN: Code restructure failed: missing block: B:233:0x04e9, code lost:
    
        if (r0 < 0) goto L206;
     */
    /* JADX WARN: Code restructure failed: missing block: B:234:0x04ec, code lost:
    
        r6.expStr = r6.expStr.substring(0, r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:235:0x04fa, code lost:
    
        r0 = new java.util.ArrayList();
        r0 = new java.util.ArrayList();
        searchWildcardArea(r6.expStr, r0, r0, true);
        r19 = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:236:0x0526, code lost:
    
        if (extendPos("[*", r6.expStr) < 0) goto L209;
     */
    /* JADX WARN: Code restructure failed: missing block: B:237:0x0529, code lost:
    
        r19 = 0 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:239:0x0536, code lost:
    
        if (extendPos(",*", r6.expStr) < 0) goto L212;
     */
    /* JADX WARN: Code restructure failed: missing block: B:240:0x0539, code lost:
    
        r19 = r19 + 2;
     */
    /* JADX WARN: Code restructure failed: missing block: B:242:0x053e, code lost:
    
        switch(r19) {
            case 0: goto L214;
            case 1: goto L215;
            case 2: goto L228;
            case 3: goto L245;
            default: goto L267;
        };
     */
    /* JADX WARN: Code restructure failed: missing block: B:243:0x055c, code lost:
    
        r14 = 1;
        r15 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:245:0x0567, code lost:
    
        if (r14 != 0) goto L223;
     */
    /* JADX WARN: Code restructure failed: missing block: B:247:0x056f, code lost:
    
        if (r0.size() <= 0) goto L223;
     */
    /* JADX WARN: Code restructure failed: missing block: B:248:0x0572, code lost:
    
        r14 = r0.size();
        r22 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:250:0x059c, code lost:
    
        if (r22 <= r14) goto L220;
     */
    /* JADX WARN: Code restructure failed: missing block: B:251:0x057f, code lost:
    
        r6.hNumArray[r22] = ((java.lang.Integer) r0.get(r22 - 1)).intValue();
        r22 = r22 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:254:0x05a1, code lost:
    
        if (r14 != 0) goto L227;
     */
    /* JADX WARN: Code restructure failed: missing block: B:255:0x05a4, code lost:
    
        r6.ret = 57;
     */
    /* JADX WARN: Code restructure failed: missing block: B:256:0x05ae, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:257:0x05af, code lost:
    
        r15 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:259:0x05b7, code lost:
    
        if (r14 != 0) goto L236;
     */
    /* JADX WARN: Code restructure failed: missing block: B:261:0x05bf, code lost:
    
        if (r0.size() <= 0) goto L236;
     */
    /* JADX WARN: Code restructure failed: missing block: B:262:0x05c2, code lost:
    
        r14 = r0.size();
        r22 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:264:0x05ec, code lost:
    
        if (r22 <= r14) goto L233;
     */
    /* JADX WARN: Code restructure failed: missing block: B:265:0x05cf, code lost:
    
        r6.hNumArray[r22] = ((java.lang.Integer) r0.get(r22 - 1)).intValue();
        r22 = r22 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:268:0x05f1, code lost:
    
        if (r14 != 0) goto L240;
     */
    /* JADX WARN: Code restructure failed: missing block: B:269:0x05f4, code lost:
    
        r6.ret = 57;
     */
    /* JADX WARN: Code restructure failed: missing block: B:270:0x05fe, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:271:0x05ff, code lost:
    
        r15 = r14;
        r14 = 1;
        r22 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:273:0x0621, code lost:
    
        if (r22 <= r15) goto L241;
     */
    /* JADX WARN: Code restructure failed: missing block: B:274:0x060c, code lost:
    
        r6.lNumArray[r22] = r6.hNumArray[r22];
        r22 = r22 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:277:0x0629, code lost:
    
        if (r14 != 0) goto L253;
     */
    /* JADX WARN: Code restructure failed: missing block: B:279:0x0631, code lost:
    
        if (r0.size() <= 0) goto L253;
     */
    /* JADX WARN: Code restructure failed: missing block: B:280:0x0634, code lost:
    
        r14 = r0.size();
        r22 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:282:0x065e, code lost:
    
        if (r22 <= r14) goto L250;
     */
    /* JADX WARN: Code restructure failed: missing block: B:283:0x0641, code lost:
    
        r6.hNumArray[r22] = ((java.lang.Integer) r0.get(r22 - 1)).intValue();
        r22 = r22 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:286:0x0663, code lost:
    
        if (r15 != 0) goto L261;
     */
    /* JADX WARN: Code restructure failed: missing block: B:288:0x066b, code lost:
    
        if (r0.size() <= 0) goto L261;
     */
    /* JADX WARN: Code restructure failed: missing block: B:289:0x066e, code lost:
    
        r15 = r0.size();
        r22 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:291:0x0698, code lost:
    
        if (r22 <= r15) goto L258;
     */
    /* JADX WARN: Code restructure failed: missing block: B:292:0x067b, code lost:
    
        r6.lNumArray[r22] = ((java.lang.Integer) r0.get(r22 - 1)).intValue();
        r22 = r22 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:295:0x069d, code lost:
    
        if (r14 == 0) goto L265;
     */
    /* JADX WARN: Code restructure failed: missing block: B:297:0x06a2, code lost:
    
        if (r15 != 0) goto L267;
     */
    /* JADX WARN: Code restructure failed: missing block: B:298:0x06a5, code lost:
    
        r6.ret = 57;
     */
    /* JADX WARN: Code restructure failed: missing block: B:299:0x06af, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:300:0x06b0, code lost:
    
        r0 = r6.expStr;
        r23 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:302:0x0819, code lost:
    
        if (r23 <= r14) goto L268;
     */
    /* JADX WARN: Code restructure failed: missing block: B:303:0x06bc, code lost:
    
        r0.setLength(0);
        r0.append(r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:304:0x06c8, code lost:
    
        r0 = extendPos("[*", r0.toString());
     */
    /* JADX WARN: Code restructure failed: missing block: B:305:0x06d6, code lost:
    
        if (r0 < 0) goto L272;
     */
    /* JADX WARN: Code restructure failed: missing block: B:306:0x06d9, code lost:
    
        r0.deleteCharAt(r0 + 1);
        r0.insert(r0 + 1, r6.hNumArray[r23]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:308:0x06f4, code lost:
    
        if (r0 >= 0) goto L353;
     */
    /* JADX WARN: Code restructure failed: missing block: B:310:0x06f7, code lost:
    
        r6.expStr = r0.toString();
        r0 = r6.expStr;
        r25 = 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:312:0x080f, code lost:
    
        if (r25 <= r15) goto L275;
     */
    /* JADX WARN: Code restructure failed: missing block: B:313:0x070b, code lost:
    
        r0.setLength(0);
        r0.append(r0);
     */
    /* JADX WARN: Code restructure failed: missing block: B:314:0x0717, code lost:
    
        r0 = extendPos(",*", r0.toString());
     */
    /* JADX WARN: Code restructure failed: missing block: B:315:0x0725, code lost:
    
        if (r0 < 0) goto L279;
     */
    /* JADX WARN: Code restructure failed: missing block: B:316:0x0728, code lost:
    
        r0.deleteCharAt(r0 + 1);
        r0.insert(r0 + 1, r6.lNumArray[r25]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:318:0x0743, code lost:
    
        if (r0 >= 0) goto L358;
     */
    /* JADX WARN: Code restructure failed: missing block: B:320:0x0746, code lost:
    
        r6.expStr = r0.toString();
     */
    /* JADX WARN: Code restructure failed: missing block: B:321:0x0752, code lost:
    
        if (r6.defineExpVision == null) goto L297;
     */
    /* JADX WARN: Code restructure failed: missing block: B:323:0x075f, code lost:
    
        if (r6.defineExpVision.equals("") != false) goto L297;
     */
    /* JADX WARN: Code restructure failed: missing block: B:324:0x0762, code lost:
    
        r0.setLength(0);
        r0.append(r6.defineExpVision);
     */
    /* JADX WARN: Code restructure failed: missing block: B:325:0x0770, code lost:
    
        r0 = extendPos("[*", r0.toString());
     */
    /* JADX WARN: Code restructure failed: missing block: B:326:0x077e, code lost:
    
        if (r0 < 0) goto L289;
     */
    /* JADX WARN: Code restructure failed: missing block: B:327:0x0781, code lost:
    
        r0.deleteCharAt(r0 + 1);
        r0.insert(r0 + 1, r6.hNumArray[r23]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:329:0x079c, code lost:
    
        if (r0 >= 0) goto L360;
     */
    /* JADX WARN: Code restructure failed: missing block: B:331:0x079f, code lost:
    
        r0 = extendPos(",*", r0.toString());
     */
    /* JADX WARN: Code restructure failed: missing block: B:332:0x07ad, code lost:
    
        if (r0 < 0) goto L294;
     */
    /* JADX WARN: Code restructure failed: missing block: B:333:0x07b0, code lost:
    
        r0.deleteCharAt(r0 + 1);
        r0.insert(r0 + 1, r6.lNumArray[r25]);
     */
    /* JADX WARN: Code restructure failed: missing block: B:335:0x07cb, code lost:
    
        if (r0 >= 0) goto L362;
     */
    /* JADX WARN: Code restructure failed: missing block: B:337:0x07ce, code lost:
    
        r6.expVision = r0.toString();
     */
    /* JADX WARN: Code restructure failed: missing block: B:338:0x07e0, code lost:
    
        expCheck(r8);
     */
    /* JADX WARN: Code restructure failed: missing block: B:339:0x07ec, code lost:
    
        if (r6.ret != 1014) goto L301;
     */
    /* JADX WARN: Code restructure failed: missing block: B:340:0x07ef, code lost:
    
        finishOneExpress(true);
     */
    /* JADX WARN: Code restructure failed: missing block: B:342:0x0808, code lost:
    
        r25 = r25 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:344:0x07fb, code lost:
    
        if (r6.ret == 0) goto L305;
     */
    /* JADX WARN: Code restructure failed: missing block: B:345:0x0803, code lost:
    
        finishOneExpress(false);
     */
    /* JADX WARN: Code restructure failed: missing block: B:349:0x0802, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:352:0x07d9, code lost:
    
        r6.expVision = "";
     */
    /* JADX WARN: Code restructure failed: missing block: B:355:0x0812, code lost:
    
        r23 = r23 + 1;
     */
    /* JADX WARN: Code restructure failed: missing block: B:358:0x081c, code lost:
    
        r6.ret = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:359:0x0825, code lost:
    
        return r6.ret;
     */
    /* JADX WARN: Code restructure failed: missing block: B:92:0x0200, code lost:
    
        if (r6.ch != '{') goto L87;
     */
    /* JADX WARN: Code restructure failed: missing block: B:93:0x0203, code lost:
    
        getChar();
     */
    /* JADX WARN: Code restructure failed: missing block: B:94:0x020d, code lost:
    
        if (r6.ch == '{') goto L321;
     */
    /* JADX WARN: Code restructure failed: missing block: B:96:0x0214, code lost:
    
        if (r6.ch != 0) goto L322;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private int estimate(java.lang.String r7, com.jiuqi.syntax.SyntaxData r8) {
        /*
            Method dump skipped, instructions count: 2086
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.syntax.SyntaxParser.estimate(java.lang.String, com.jiuqi.syntax.SyntaxData):int");
    }

    private String searchTableName(String s, int beginPos) {
        String result = "";
        while (beginPos >= 0 && s.charAt(beginPos) == ' ') {
            beginPos--;
        }
        while (beginPos >= 0 && isSignChar(s.charAt(beginPos))) {
            result = String.valueOf(s.charAt(beginPos)) + result;
            beginPos--;
        }
        if (result.equals(OP_IF_NAME) || result.equals(OP_THEN_NAME) || result.equals(OP_ELSE_NAME) || result.equals(OP_AND_NAME) || result.equals(OP_OR_NAME) || result.equals(OP_NOT_NAME)) {
            result = "";
        }
        return result;
    }

    private void searchWildcardArea(String expStr, ArrayList hangAreas, ArrayList lanAreas, boolean attractWildcardArea) {
        String cellStr1;
        int error;
        int cellIndex;
        String cellStr2;
        int error2;
        int cellIndex2;
        int error3;
        int cellIndex3;
        String cellStr3;
        int error4;
        int cellIndex4;
        String cellStr;
        String newExpStr = "";
        ArrayList wildcardInfos = new ArrayList();
        hangAreas.clear();
        lanAreas.clear();
        int syntaxPos = syntaxPos("[", expStr);
        while (true) {
            int i = syntaxPos;
            if (i >= 0) {
                boolean found = false;
                boolean strStart = false;
                int j = i;
                while (true) {
                    if (j >= expStr.length()) {
                        break;
                    }
                    if (expStr.charAt(j) == '\"') {
                        strStart = !strStart;
                    }
                    if (strStart || expStr.charAt(j) != ']') {
                        j++;
                    } else {
                        found = true;
                        break;
                    }
                }
                if (!found) {
                    break;
                }
                String taskTag = "";
                int taskTagPos = j + 1;
                while (taskTagPos < expStr.length() && expStr.charAt(taskTagPos) == ' ') {
                    taskTagPos++;
                }
                if (taskTagPos < expStr.length() && expStr.charAt(taskTagPos) == '@') {
                    String str = "";
                    while (true) {
                        cellStr = str;
                        taskTagPos++;
                        if (taskTagPos >= expStr.length() || !isDigitChar(expStr.charAt(taskTagPos))) {
                            break;
                        } else {
                            str = String.valueOf(cellStr) + expStr.charAt(taskTagPos);
                        }
                    }
                    taskTag = cellStr;
                }
                String cellStr4 = expStr.substring(i + 1, j);
                int dot = syntaxPos(",", cellStr4);
                if (dot >= 0) {
                    cellStr1 = cellStr4.substring(0, dot);
                    cellStr2 = cellStr4.substring(dot + 1);
                    int dot2 = syntaxPos(",", cellStr2);
                    if (dot2 >= 0) {
                        cellStr3 = cellStr2.substring(dot2 + 1);
                        cellStr2 = cellStr2.substring(0, dot2);
                    } else {
                        cellStr3 = "";
                    }
                    if (!cellStr2.equals("") && cellStr2.charAt(0) == '\'') {
                        cellStr3 = cellStr3.equals("") ? cellStr2 : String.valueOf(cellStr2) + "," + cellStr3;
                        cellStr2 = "";
                    }
                    if (cellStr2.equals("")) {
                        if (cellStr1.equals(OP_PRODUCT_NAME)) {
                            cellStr2 = OP_PRODUCT_NAME;
                            cellStr4 = String.valueOf(cellStr1) + "," + cellStr2;
                        } else {
                            if (cellStr1.equals("") || cellStr1.charAt(0) < '0' || cellStr1.charAt(0) > '9') {
                                error4 = 0;
                                cellIndex4 = 0;
                            } else {
                                error4 = -1;
                                cellIndex4 = 0;
                                try {
                                    cellIndex4 = Integer.parseInt(cellStr1);
                                } catch (Exception unused) {
                                    error4 = 0;
                                }
                            }
                            if (error4 < 0 && cellIndex4 > 0) {
                                cellStr2 = OP_PRODUCT_NAME;
                                cellStr4 = String.valueOf(cellStr1) + "," + cellStr2;
                            } else {
                                cellStr2 = "";
                                cellStr4 = cellStr1;
                            }
                        }
                        if (!cellStr3.equals("")) {
                            cellStr4 = String.valueOf(cellStr4) + "," + cellStr3;
                        }
                    }
                } else {
                    cellStr1 = cellStr4;
                    if (cellStr1.equals(OP_PRODUCT_NAME)) {
                        cellStr2 = OP_PRODUCT_NAME;
                        cellStr4 = String.valueOf(cellStr1) + "," + cellStr2;
                    } else {
                        if (cellStr1.equals("") || cellStr1.charAt(0) < '0' || cellStr1.charAt(0) > '9') {
                            error = 0;
                            cellIndex = 0;
                        } else {
                            error = -1;
                            cellIndex = 0;
                            try {
                                cellIndex = Integer.parseInt(cellStr1);
                            } catch (Exception unused2) {
                                error = 0;
                            }
                        }
                        if (error < 0 && cellIndex > 0) {
                            cellStr2 = OP_PRODUCT_NAME;
                            cellStr4 = String.valueOf(cellStr1) + "," + cellStr2;
                        } else {
                            cellStr2 = "";
                        }
                    }
                }
                String tableName = searchTableName(expStr, i - 1);
                if (cellStr1.equals(OP_PRODUCT_NAME) && cellStr2.equals(OP_PRODUCT_NAME)) {
                    WildcardInfo info = new WildcardInfo();
                    wildcardInfos.add(info);
                    info.taskName = taskTag;
                    info.tableName = tableName;
                    info.isLan = true;
                    info.number = 0;
                    WildcardInfo info2 = new WildcardInfo();
                    wildcardInfos.add(info2);
                    info2.taskName = taskTag;
                    info2.tableName = tableName;
                    info2.isLan = false;
                    info2.number = 0;
                } else if (cellStr1.equals(OP_PRODUCT_NAME)) {
                    if (cellStr2.equals("") || cellStr2.charAt(0) < '0' || cellStr2.charAt(0) > '9') {
                        error3 = 0;
                        cellIndex3 = 0;
                    } else {
                        error3 = -1;
                        cellIndex3 = 0;
                        try {
                            cellIndex3 = Integer.parseInt(cellStr2);
                        } catch (Exception unused3) {
                            error3 = 0;
                        }
                    }
                    if (error3 < 0 && cellIndex3 > 0) {
                        WildcardInfo info3 = new WildcardInfo();
                        wildcardInfos.add(info3);
                        info3.taskName = taskTag;
                        info3.tableName = tableName;
                        info3.isLan = false;
                        info3.number = cellIndex3;
                    }
                } else if (cellStr2.equals(OP_PRODUCT_NAME)) {
                    if (cellStr1.equals("") || cellStr1.charAt(0) < '0' || cellStr1.charAt(0) > '9') {
                        error2 = 0;
                        cellIndex2 = 0;
                    } else {
                        error2 = -1;
                        cellIndex2 = 0;
                        try {
                            cellIndex2 = Integer.parseInt(cellStr1);
                        } catch (Exception unused4) {
                            error2 = 0;
                        }
                    }
                    if (error2 < 0 && cellIndex2 > 0) {
                        WildcardInfo info4 = new WildcardInfo();
                        wildcardInfos.add(info4);
                        info4.taskName = taskTag;
                        info4.tableName = tableName;
                        info4.isLan = true;
                        info4.number = cellIndex2;
                    }
                }
                newExpStr = String.valueOf(newExpStr) + expStr.substring(0, i) + "[" + cellStr4 + "]";
                expStr = expStr.substring(j + 1);
                syntaxPos = syntaxPos("[", expStr);
            } else {
                break;
            }
        }
        String str2 = String.valueOf(newExpStr) + expStr;
        if (attractWildcardArea && wildcardInfos.size() > 0) {
            getWildcardAreas(wildcardInfos, hangAreas, lanAreas);
        }
    }

    private int getCellData(DataCell dataCell, CommonData value) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.getValue(new SyntaxEvent(this, dataCell, value));
        }
        return 1;
    }

    private int setCellData(DataCell dataCell, CommonData value) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.setValue(new SyntaxEvent(this, dataCell, value));
        }
        return 1;
    }

    private int getStatData(DataCell dataCell, CommonData value) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.getStatValue(new SyntaxEvent(this, dataCell, value));
        }
        return 1;
    }

    private int getWildcardAreas(ArrayList wildcardInfos, ArrayList hangAreas, ArrayList lanAreas) {
        if (this.syntaxListener != null) {
            WildcardInfo[] infos = new WildcardInfo[wildcardInfos.size()];
            for (int i = 0; i < wildcardInfos.size(); i++) {
                infos[i] = (WildcardInfo) wildcardInfos.get(i);
            }
            WildcardAreasEvent event = new WildcardAreasEvent(this, infos);
            this.syntaxListener.getWildcardAreas(event);
            hangAreas.clear();
            if (event.hangAreas != null) {
                for (int i2 = 0; i2 < event.hangAreas.length; i2++) {
                    hangAreas.add(new Integer(event.hangAreas[i2]));
                }
            }
            lanAreas.clear();
            if (event.lanAreas != null) {
                for (int i3 = 0; i3 < event.lanAreas.length; i3++) {
                    lanAreas.add(new Integer(event.lanAreas[i3]));
                }
                return 0;
            }
            return 0;
        }
        return 1;
    }

    private int getInDict(DictMeaningEvent event) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.getDictMeaning(event);
        }
        return 1;
    }

    private int getDictValue(DictMeaningEvent event) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.getDictMeaning(event);
        }
        return 1;
    }

    private int getUnitState(UnitStateEvent event) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.getUnitState(event);
        }
        return 1;
    }

    private int getLinkPlus(LinkPlusEvent event) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.getLinkPlus(event);
        }
        return 1;
    }

    private int getFloatStat(FloatStatEvent event) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.getFloatStat(event);
        }
        return 1;
    }

    private int execFloatCopy(FloatCopyEvent event) {
        if (this.syntaxListener != null) {
            return this.syntaxListener.execFloatCopy(event);
        }
        return 1;
    }

    private void finishOneExpress(boolean hasError) {
        if (this.syntaxListener != null) {
            this.syntaxListener.finishOneExpress(hasError);
        }
    }

    private void getChar() {
        if (this.expi >= 0 && this.expi < this.expStr.length()) {
            this.ch = this.expStr.charAt(this.expi);
            this.expi++;
        } else {
            this.ch = (char) 0;
        }
    }

    private char getNextChar() {
        if (this.expi >= 0 && this.expi < this.expStr.length()) {
            return this.expStr.charAt(this.expi);
        }
        return (char) 0;
    }

    private void skipSpaces() {
        while (this.ch == ' ') {
            getChar();
        }
    }

    private int getInteger() {
        StringBuffer strBuffer = new StringBuffer();
        if (this.ch == ' ') {
            skipSpaces();
        }
        if (this.ch == '+' || this.ch == '-') {
            if (this.ch == '-') {
                strBuffer.append(this.ch);
            }
            getChar();
        }
        if (this.ch == ' ') {
            skipSpaces();
        }
        if (this.ch < '0' || this.ch > '9') {
            this.ret = SY_INVALID_CHAR;
            return 0;
        }
        try {
            do {
                strBuffer.append(this.ch);
                getChar();
                if (this.ch >= '0') {
                }
                return Integer.parseInt(strBuffer.toString());
            } while (this.ch <= '9');
            return Integer.parseInt(strBuffer.toString());
        } catch (Exception unused) {
            this.ret = 15;
            return 0;
        }
    }

    private void addCellCaption(DataCell dataCell) {
        SyntaxCellTitleEvent event = new SyntaxCellTitleEvent(this, dataCell, "");
        if (this.syntaxListener != null) {
            this.syntaxListener.getCellTitle(event);
        }
        if (event.cellTitle == null || event.cellTitle.equals("")) {
            addStringCaption(dataCell.toString());
        } else {
            addStringCaption(event.cellTitle);
        }
    }

    private void addStringCaption(String s) {
        if (!this.inParseCell && this.inEffectCheck) {
            this.expDescription = String.valueOf(this.expDescription) + s;
        }
    }

    private void addStringCaption(char c) {
        addStringCaption(String.valueOf(c));
    }

    private void addCellVision(DataCell dataCell) {
        addStringVision(dataCell.toString());
    }

    private void addStringVision(String s) {
        if ((this.defineExpVision == null || this.defineExpVision.equals("")) && this.expVision.indexOf(String.valueOf(s) + ";") < 0) {
            this.expVision = String.valueOf(this.expVision) + s + ";";
        }
    }

    private void writeNiporlan(NiporlanItem ni) {
        if (this.niporlan != null) {
            switch (this.niporlanItemType) {
                case 0:
                    this.niporlan.addIfItem(ni);
                    return;
                case 1:
                    this.niporlan.addThenItem(ni);
                    return;
                case 2:
                    this.niporlan.addElseitem(ni);
                    return;
                default:
                    return;
            }
        }
    }

    private void writeNiporlan(int op) {
        if (this.niporlan == null) {
            return;
        }
        if (this.niFactory != null) {
            writeNiporlan(this.niFactory.getNiporlanItem(op));
        } else {
            writeNiporlan(new NiporlanItem(op));
        }
    }

    private void writeNiporlan(String funcName) {
        if (this.niporlan == null) {
            return;
        }
        if (this.niFactory != null) {
            writeNiporlan(this.niFactory.getNiporlanItem(funcName));
        } else {
            writeNiporlan(new NiporlanItem(funcName));
        }
    }

    private void writeNiporlan(CommonData commonData) {
        if (this.niporlan == null) {
            return;
        }
        if (this.niFactory != null) {
            writeNiporlan(this.niFactory.getNiporlanItem(commonData));
        } else {
            writeNiporlan(new NiporlanItem(commonData));
        }
    }

    private void writeNiporlan(DataCell dataCell) {
        NiporlanItem ni;
        if (this.niporlan == null) {
            return;
        }
        if (this.niFactory != null) {
            ni = this.niFactory.getNiporlanItem(dataCell);
        } else {
            ni = new NiporlanItem(dataCell);
        }
        writeNiporlan(ni);
        if (this.optListener != null) {
            this.optListener.finishOneNiporlanItem(ni);
        }
    }

    private void writeNiporlan(Object object) {
        if (this.niporlan == null) {
            return;
        }
        if (this.niFactory != null) {
            writeNiporlan(this.niFactory.getNiporlanItem(object));
        } else {
            writeNiporlan(new NiporlanItem(object));
        }
    }

    private SyntaxData newSyntaxData() {
        SyntaxData syntaxData;
        if (!this.unUsedSyntaxDatas.empty()) {
            syntaxData = (SyntaxData) this.unUsedSyntaxDatas.pop();
        } else {
            syntaxData = new SyntaxData();
        }
        return syntaxData;
    }

    private void disposeSyntaxData(SyntaxData syntaxData) {
        this.unUsedSyntaxDatas.push(syntaxData);
    }

    private void checkOpData(SyntaxData opData) {
        if (opData.type == 9) {
            this.ret = getCellData(opData.cdCell, opData.value);
            if (this.ret != 0) {
                return;
            }
            opData.assign(opData.value);
        }
    }

    private void checkOpType(SyntaxData lopData, SyntaxData ropData, int opCode) {
        if (lopData.type == 0 || ropData.type == 0) {
            lopData.type = 0;
            this.ret = 0;
            return;
        }
        if (opCode == 6) {
            if (lopData.type != 9 || lopData.type != ropData.type) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if (!lopData.cdCell.tableName.equals(ropData.cdCell.tableName) || !lopData.cdCell.taskName.equals(ropData.cdCell.taskName) || lopData.cdCell.isZB || ropData.cdCell.isZB || lopData.cdCell.year != ropData.cdCell.year || lopData.cdCell.termKind != ropData.cdCell.termKind || lopData.cdCell.term != ropData.cdCell.term || ((lopData.value.type != 1 && lopData.value.type != 2 && lopData.value.type != 10) || (ropData.value.type != 1 && ropData.value.type != 2 && ropData.value.type != 10))) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if (lopData.cdCell.row > ropData.cdCell.row || lopData.cdCell.col > ropData.cdCell.col) {
                this.ret = SY_CPLUS_OUTOF_ORDER;
                return;
            }
            SyntaxData sumSyData = newSyntaxData();
            try {
                sumSyData.assign(lopData);
                this.tempSyData.assign(lopData);
                sumSyData.value.type = 2;
                sumSyData.value.cdReal = 0.0d;
                for (int r = lopData.cdCell.row; r <= ropData.cdCell.row; r++) {
                    for (int c = lopData.cdCell.col; c <= ropData.cdCell.col; c++) {
                        this.tempSyData.cdCell.row = r;
                        this.tempSyData.cdCell.col = c;
                        this.ret = getCellData(this.tempSyData.cdCell, this.tempSyData.value);
                        if (this.ret == 0) {
                            if (this.tempSyData.value.type == 2) {
                                sumSyData.value.cdReal += this.tempSyData.value.cdReal;
                            } else if (this.tempSyData.value.type == 1) {
                                sumSyData.value.cdReal += this.tempSyData.value.cdInt;
                            } else {
                                this.ret = SY_TYPE_NO_MATCH;
                            }
                        }
                        return;
                    }
                }
                lopData.type = 2;
                lopData.isNull = false;
                lopData.cdReal = sumSyData.value.cdReal;
                this.ret = 0;
                return;
            } finally {
                disposeSyntaxData(sumSyData);
            }
        }
        if (ropData.type == 9) {
            this.ret = getCellData(ropData.cdCell, ropData.value);
            if (this.ret != 0) {
                return;
            }
            ropData.assign(ropData.value);
            ropData.initNullValue();
        }
        if (opCode == 17) {
            if (lopData.type != 9) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if (lopData.value.type != 0 && lopData.value.type != ropData.type && lopData.value.type != 1 && lopData.value.type != 2 && lopData.value.type != 10 && ropData.value.type != 1 && ropData.value.type != 2 && ropData.value.type != 10) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            lopData.value.assign(ropData);
            if (this.canAssignValue) {
                this.ret = setCellData(lopData.cdCell, lopData.value);
                return;
            }
            return;
        }
        if (lopData.type == 9) {
            this.ret = getCellData(lopData.cdCell, lopData.value);
            if (this.ret != 0) {
                return;
            }
            lopData.assign(lopData.value);
            lopData.initNullValue();
        }
        if (opCode == 15) {
            if (lopData.type != 5 || ropData.type != 5) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            lopData.cdBool = lopData.cdBool || ropData.cdBool;
            lopData.isNull = false;
            this.ret = 0;
            return;
        }
        if (opCode == 14) {
            if (lopData.type != 5 || ropData.type != 5) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            lopData.cdBool = lopData.cdBool && ropData.cdBool;
            lopData.isNull = false;
            this.ret = 0;
            return;
        }
        if (opCode == 1 || opCode == 2 || opCode == 4 || opCode == 5) {
            if (lopData.type == 5) {
                lopData.type = 1;
                if (lopData.cdBool) {
                    lopData.cdInt = -1;
                } else {
                    lopData.cdInt = 0;
                }
            } else if (ropData.type == 5) {
                ropData.type = 1;
                if (ropData.cdBool) {
                    ropData.cdInt = -1;
                } else {
                    ropData.cdInt = 0;
                }
            } else if ((lopData.type == 3 && ropData.type != 3) || (ropData.type != 3 && lopData.type == 3)) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if (lopData.type == 3) {
                if (opCode == 1) {
                    lopData.cdString = String.valueOf(lopData.cdString) + ropData.cdString;
                    lopData.isNull = lopData.isNull && ropData.isNull;
                    this.ret = 0;
                    return;
                }
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if ((lopData.type == 6 && ropData.type != 6) || (ropData.type != 6 && lopData.type == 6)) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if (lopData.type == 6) {
                if (opCode == 2) {
                    lopData.type = 1;
                    lopData.cdInt = minusDate(lopData.cdDate, ropData.cdDate);
                    lopData.isNull = false;
                    this.ret = 0;
                    return;
                }
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if (lopData.type == 1 && ropData.type == 1) {
                switch (opCode) {
                    case 1:
                        if (Math.abs(lopData.cdInt + ropData.cdInt) <= 2.147483647E9d) {
                            lopData.cdInt += ropData.cdInt;
                            break;
                        } else {
                            lopData.type = 2;
                            lopData.cdReal = lopData.cdInt + ropData.cdInt;
                            break;
                        }
                    case 2:
                        if (Math.abs(lopData.cdInt - ropData.cdInt) <= 2.147483647E9d) {
                            lopData.cdInt -= ropData.cdInt;
                            break;
                        } else {
                            lopData.type = 2;
                            lopData.cdReal = lopData.cdInt - ropData.cdInt;
                            break;
                        }
                    case 4:
                        if (Math.abs(lopData.cdInt * ropData.cdInt) <= 2.147483647E9d) {
                            lopData.cdInt *= ropData.cdInt;
                            break;
                        } else {
                            lopData.type = 2;
                            lopData.cdReal = lopData.cdInt * ropData.cdInt;
                            break;
                        }
                    case 5:
                        lopData.type = 2;
                        if (ropData.cdInt == 0) {
                            lopData.cdReal = 0.0d;
                            break;
                        } else {
                            lopData.cdReal = lopData.cdInt / ropData.cdInt;
                            break;
                        }
                }
                lopData.isNull = false;
                this.ret = 0;
                return;
            }
            if ((lopData.type == 2 || lopData.type == 1) && (ropData.type == 2 || ropData.type == 1)) {
                if (lopData.type == 1) {
                    lopData.type = 2;
                    lopData.cdReal = lopData.cdInt;
                }
                if (ropData.type == 1) {
                    ropData.type = 2;
                    ropData.cdReal = ropData.cdInt;
                }
                switch (opCode) {
                    case 1:
                        lopData.cdReal += ropData.cdReal;
                        break;
                    case 2:
                        if (Math.abs(lopData.cdReal - ropData.cdReal) >= 1.0E-5d) {
                            lopData.cdReal -= ropData.cdReal;
                            break;
                        } else {
                            lopData.cdReal = 0.0d;
                            break;
                        }
                    case 4:
                        lopData.cdReal *= ropData.cdReal;
                        break;
                    case 5:
                        if (ropData.cdReal != 0.0d) {
                            lopData.cdReal /= ropData.cdReal;
                            break;
                        } else {
                            lopData.cdReal = 0.0d;
                            break;
                        }
                }
                lopData.isNull = false;
                this.ret = 0;
                return;
            }
            if ((lopData.type == 2 || lopData.type == 1 || lopData.type == 10) && (ropData.type == 2 || ropData.type == 1 || ropData.type == 10)) {
                if (lopData.type != 10) {
                    lopData.type = 10;
                    if (lopData.type == 1) {
                        lopData.cdDecimal = new BigDecimal(lopData.cdInt);
                    } else if (lopData.type == 2) {
                        lopData.cdDecimal = new BigDecimal(lopData.cdReal);
                    }
                }
                if (lopData.cdDecimal == null) {
                    lopData.cdDecimal = new BigDecimal(0);
                }
                if (ropData.type != 10) {
                    ropData.type = 10;
                    if (ropData.type == 1) {
                        ropData.cdDecimal = new BigDecimal(ropData.cdInt);
                    } else if (ropData.type == 2) {
                        ropData.cdDecimal = new BigDecimal(ropData.cdReal);
                    }
                }
                if (ropData.cdDecimal == null) {
                    ropData.cdDecimal = new BigDecimal(0);
                }
                switch (opCode) {
                    case 1:
                        lopData.cdDecimal = lopData.cdDecimal.add(ropData.cdDecimal);
                        break;
                    case 2:
                        lopData.cdDecimal = lopData.cdDecimal.subtract(ropData.cdDecimal);
                        if (lopData.cdDecimal.compareTo(new BigDecimal(1.0E-5d)) < 0) {
                            lopData.cdDecimal = new BigDecimal(0);
                            break;
                        }
                        break;
                    case 4:
                        lopData.cdDecimal = lopData.cdDecimal.multiply(ropData.cdDecimal);
                        break;
                    case 5:
                        if (ropData.cdDecimal.compareTo(new BigDecimal(1.0E-5d)) < 0) {
                            lopData.cdDecimal = new BigDecimal(0);
                            break;
                        } else {
                            lopData.cdDecimal = lopData.cdDecimal.divide(ropData.cdDecimal, 4);
                            break;
                        }
                }
                lopData.isNull = false;
                this.ret = 0;
                return;
            }
            this.ret = SY_TYPE_NO_MATCH;
            return;
        }
        if (opCode == 8) {
            if (lopData.type != 3 || ropData.type != 3) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            lopData.type = 5;
            lopData.isNull = false;
            this.ret = 0;
            return;
        }
        if (opCode == 7 || opCode == 9 || opCode == 10 || opCode == 11 || opCode == 12 || opCode == 13) {
            if ((lopData.type == 3 && ropData.type != 3) || (lopData.type != 3 && ropData.type == 3)) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if ((lopData.type == 6 && ropData.type != 6) || (lopData.type != 6 && ropData.type == 6)) {
                this.ret = SY_TYPE_NO_MATCH;
                return;
            }
            if (lopData.type == 3) {
                lopData.type = 5;
                switch (opCode) {
                    case 7:
                        lopData.cdBool = lopData.cdString.equals(ropData.cdString);
                        break;
                    case 9:
                        lopData.cdBool = !lopData.cdString.equals(ropData.cdString);
                        break;
                    case 10:
                        lopData.cdBool = lopData.cdString.compareTo(ropData.cdString) > 0;
                        break;
                    case 11:
                        lopData.cdBool = lopData.cdString.compareTo(ropData.cdString) < 0;
                        break;
                    case 12:
                        lopData.cdBool = lopData.cdString.compareTo(ropData.cdString) >= 0;
                        break;
                    case 13:
                        lopData.cdBool = lopData.cdString.compareTo(ropData.cdString) <= 0;
                        break;
                }
                lopData.isNull = false;
                this.ret = 0;
                return;
            }
            if (lopData.type == 6) {
                lopData.getValidcdDate();
                ropData.getValidcdDate();
                lopData.type = 5;
                switch (opCode) {
                    case 7:
                        lopData.cdBool = lopData.cdDate.equals(ropData.cdDate);
                        break;
                    case 9:
                        lopData.cdBool = !lopData.cdDate.equals(ropData.cdDate);
                        break;
                    case 10:
                        lopData.cdBool = lopData.cdDate.after(ropData.cdDate);
                        break;
                    case 11:
                        lopData.cdBool = lopData.cdDate.before(ropData.cdDate);
                        break;
                    case 12:
                        lopData.cdBool = lopData.cdDate.after(ropData.cdDate) || lopData.cdDate.equals(ropData.cdDate);
                        break;
                    case 13:
                        lopData.cdBool = lopData.cdDate.before(ropData.cdDate) || lopData.cdDate.equals(ropData.cdDate);
                        break;
                }
                lopData.isNull = false;
                this.ret = 0;
                return;
            }
            if (lopData.type == 1 && ropData.type == 1) {
                lopData.type = 5;
                switch (opCode) {
                    case 7:
                        lopData.cdBool = lopData.cdInt == ropData.cdInt;
                        break;
                    case 9:
                        lopData.cdBool = lopData.cdInt != ropData.cdInt;
                        break;
                    case 10:
                        lopData.cdBool = lopData.cdInt > ropData.cdInt;
                        break;
                    case 11:
                        lopData.cdBool = lopData.cdInt < ropData.cdInt;
                        break;
                    case 12:
                        lopData.cdBool = lopData.cdInt >= ropData.cdInt;
                        break;
                    case 13:
                        lopData.cdBool = lopData.cdInt <= ropData.cdInt;
                        break;
                }
                lopData.isNull = false;
                this.ret = 0;
                return;
            }
            if (lopData.type == 1) {
                lopData.type = 2;
                lopData.cdReal = lopData.cdInt;
            }
            if (ropData.type == 1) {
                ropData.type = 2;
                ropData.cdReal = ropData.cdInt;
            }
            lopData.type = 5;
            switch (opCode) {
                case 7:
                    lopData.cdBool = Math.abs(lopData.cdReal - ropData.cdReal) < getBalanceDifferenceValue();
                    break;
                case 9:
                    lopData.cdBool = Math.abs(lopData.cdReal - ropData.cdReal) >= getBalanceDifferenceValue();
                    break;
                case 10:
                    lopData.cdBool = lopData.cdReal - ropData.cdReal > 1.0E-5d;
                    break;
                case 11:
                    lopData.cdBool = lopData.cdReal - ropData.cdReal < -1.0E-5d;
                    break;
                case 12:
                    lopData.cdBool = lopData.cdReal - ropData.cdReal > getBalanceDifferenceValue() || Math.abs(lopData.cdReal - ropData.cdReal) < getBalanceDifferenceValue();
                    break;
                case 13:
                    lopData.cdBool = lopData.cdReal - ropData.cdReal < (-getBalanceDifferenceValue()) || Math.abs(lopData.cdReal - ropData.cdReal) < getBalanceDifferenceValue();
                    break;
            }
            lopData.isNull = false;
            this.ret = 0;
        }
    }

    private void multorFuncParam(FunctionParam param, SyntaxData opData) {
        if (param.type == 3 && param.isSign) {
            if (this.ch == ' ') {
                skipSpaces();
            }
            String tmpStr = "";
            while (true) {
                if (!isSignChar(this.ch) && this.ch != '<' && this.ch != '>' && this.ch != ':' && this.ch != '#') {
                    break;
                }
                tmpStr = String.valueOf(tmpStr) + this.ch;
                getChar();
            }
            if (!tmpStr.equals("")) {
                if (this.hasExpDescription) {
                    addStringCaption(tmpStr);
                }
                opData.type = 3;
                opData.isNull = false;
                opData.cdString = tmpStr;
                if (this.hasMakeNiporlan) {
                    writeNiporlan((CommonData) opData);
                    return;
                }
                return;
            }
            wholeExp(opData);
            if (this.ret != 0) {
                return;
            }
            this.tempSyData.type = 3;
            this.tempSyData.isNull = false;
            this.tempSyData.cdString = "";
            checkOpType(opData, this.tempSyData, 1);
            if (this.ret != 0) {
                this.ret = 17;
                return;
            }
            return;
        }
        if (param.type == 4) {
            if (this.ch == ' ') {
                skipSpaces();
            }
            if (this.ch != '\'') {
                this.ret = SY_FUNC_BAD_PARAM;
                return;
            }
            getChar();
            this.tmpStrBuffer.setLength(0);
            while (this.ch != '\'' && this.ch != 0) {
                this.tmpStrBuffer.append(this.ch);
                getChar();
            }
            if (this.ch != '\'') {
                this.ret = SY_FUNC_BAD_PARAM;
                return;
            }
            opData.type = 4;
            opData.isNull = false;
            opData.cdString = this.tmpStrBuffer.toString();
            if (this.hasMakeNiporlan) {
                writeNiporlan((CommonData) opData);
            }
            getChar();
            if (this.hasExpDescription) {
                addStringCaption("'" + opData.cdString + "'");
                return;
            }
            return;
        }
        wholeExp(opData);
        if (this.ret != 0) {
            return;
        }
        if (param.type == 3) {
            this.tempSyData.type = 3;
            this.tempSyData.isNull = false;
            this.tempSyData.cdString = "";
            checkOpType(opData, this.tempSyData, 1);
            if (this.ret != 0) {
                this.ret = 17;
                return;
            }
            return;
        }
        if (param.type == 2 || param.type == 1) {
            this.tempSyData.type = 1;
            this.tempSyData.isNull = false;
            this.tempSyData.cdInt = 1;
            checkOpType(opData, this.tempSyData, 4);
            if (this.ret != 0) {
                this.ret = 16;
                return;
            }
            return;
        }
        if (param.type == 5) {
            this.tempSyData.type = 5;
            this.tempSyData.isNull = false;
            this.tempSyData.cdBool = false;
            checkOpType(opData, this.tempSyData, 15);
            if (this.ret != 0) {
                this.ret = 19;
                return;
            }
            return;
        }
        if (param.type == 6) {
            checkOpData(opData);
            if (this.ret != 0 || opData.type != 6) {
                this.ret = 18;
                return;
            }
            return;
        }
        if (param.type == 0) {
            checkOpData(opData);
            if (this.ret != 0) {
            }
        }
    }

    private void multor(SyntaxData syData) {
        SyntaxData leftOpData = newSyntaxData();
        SyntaxData rightOpData = newSyntaxData();
        try {
            if (this.ch == 0) {
                this.ret = 9;
            } else {
                if (this.ch == ' ') {
                    skipSpaces();
                }
                if (this.ch == '\"') {
                    this.tmpStrBuffer.setLength(0);
                    getChar();
                    while (this.ch != '\"' && this.ch != 0) {
                        this.tmpStrBuffer.append(this.ch);
                        getChar();
                    }
                    if (this.ch == '\"') {
                        getChar();
                    }
                    if (this.hasExpDescription) {
                        addStringCaption("\"" + ((Object) this.tmpStrBuffer) + "\"");
                    }
                    syData.type = 3;
                    syData.cdString = this.tmpStrBuffer.toString();
                    syData.isNull = false;
                    if (this.hasMakeNiporlan && !this.inParseCell && this.inEffectCheck) {
                        writeNiporlan((CommonData) syData);
                    }
                    this.ret = 0;
                } else if ((this.ch >= '0' && this.ch <= '9') || (this.ch == '-' && getNextChar() >= '0' && getNextChar() <= '9')) {
                    if (this.hasExpDescription) {
                        addStringCaption(this.ch);
                    }
                    if (this.ch == '-') {
                        getChar();
                        this.tempReal = -Double.parseDouble(String.valueOf(this.ch));
                    } else {
                        this.tempReal = Double.parseDouble(String.valueOf(this.ch));
                    }
                    getChar();
                    while (this.ch >= '0' && this.ch <= '9') {
                        if (this.hasExpDescription) {
                            addStringCaption(this.ch);
                        }
                        this.tempReal = (this.tempReal * 10.0d) + Double.parseDouble(String.valueOf(this.ch));
                        getChar();
                    }
                    if (this.ch == '.') {
                        if (this.hasExpDescription) {
                            addStringCaption(this.ch);
                        }
                        getChar();
                        this.decPos = 0.1d;
                        while (this.ch >= '0' && this.ch <= '9') {
                            if (this.hasExpDescription) {
                                addStringCaption(this.ch);
                            }
                            this.tempReal += Double.parseDouble(String.valueOf(this.ch)) * this.decPos;
                            this.decPos /= 10.0d;
                            getChar();
                        }
                        syData.type = 2;
                        syData.cdReal = this.tempReal;
                        syData.isNull = false;
                        if (this.hasMakeNiporlan) {
                            writeNiporlan((CommonData) syData);
                        }
                        this.ret = 0;
                    } else if (this.tempReal < 2.147483647E9d) {
                        syData.type = 1;
                        syData.cdInt = (int) this.tempReal;
                        syData.isNull = false;
                        if (this.hasMakeNiporlan && !this.inParseCell && this.inEffectCheck) {
                            writeNiporlan((CommonData) syData);
                        }
                        this.ret = 0;
                    } else {
                        syData.type = 2;
                        syData.cdReal = this.tempReal;
                        syData.isNull = false;
                        if (this.hasMakeNiporlan && !this.inParseCell && this.inEffectCheck) {
                            writeNiporlan((CommonData) syData);
                        }
                        this.ret = 0;
                    }
                } else if (this.ch == '(') {
                    if (this.hasExpDescription) {
                        addStringCaption(this.ch);
                    }
                    getChar();
                    wholeExp(syData);
                    if (this.ret == 0) {
                        if (this.ch == ' ') {
                            skipSpaces();
                        }
                        if (this.ch != ')') {
                            this.ret = 3;
                        } else {
                            if (this.hasExpDescription) {
                                addStringCaption(this.ch);
                            }
                            getChar();
                            this.ret = 0;
                        }
                    }
                } else {
                    if (this.ch != '[' || !this.hasCellSyntax) {
                        if (isFirstSignChar(this.ch)) {
                            this.tmpStrBuffer.setLength(0);
                            this.tmpStrBuffer.append(this.ch);
                            getChar();
                            while (true) {
                                if (!isSignChar(this.ch) && this.ch != '$') {
                                    break;
                                }
                                this.tmpStrBuffer.append(this.ch);
                                getChar();
                            }
                            this.tmpStr = this.tmpStrBuffer.toString();
                            if (!RESERVED_SIGNS.containsKey(this.tmpStr)) {
                                int saveExpI = this.expi;
                                char saveCh = this.ch;
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch == '(') {
                                    FunctionListener funcListener = getFunctionListener(this.tmpStr);
                                    if (funcListener == null) {
                                        this.ret = SY_FUNC_NO_EXIST;
                                        return;
                                    }
                                    Function func = funcListener.funcByName(this.tmpStr);
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption(String.valueOf(func.title) + '(');
                                    }
                                    CommonDatas paramValues = new CommonDatas();
                                    for (int i = 0; i < func.params.size(); i++) {
                                        paramValues.add(new CommonData());
                                    }
                                    for (int i2 = 0; i2 < func.params.size(); i2++) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch == ',' || this.ch == ')') {
                                            if (!func.params.getParam(i2).canOmit) {
                                                this.ret = SY_FUNC_BAD_PARAM;
                                                return;
                                            }
                                            paramValues.getItem(i2).type = func.params.getParam(i2).type;
                                            paramValues.getItem(i2).isNull = true;
                                            paramValues.getItem(i2).initNullValue();
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan(paramValues.getItem(i2));
                                            }
                                        } else {
                                            multorFuncParam(func.params.getParam(i2), leftOpData);
                                            if (this.ret != 0) {
                                                return;
                                            } else {
                                                paramValues.getItem(i2).assign(leftOpData);
                                            }
                                        }
                                        if (i2 < func.params.size() - 1) {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch == ',') {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(',');
                                                }
                                            }
                                        }
                                    }
                                    if (func.isInfiniteParam && func.params.size() > 0) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        while (this.ch == ',') {
                                            getChar();
                                            if (this.hasExpDescription) {
                                                addStringCaption(',');
                                            }
                                            multorFuncParam(func.params.getParam(func.params.size() - 1), leftOpData);
                                            if (this.ret != 0) {
                                                return;
                                            }
                                            paramValues.add(new CommonData());
                                            paramValues.getItem(paramValues.size() - 1).assign(leftOpData);
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                        }
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ')') {
                                        this.ret = 3;
                                        return;
                                    }
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption(')');
                                    }
                                    if (func.isInfiniteParam && this.hasMakeNiporlan) {
                                        this.tempSyData.type = 1;
                                        this.tempSyData.isNull = false;
                                        this.tempSyData.cdInt = paramValues.size();
                                        writeNiporlan((CommonData) this.tempSyData);
                                    }
                                    if (this.hasMakeNiporlan) {
                                        writeNiporlan(func.name);
                                    }
                                    syData.type = func.resultType;
                                    syData.isNull = false;
                                    syData.initValue();
                                    this.ret = funcListener.callFunction(func.name, paramValues, syData, this.isCheckMode || !this.canAssignValue);
                                    return;
                                }
                                this.expi = saveExpI;
                                this.ch = saveCh;
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch == '[' && this.hasCellSyntax) {
                                    this.expi = saveExpI - this.tmpStr.length();
                                    this.ch = this.tmpStr.charAt(0);
                                    parseCellExp(syData);
                                    if (this.ret != 0) {
                                        return;
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != '&') {
                                        if (this.hasExpDescription) {
                                            addCellCaption(syData.cdCell);
                                        }
                                        if (this.hasExpVision) {
                                            addCellVision(syData.cdCell);
                                        }
                                        if (this.hasMakeNiporlan) {
                                            writeNiporlan(syData.cdCell);
                                        }
                                        this.ret = 0;
                                        return;
                                    }
                                    getChar();
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    parseCellExp(leftOpData);
                                    if (this.ret != 0) {
                                        this.ret = SY_CPLUS_BAD_USE;
                                        return;
                                    }
                                    if (syData.cdCell.isZB || leftOpData.cdCell.isZB) {
                                        this.ret = SY_CPLUS_BAD_USE;
                                        return;
                                    }
                                    if (this.hasExpDescription) {
                                        addStringCaption(String.valueOf(syData.cdCell.toString()) + '&' + leftOpData.cdCell.toString());
                                    }
                                    if (this.hasMakeNiporlan) {
                                        this.tempSyData.assign(syData);
                                        for (int r = syData.cdCell.row; r <= leftOpData.cdCell.row; r++) {
                                            for (int c = syData.cdCell.col; c <= leftOpData.cdCell.col; c++) {
                                                this.tempSyData.cdCell.row = r;
                                                this.tempSyData.cdCell.col = c;
                                                this.ret = getCellData(this.tempSyData.cdCell, this.tempSyData.value);
                                                if (this.ret != 0) {
                                                    return;
                                                }
                                                writeNiporlan(this.tempSyData.cdCell);
                                                if (r != syData.cdCell.row || c != syData.cdCell.col) {
                                                    writeNiporlan(1);
                                                }
                                            }
                                        }
                                    }
                                    checkOpType(syData, leftOpData, 6);
                                    if (this.ret != 0) {
                                        this.ret = SY_CPLUS_BAD_USE;
                                        return;
                                    } else {
                                        this.ret = 0;
                                        return;
                                    }
                                }
                            } else if (this.tmpStr.equals("L$")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("L$(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    if (leftOpData.type != 1) {
                                                        this.ret = 15;
                                                    } else {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch != ')') {
                                                            this.ret = 3;
                                                        } else {
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(")");
                                                            }
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan("L$");
                                                            }
                                                            getChar();
                                                            syData.cdString = asciiCopy(syData.cdString, 1, leftOpData.cdInt);
                                                            this.ret = 0;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("M$")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("M$(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    if (leftOpData.type != 1) {
                                                        this.ret = 15;
                                                    } else {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch != ',') {
                                                            this.ret = 14;
                                                        } else {
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(",");
                                                            }
                                                            getChar();
                                                            wholeExp(rightOpData);
                                                            if (this.ret == 0) {
                                                                if (rightOpData.type != 1) {
                                                                    this.ret = 15;
                                                                } else {
                                                                    if (this.ch == ' ') {
                                                                        skipSpaces();
                                                                    }
                                                                    if (this.ch != ')') {
                                                                        this.ret = 3;
                                                                    } else {
                                                                        getChar();
                                                                        if (this.hasExpDescription) {
                                                                            addStringCaption(")");
                                                                        }
                                                                        if (this.hasMakeNiporlan) {
                                                                            writeNiporlan("M$");
                                                                        }
                                                                        syData.cdString = asciiCopy(syData.cdString, leftOpData.cdInt, rightOpData.cdInt);
                                                                        this.ret = 0;
                                                                    }
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("R$")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("R$(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    if (leftOpData.type != 1) {
                                                        this.ret = 15;
                                                    } else {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch != ')') {
                                                            this.ret = 3;
                                                        } else {
                                                            getChar();
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(")");
                                                            }
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan("R$");
                                                            }
                                                            if ((asciiLength(syData.cdString) + 1) - leftOpData.cdInt >= 1) {
                                                                syData.cdString = asciiCopy(syData.cdString, (asciiLength(syData.cdString) + 1) - leftOpData.cdInt, leftOpData.cdInt);
                                                            } else {
                                                                syData.cdString = syData.cdString;
                                                            }
                                                            this.ret = 0;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("POS")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("字符位置(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret == 0 && syData.type == 3) {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    this.tempSyData.type = 3;
                                                    this.tempSyData.cdString = "";
                                                    checkOpType(leftOpData, this.tempSyData, 1);
                                                    if (this.ret == 0 && leftOpData.type == 3) {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch != ')') {
                                                            this.ret = 3;
                                                        } else {
                                                            getChar();
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(")");
                                                            }
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan("POS");
                                                            }
                                                            syData.type = 1;
                                                            syData.cdInt = asciiPos(syData.cdString, leftOpData.cdString);
                                                            this.ret = 0;
                                                        }
                                                    } else {
                                                        this.ret = 17;
                                                    }
                                                }
                                            }
                                        } else {
                                            this.ret = 17;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("T") || this.tmpStr.equals("TRUE")) {
                                if (this.hasExpDescription) {
                                    addStringCaption("真");
                                }
                                syData.type = 5;
                                syData.cdBool = true;
                                syData.isNull = false;
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan((CommonData) syData);
                                }
                                this.ret = 0;
                            } else if (this.tmpStr.equals("F") || this.tmpStr.equals("FALSE")) {
                                if (this.hasExpDescription) {
                                    addStringCaption("假");
                                }
                                syData.type = 5;
                                syData.cdBool = false;
                                syData.isNull = false;
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan((CommonData) syData);
                                }
                                this.ret = 0;
                            } else if (this.tmpStr.equals(OP_NOT_NAME)) {
                                if (this.hasExpDescription) {
                                    addStringCaption("非 ");
                                }
                                mainItem(syData);
                                if (this.ret == 0) {
                                    if (syData.type != 5) {
                                        this.ret = SY_TYPE_NO_MATCH;
                                    } else {
                                        if (this.hasMakeNiporlan) {
                                            writeNiporlan(16);
                                        }
                                        syData.cdBool = !syData.cdBool;
                                        this.ret = 0;
                                    }
                                }
                            } else if (this.tmpStr.equals("ABS")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption("绝对值(");
                                    }
                                    getChar();
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        }
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption(")");
                                        }
                                        leftOpData.type = 1;
                                        leftOpData.cdInt = 1;
                                        checkOpType(syData, leftOpData, 4);
                                        if (this.ret == 0) {
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("ABS");
                                            }
                                            switch (syData.type) {
                                                case 1:
                                                    syData.cdInt = Math.abs(syData.cdInt);
                                                    break;
                                                case 2:
                                                    syData.cdReal = Math.abs(syData.cdReal);
                                                    break;
                                            }
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("INT")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption("取整(");
                                    }
                                    getChar();
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        }
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption(")");
                                        }
                                        leftOpData.type = 1;
                                        leftOpData.cdInt = 1;
                                        checkOpType(syData, leftOpData, 4);
                                        if (this.ret == 0) {
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("INT");
                                            }
                                            switch (syData.type) {
                                                case 1:
                                                    syData.cdInt = syData.cdInt;
                                                    break;
                                                case 2:
                                                    syData.cdReal = trunc(syData.cdReal);
                                                    break;
                                            }
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("ROUND")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption("四舍五入取整(");
                                    }
                                    getChar();
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 1;
                                        this.tempSyData.cdInt = 1;
                                        this.tempSyData.isNull = false;
                                        checkOpType(syData, this.tempSyData, 4);
                                        if (this.ret == 0) {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch == ',') {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                if (this.ch == ' ') {
                                                    skipSpaces();
                                                }
                                                multor(leftOpData);
                                                if (this.ret == 0) {
                                                    if (leftOpData.type != 1) {
                                                        this.ret = 15;
                                                    }
                                                }
                                            } else {
                                                leftOpData.type = 1;
                                                leftOpData.cdInt = 0;
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan((CommonData) leftOpData);
                                                }
                                            }
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            }
                                            getChar();
                                            if (this.hasExpDescription) {
                                                addStringCaption(")");
                                            }
                                            if (this.ret == 0) {
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("ROUND");
                                                }
                                                switch (syData.type) {
                                                    case 1:
                                                        syData.cdInt = (int) Math.round(roundFloat(syData.cdInt, leftOpData.cdInt));
                                                        break;
                                                    case 2:
                                                        syData.cdReal = roundFloat(syData.cdReal, leftOpData.cdInt);
                                                        break;
                                                }
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("MOD")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("取模(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 1;
                                        this.tempSyData.cdInt = 1;
                                        this.tempSyData.isNull = false;
                                        checkOpType(syData, this.tempSyData, 4);
                                        if (this.ret == 0) {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    this.tempSyData.type = 1;
                                                    this.tempSyData.cdInt = 1;
                                                    checkOpType(leftOpData, this.tempSyData, 4);
                                                    if (this.ret == 0) {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch != ')') {
                                                            this.ret = 3;
                                                        } else {
                                                            getChar();
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(")");
                                                            }
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan("MOD");
                                                            }
                                                            if (syData.type == 1) {
                                                                syData.type = 2;
                                                                syData.cdReal = syData.cdInt;
                                                            }
                                                            if (leftOpData.type == 1) {
                                                                leftOpData.type = 2;
                                                                leftOpData.cdReal = leftOpData.cdInt;
                                                            }
                                                            syData.cdReal = floatMod(syData.cdReal, leftOpData.cdReal);
                                                            this.ret = 0;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("POWER")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("乘方(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 1;
                                        this.tempSyData.cdInt = 1;
                                        checkOpType(syData, this.tempSyData, 4);
                                        if (this.ret == 0) {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    this.tempSyData.type = 1;
                                                    this.tempSyData.cdInt = 1;
                                                    checkOpType(leftOpData, this.tempSyData, 4);
                                                    if (this.ret == 0) {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch != ')') {
                                                            this.ret = 3;
                                                        } else {
                                                            getChar();
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(")");
                                                            }
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan("POWER");
                                                            }
                                                            if (syData.type == 1) {
                                                                syData.type = 2;
                                                                syData.cdReal = syData.cdInt;
                                                            }
                                                            if (leftOpData.type == 1) {
                                                                leftOpData.type = 2;
                                                                leftOpData.cdReal = leftOpData.cdInt;
                                                            }
                                                            if (syData.cdReal >= 0.0d || Math.abs(leftOpData.cdReal - trunc(leftOpData.cdReal)) <= 1.0E-5d) {
                                                                syData.cdReal = Math.pow(syData.cdReal, leftOpData.cdReal);
                                                            } else {
                                                                syData.cdReal = 1.0d;
                                                            }
                                                            this.ret = 0;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("TAN")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption("正切值(");
                                    }
                                    getChar();
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        }
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption(")");
                                        }
                                        leftOpData.type = 1;
                                        leftOpData.cdInt = 1;
                                        checkOpType(syData, leftOpData, 4);
                                        if (this.ret == 0) {
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("TAN");
                                            }
                                            switch (syData.type) {
                                                case 1:
                                                    syData.cdReal = Math.tan(syData.cdInt);
                                                    break;
                                                case 2:
                                                    syData.cdReal = Math.tan(syData.cdReal);
                                                    break;
                                            }
                                            syData.type = 2;
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("ATAN")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption("反正切值(");
                                    }
                                    getChar();
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        }
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption(")");
                                        }
                                        leftOpData.type = 1;
                                        leftOpData.cdInt = 1;
                                        checkOpType(syData, leftOpData, 4);
                                        if (this.ret == 0) {
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("ATAN");
                                            }
                                            switch (syData.type) {
                                                case 1:
                                                    syData.cdReal = Math.atan(syData.cdInt);
                                                    break;
                                                case 2:
                                                    syData.cdReal = Math.atan(syData.cdReal);
                                                    break;
                                            }
                                            syData.type = 2;
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("LN")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption("自然对数(");
                                    }
                                    getChar();
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        }
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption(")");
                                        }
                                        leftOpData.type = 1;
                                        leftOpData.cdInt = 1;
                                        checkOpType(syData, leftOpData, 4);
                                        if (this.ret == 0) {
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("LN");
                                            }
                                            switch (syData.type) {
                                                case 1:
                                                    syData.cdReal = Math.log(syData.cdInt);
                                                    break;
                                                case 2:
                                                    syData.cdReal = Math.log(syData.cdReal);
                                                    break;
                                            }
                                            syData.type = 2;
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("LOG10")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption("10为底的对数(");
                                    }
                                    getChar();
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        }
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption(")");
                                        }
                                        leftOpData.type = 1;
                                        leftOpData.cdInt = 1;
                                        checkOpType(syData, leftOpData, 4);
                                        if (this.ret == 0) {
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("LOG10");
                                            }
                                            switch (syData.type) {
                                                case 1:
                                                    syData.cdReal = Math.log(syData.cdInt) / Math.log(10.0d);
                                                    break;
                                                case 2:
                                                    syData.cdReal = Math.log(syData.cdReal) / Math.log(10.0d);
                                                    break;
                                            }
                                            syData.type = 2;
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("LOG")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("对数(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 1;
                                        this.tempSyData.cdInt = 1;
                                        checkOpType(syData, this.tempSyData, 4);
                                        if (this.ret == 0) {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    this.tempSyData.type = 1;
                                                    this.tempSyData.cdInt = 1;
                                                    checkOpType(leftOpData, this.tempSyData, 4);
                                                    if (this.ret == 0) {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch != ')') {
                                                            this.ret = 3;
                                                        } else {
                                                            getChar();
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(")");
                                                            }
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan("LOG");
                                                            }
                                                            if (syData.type == 1) {
                                                                syData.type = 2;
                                                                syData.cdReal = syData.cdInt;
                                                            }
                                                            if (leftOpData.type == 1) {
                                                                leftOpData.type = 2;
                                                                leftOpData.cdReal = leftOpData.cdInt;
                                                            }
                                                            syData.cdReal = Math.log(syData.cdReal) / Math.log(leftOpData.cdReal);
                                                            this.ret = 0;
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("VAL")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("求值(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("VAL");
                                                }
                                                syData.type = 2;
                                                syData.cdReal = safeStrToFloat(syData.cdString);
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("STR")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("转字符(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (syData.type == 9) {
                                            this.ret = getCellData(syData.cdCell, syData.value);
                                            if (this.ret == 0) {
                                                syData.assign(syData.value);
                                                syData.initNullValue();
                                            }
                                        }
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ',') {
                                            this.tempSyData.type = 1;
                                            this.tempSyData.cdInt = 0;
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan((CommonData) this.tempSyData);
                                            }
                                            this.tmpInt = 0;
                                            this.tempSyData.type = 5;
                                            this.tempSyData.cdBool = false;
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan((CommonData) this.tempSyData);
                                            }
                                            leftOpData.cdBool = false;
                                        } else if (syData.type == 1 || syData.type == 2) {
                                            getChar();
                                            if (this.hasExpDescription) {
                                                addStringCaption(",");
                                            }
                                            wholeExp(leftOpData);
                                            if (this.ret == 0) {
                                                this.tempSyData.type = 1;
                                                this.tempSyData.cdInt = 1;
                                                checkOpType(leftOpData, this.tempSyData, 4);
                                                if (this.ret != 0) {
                                                    this.ret = 15;
                                                } else if (leftOpData.type == 1 || leftOpData.type == 2) {
                                                    if (leftOpData.type == 2) {
                                                        this.tmpInt = (int) leftOpData.cdReal;
                                                    } else {
                                                        this.tmpInt = leftOpData.cdInt;
                                                    }
                                                    if (this.ch == ' ') {
                                                        skipSpaces();
                                                    }
                                                    if (this.ch == ',') {
                                                        getChar();
                                                        if (this.hasExpDescription) {
                                                            addStringCaption(",");
                                                        }
                                                        wholeExp(leftOpData);
                                                        if (this.ret == 0) {
                                                            if (leftOpData.type != 5) {
                                                                this.ret = 19;
                                                            }
                                                        }
                                                    } else {
                                                        this.tempSyData.type = 5;
                                                        this.tempSyData.cdBool = false;
                                                        if (this.hasMakeNiporlan) {
                                                            writeNiporlan((CommonData) this.tempSyData);
                                                        }
                                                        leftOpData.cdBool = false;
                                                    }
                                                } else {
                                                    this.ret = 15;
                                                }
                                            }
                                        } else {
                                            this.ret = 3;
                                        }
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        } else {
                                            getChar();
                                            if (this.hasExpDescription) {
                                                addStringCaption(")");
                                            }
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("STR");
                                            }
                                            if (syData.type == 1) {
                                                syData.type = 3;
                                                syData.cdString = FloatToStr(syData.cdInt, this.tmpInt, leftOpData.cdBool);
                                            } else if (syData.type == 2) {
                                                syData.type = 3;
                                                syData.cdString = FloatToStr(syData.cdReal, this.tmpInt, leftOpData.cdBool);
                                            } else {
                                                syData.cdString = syData.toString();
                                                syData.type = 3;
                                            }
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("IDC")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("校验位(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("IDC");
                                                }
                                                syData.cdString = String.valueOf(idc(syData.cdString));
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("ISDIGIT")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("是数字(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("ISDIGIT");
                                                }
                                                syData.type = 5;
                                                syData.cdBool = isDigit(syData.cdString);
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("LEN")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("长度(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("LEN");
                                                }
                                                syData.type = 1;
                                                syData.cdInt = asciiLength(syData.cdString);
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("ISNULL")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("是空值(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        if (syData.type == 9) {
                                            this.ret = getCellData(syData.cdCell, syData.value);
                                            if (this.ret == 0) {
                                                syData.assign(syData.value);
                                            }
                                        }
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                        } else {
                                            getChar();
                                            if (this.hasExpDescription) {
                                                addStringCaption(")");
                                            }
                                            if (this.hasMakeNiporlan) {
                                                writeNiporlan("ISNULL");
                                            }
                                            syData.type = 5;
                                            syData.cdBool = syData.isNull;
                                            this.ret = 0;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("EXISTCHINESE")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("有中文(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("EXISTCHINESE");
                                                }
                                                syData.type = 5;
                                                syData.cdBool = existChinese(syData.cdString);
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("INLIST")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("在列表中(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ',') {
                                                this.ret = 14;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                if (this.ch == ' ') {
                                                    skipSpaces();
                                                }
                                                if (isFirstSignChar(this.ch)) {
                                                    this.tmpStrBuffer.setLength(0);
                                                    this.tmpStrBuffer.append(this.ch);
                                                    getChar();
                                                    while (isSignChar(this.ch)) {
                                                        this.tmpStrBuffer.append(this.ch);
                                                        getChar();
                                                    }
                                                    this.tmpStr = this.tmpStrBuffer.toString();
                                                    if (this.hasExpDescription) {
                                                        addStringCaption(this.tmpStr);
                                                    }
                                                    this.tempSyData.type = 3;
                                                    this.tempSyData.cdString = this.tmpStr;
                                                    if (this.hasMakeNiporlan) {
                                                        writeNiporlan((CommonData) this.tempSyData);
                                                    }
                                                    DictMeaningEvent event = new DictMeaningEvent(this);
                                                    event.code = syData.cdString;
                                                    event.dictName = this.tmpStr;
                                                    event.meaningName = "";
                                                    this.ret = getInDict(event);
                                                    if (this.ret != 0) {
                                                        return;
                                                    }
                                                    syData.type = 5;
                                                    syData.cdBool = event.inDict;
                                                    if (this.hasMakeNiporlan) {
                                                        writeNiporlan("INDICT");
                                                    }
                                                } else {
                                                    syData.type = 5;
                                                    syData.cdBool = false;
                                                    CommonData count = new CommonData();
                                                    count.type = 1;
                                                    count.cdInt = 0;
                                                    do {
                                                        if (this.ch == ',') {
                                                            getChar();
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(",");
                                                            }
                                                        }
                                                        wholeExp(leftOpData);
                                                        if (this.ret != 0) {
                                                            return;
                                                        }
                                                        if (leftOpData.type != 3) {
                                                            this.ret = 17;
                                                            return;
                                                        }
                                                        if (syData.cdString.equals(leftOpData.cdString) || (!leftOpData.cdString.equals("") && syData.cdString.indexOf(leftOpData.cdString) == 0)) {
                                                            syData.cdBool = true;
                                                        }
                                                        count.cdInt++;
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                    } while (this.ch == ',');
                                                    if (this.hasMakeNiporlan) {
                                                        writeNiporlan(count);
                                                    }
                                                    if (this.hasMakeNiporlan) {
                                                        writeNiporlan("INLIST");
                                                    }
                                                }
                                                if (this.ch == ' ') {
                                                    skipSpaces();
                                                }
                                                if (this.ch != ')') {
                                                    this.ret = 3;
                                                } else {
                                                    getChar();
                                                    if (this.hasExpDescription) {
                                                        addStringCaption(")");
                                                    }
                                                    this.ret = 0;
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("DICTVALUE") || this.tmpStr.equals("DV") || this.tmpStr.equals("GETMEANING")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("取字典值(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch == ',') {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                if (this.ch == ' ') {
                                                    skipSpaces();
                                                }
                                                this.tmpStrBuffer.setLength(0);
                                                this.tmpStrBuffer.append(this.ch);
                                                getChar();
                                                while (isSignChar(this.ch)) {
                                                    this.tmpStrBuffer.append(this.ch);
                                                    getChar();
                                                }
                                                this.tmpStr = this.tmpStrBuffer.toString();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(this.tmpStr);
                                                }
                                                this.tempSyData.type = 3;
                                                this.tempSyData.cdString = this.tmpStr;
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan((CommonData) this.tempSyData);
                                                }
                                                if (this.ch == ',') {
                                                    if (this.hasExpDescription) {
                                                        addStringCaption(",");
                                                    }
                                                    getChar();
                                                    if (this.ch == ' ') {
                                                        skipSpaces();
                                                    }
                                                    this.tmpStrBuffer.setLength(0);
                                                    this.tmpStrBuffer.append(this.ch);
                                                    getChar();
                                                    while (isSignChar(this.ch)) {
                                                        this.tmpStrBuffer.append(this.ch);
                                                        getChar();
                                                    }
                                                    this.tmpStr2 = this.tmpStrBuffer.toString();
                                                    if (this.hasExpDescription) {
                                                        addStringCaption(this.tmpStr2);
                                                    }
                                                    this.tempSyData.type = 3;
                                                    this.tempSyData.cdString = this.tmpStr2;
                                                    if (this.hasMakeNiporlan) {
                                                        writeNiporlan((CommonData) this.tempSyData);
                                                    }
                                                } else {
                                                    this.tempSyData.type = 3;
                                                    this.tempSyData.cdString = "";
                                                    if (this.hasMakeNiporlan) {
                                                        writeNiporlan((CommonData) this.tempSyData);
                                                    }
                                                }
                                                DictMeaningEvent event2 = new DictMeaningEvent(this);
                                                event2.code = syData.cdString;
                                                event2.dictName = this.tmpStr;
                                                event2.meaningName = this.tempSyData.cdString;
                                                this.ret = getDictValue(event2);
                                                if (this.ret != 0) {
                                                    return;
                                                }
                                                syData.assign(event2.meaningValue);
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("DICTVALUE");
                                                }
                                                if (this.ch == ' ') {
                                                    skipSpaces();
                                                }
                                                if (this.ch != ')') {
                                                    this.ret = 3;
                                                    return;
                                                }
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                this.ret = 0;
                                                return;
                                            }
                                            this.ret = 14;
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("STATE")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch == '(') {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("单位状态(");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ')') {
                                        wholeExp(syData);
                                        if (this.ret == 0) {
                                            this.tempSyData.type = 3;
                                            this.tempSyData.cdString = "";
                                            checkOpType(syData, this.tempSyData, 1);
                                            if (this.ret != 0) {
                                                this.ret = 17;
                                            } else if (syData.type != 3) {
                                                this.ret = 17;
                                            } else {
                                                if (this.ch == ' ') {
                                                    skipSpaces();
                                                }
                                                if (this.ch == ',') {
                                                    getChar();
                                                    if (this.hasExpDescription) {
                                                        addStringCaption(",");
                                                    }
                                                    wholeExp(leftOpData);
                                                    if (this.ret == 0) {
                                                        this.tempSyData.type = 3;
                                                        this.tempSyData.cdString = "";
                                                        checkOpType(leftOpData, this.tempSyData, 1);
                                                        if (this.ret != 0) {
                                                            this.ret = 17;
                                                        } else if (leftOpData.type != 3) {
                                                            this.ret = 17;
                                                        }
                                                    }
                                                } else {
                                                    this.tempSyData.type = 3;
                                                    this.tempSyData.cdString = "";
                                                    if (this.hasMakeNiporlan) {
                                                        writeNiporlan((CommonData) this.tempSyData);
                                                    }
                                                    leftOpData.cdString = "";
                                                }
                                            }
                                        }
                                    } else {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        this.tempSyData.isNull = false;
                                        if (this.hasMakeNiporlan) {
                                            writeNiporlan((CommonData) this.tempSyData);
                                        }
                                        if (this.hasMakeNiporlan) {
                                            writeNiporlan((CommonData) this.tempSyData);
                                        }
                                        syData.cdString = "";
                                        leftOpData.cdString = "";
                                    }
                                    UnitStateEvent event3 = new UnitStateEvent(this, syData.cdString, leftOpData.cdString);
                                    this.ret = getUnitState(event3);
                                    if (this.ret != 0) {
                                        return;
                                    }
                                    syData.isNull = false;
                                    syData.type = 1;
                                    syData.cdInt = event3.state;
                                    if (this.hasMakeNiporlan) {
                                        writeNiporlan("UNITSTATE");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ')') {
                                        this.ret = 3;
                                        return;
                                    }
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption(")");
                                    }
                                    this.ret = 0;
                                    return;
                                }
                                this.ret = 2;
                            } else if (this.tmpStr.equals("FLOATSTAT")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("浮动行统计(");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch == '\'') {
                                        FloatStatEvent event4 = new FloatStatEvent(this);
                                        getChar();
                                        this.tmpStrBuffer.setLength(0);
                                        while (this.ch != '\'' && this.ch != 0) {
                                            this.tmpStrBuffer.append(this.ch);
                                            getChar();
                                        }
                                        if (this.ch != '\'') {
                                            this.ret = SY_FUNC_BAD_PARAM;
                                            return;
                                        }
                                        event4.expression = this.tmpStrBuffer.toString();
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption("'" + event4.expression + "'");
                                        }
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch == ',') {
                                            if (this.hasExpDescription) {
                                                addStringCaption(",");
                                            }
                                            getChar();
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != '\'') {
                                                this.ret = SY_FUNC_BAD_PARAM;
                                                return;
                                            }
                                            getChar();
                                            this.tmpStrBuffer.setLength(0);
                                            while (this.ch != '\'' && this.ch != 0) {
                                                this.tmpStrBuffer.append(this.ch);
                                                getChar();
                                            }
                                            if (this.ch != '\'') {
                                                this.ret = SY_FUNC_BAD_PARAM;
                                                return;
                                            }
                                            event4.condition = this.tmpStrBuffer.toString();
                                            getChar();
                                            if (this.hasExpDescription) {
                                                addStringCaption("'" + event4.condition + "'");
                                            }
                                        } else {
                                            event4.condition = "";
                                        }
                                        if (this.ch == ',') {
                                            if (this.hasExpDescription) {
                                                addStringCaption(",");
                                            }
                                            getChar();
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            this.tmpStrBuffer.setLength(0);
                                            while (true) {
                                                if (!isLetterChar(this.ch) && !isChinaChar(this.ch)) {
                                                    break;
                                                }
                                                this.tmpStrBuffer.append(this.ch);
                                                getChar();
                                            }
                                            this.tmpStr = this.tmpStrBuffer.toString();
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (DataCell.statSignToInt(this.tmpStr) < 0) {
                                                this.ret = SY_FUNC_BAD_PARAM;
                                                return;
                                            } else {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(this.tmpStr);
                                                }
                                                event4.statMode = DataCell.statSignToInt(this.tmpStr);
                                            }
                                        } else {
                                            event4.statMode = 1;
                                        }
                                        this.ret = getFloatStat(event4);
                                        if (this.ret != 0) {
                                            return;
                                        }
                                        syData.assign(event4.value);
                                        if (this.hasMakeNiporlan) {
                                            writeNiporlan(event4);
                                        }
                                        if (this.hasMakeNiporlan) {
                                            writeNiporlan("FLOATSTAT");
                                        }
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ')') {
                                            this.ret = 3;
                                            return;
                                        }
                                        getChar();
                                        if (this.hasExpDescription) {
                                            addStringCaption(")");
                                        }
                                        this.ret = 0;
                                        return;
                                    }
                                    this.ret = SY_FUNC_BAD_PARAM;
                                }
                            } else if (this.tmpStr.equals("FLOATCOPY")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch == '(') {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("浮动行Copy(");
                                    }
                                    FloatCopyEvent event5 = new FloatCopyEvent(this);
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    getChar();
                                    this.tmpStrBuffer.setLength(0);
                                    while (this.ch != '\'' && this.ch != 0) {
                                        this.tmpStrBuffer.append(this.ch);
                                        getChar();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    event5.sourceRelaExp = this.tmpStrBuffer.toString();
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("'" + event5.sourceRelaExp + "'");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ',') {
                                        this.ret = 14;
                                        return;
                                    }
                                    if (this.hasExpDescription) {
                                        addStringCaption(",");
                                    }
                                    getChar();
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    getChar();
                                    this.tmpStrBuffer.setLength(0);
                                    while (this.ch != '\'' && this.ch != 0) {
                                        this.tmpStrBuffer.append(this.ch);
                                        getChar();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    event5.destRelaExp = this.tmpStrBuffer.toString();
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("'" + event5.destRelaExp + "'");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ',') {
                                        this.ret = 14;
                                        return;
                                    }
                                    if (this.hasExpDescription) {
                                        addStringCaption(",");
                                    }
                                    getChar();
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    getChar();
                                    this.tmpStrBuffer.setLength(0);
                                    while (this.ch != '\'' && this.ch != 0) {
                                        this.tmpStrBuffer.append(this.ch);
                                        getChar();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    event5.sourceFilter = this.tmpStrBuffer.toString();
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("'" + event5.sourceFilter + "'");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ',') {
                                        this.ret = 14;
                                        return;
                                    }
                                    if (this.hasExpDescription) {
                                        addStringCaption(",");
                                    }
                                    getChar();
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    getChar();
                                    this.tmpStrBuffer.setLength(0);
                                    while (this.ch != '\'' && this.ch != 0) {
                                        this.tmpStrBuffer.append(this.ch);
                                        getChar();
                                    }
                                    if (this.ch != '\'') {
                                        this.ret = SY_FUNC_BAD_PARAM;
                                        return;
                                    }
                                    event5.calcExps = this.tmpStrBuffer.toString();
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("'" + event5.calcExps + "'");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch == ',') {
                                        if (this.hasExpDescription) {
                                            addStringCaption(",");
                                        }
                                        getChar();
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        this.tmpStrBuffer.setLength(0);
                                        while (isSignChar(this.ch)) {
                                            this.tmpStrBuffer.append(this.ch);
                                            getChar();
                                        }
                                        this.tmpStr = this.tmpStrBuffer.toString();
                                        if (this.tmpStr.equalsIgnoreCase("false") || this.tmpStr.equalsIgnoreCase("0")) {
                                            event5.isClearData = false;
                                        } else {
                                            if (!this.tmpStr.equalsIgnoreCase("true") && !this.tmpStr.equalsIgnoreCase("1")) {
                                                this.ret = SY_FUNC_BAD_PARAM;
                                                return;
                                            }
                                            event5.isClearData = true;
                                        }
                                        if (this.hasExpDescription) {
                                            addStringCaption(this.tmpStr);
                                        }
                                    } else {
                                        event5.isClearData = false;
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch == ',') {
                                        if (this.hasExpDescription) {
                                            addStringCaption(",");
                                        }
                                        getChar();
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        this.tmpStrBuffer.setLength(0);
                                        while (isSignChar(this.ch)) {
                                            this.tmpStrBuffer.append(this.ch);
                                            getChar();
                                        }
                                        this.tmpStr = this.tmpStrBuffer.toString();
                                        if (this.tmpStr.equalsIgnoreCase("false") || this.tmpStr.equalsIgnoreCase("0")) {
                                            event5.copyType = 0;
                                        } else if (this.tmpStr.equalsIgnoreCase("true") || this.tmpStr.equalsIgnoreCase("1")) {
                                            event5.copyType = 1;
                                        } else if (this.tmpStr.equals("2")) {
                                            event5.copyType = 2;
                                        } else {
                                            int value = Integer.parseInt(this.tmpStr);
                                            if (value < 0 && value > 100) {
                                                this.ret = SY_FUNC_BAD_PARAM;
                                                return;
                                            }
                                            event5.copyType = value;
                                        }
                                        if (this.hasExpDescription) {
                                            addStringCaption(this.tmpStr);
                                        }
                                    } else {
                                        event5.copyType = 0;
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch == ',') {
                                        getChar();
                                        event5.timeOffset = getInteger();
                                    }
                                    event5.srcPeriodType = '@';
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch == ',') {
                                        if (this.hasExpDescription) {
                                            addStringCaption(",");
                                        }
                                        getChar();
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch == '\'') {
                                            getChar();
                                            this.tmpStrBuffer.setLength(0);
                                            while (this.ch != '\'' && this.ch != 0) {
                                                this.tmpStrBuffer.append(this.ch);
                                                getChar();
                                            }
                                            if (this.ch != '\'') {
                                                this.ret = SY_FUNC_BAD_PARAM;
                                                return;
                                            }
                                            event5.srcPeriodType = this.tmpStrBuffer.toString().charAt(0);
                                            getChar();
                                            if (this.hasExpDescription) {
                                                addStringCaption("'" + event5.srcPeriodType + "'");
                                            }
                                        }
                                    }
                                    event5.periodCount = -1;
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch == ',') {
                                        getChar();
                                        event5.periodCount = getInteger();
                                    }
                                    this.ret = execFloatCopy(event5);
                                    if (this.ret != 0) {
                                        return;
                                    }
                                    syData.type = 1;
                                    syData.cdInt = event5.copyRowCount;
                                    syData.isNull = false;
                                    if (this.hasMakeNiporlan) {
                                        writeNiporlan(event5);
                                    }
                                    if (this.hasMakeNiporlan) {
                                        writeNiporlan("FLOATCOPY");
                                    }
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ')') {
                                        this.ret = 3;
                                        return;
                                    }
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption(")");
                                    }
                                    this.ret = 0;
                                    return;
                                }
                                this.ret = 2;
                            } else if (this.tmpStr.equals("DATEVALUE")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("日期(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 3;
                                        this.tempSyData.cdString = "";
                                        checkOpType(syData, this.tempSyData, 1);
                                        if (this.ret != 0) {
                                            this.ret = 17;
                                        } else if (syData.type != 3) {
                                            this.ret = 17;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch == ',') {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    this.tempSyData.type = 3;
                                                    this.tempSyData.cdString = "";
                                                    checkOpType(leftOpData, this.tempSyData, 1);
                                                    if (this.ret != 0) {
                                                        this.ret = 17;
                                                    } else if (leftOpData.type != 3) {
                                                        this.ret = 17;
                                                    }
                                                }
                                            } else {
                                                this.tempSyData.type = 3;
                                                this.tempSyData.cdString = "";
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan((CommonData) this.tempSyData);
                                                }
                                                leftOpData.cdString = "";
                                            }
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("DATEVALUE");
                                                }
                                                syData.type = 6;
                                                syData.isNull = !safeStrToDate(syData.getValidcdDate(), syData.cdString, leftOpData.cdString);
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("FORMATDATE")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("格式化日期(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.getValidcdDate();
                                        this.tempSyData.type = 6;
                                        this.tempSyData.cdDate.clear();
                                        checkOpType(this.tempSyData, syData, 7);
                                        if (this.ret != 0) {
                                            this.ret = 18;
                                        } else if (syData.type != 6) {
                                            this.ret = 18;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch == ',') {
                                                if (this.hasExpDescription) {
                                                    addStringCaption(",");
                                                }
                                                getChar();
                                                wholeExp(leftOpData);
                                                if (this.ret == 0) {
                                                    this.tempSyData.type = 3;
                                                    this.tempSyData.cdString = "";
                                                    checkOpType(leftOpData, this.tempSyData, 1);
                                                    if (this.ret != 0) {
                                                        this.ret = 17;
                                                    } else if (leftOpData.type != 3) {
                                                        this.ret = 17;
                                                    }
                                                }
                                            } else {
                                                this.tempSyData.type = 3;
                                                this.tempSyData.cdString = "";
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan((CommonData) this.tempSyData);
                                                }
                                                leftOpData.cdString = "";
                                            }
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("FORMATDATE");
                                                }
                                                syData.cdString = formatDate(syData.getValidcdDate(), leftOpData.cdString);
                                                syData.type = 3;
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("DATE")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("日期(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.type = 1;
                                        this.tempSyData.cdInt = 1;
                                        checkOpType(syData, this.tempSyData, 4);
                                        if (this.ret != 0) {
                                            this.ret = 15;
                                        } else {
                                            if (syData.type == 2) {
                                                syData.type = 1;
                                                syData.cdInt = (int) trunc(syData.cdReal);
                                            }
                                            if (syData.type != 1) {
                                                this.ret = 15;
                                            } else {
                                                if (this.ch == ' ') {
                                                    skipSpaces();
                                                }
                                                if (this.ch != ',') {
                                                    this.ret = 14;
                                                } else {
                                                    if (this.hasExpDescription) {
                                                        addStringCaption(",");
                                                    }
                                                    getChar();
                                                    wholeExp(leftOpData);
                                                    if (this.ret == 0) {
                                                        this.tempSyData.type = 1;
                                                        this.tempSyData.cdInt = 1;
                                                        checkOpType(leftOpData, this.tempSyData, 4);
                                                        if (this.ret != 0) {
                                                            this.ret = 15;
                                                        } else {
                                                            if (leftOpData.type == 2) {
                                                                leftOpData.type = 1;
                                                                leftOpData.cdInt = (int) trunc(leftOpData.cdReal);
                                                            }
                                                            if (leftOpData.type != 1) {
                                                                this.ret = 15;
                                                            } else {
                                                                if (this.ch == ' ') {
                                                                    skipSpaces();
                                                                }
                                                                if (this.ch != ',') {
                                                                    this.ret = 14;
                                                                } else {
                                                                    if (this.hasExpDescription) {
                                                                        addStringCaption(",");
                                                                    }
                                                                    getChar();
                                                                    wholeExp(rightOpData);
                                                                    if (this.ret == 0) {
                                                                        this.tempSyData.type = 1;
                                                                        this.tempSyData.cdInt = 1;
                                                                        checkOpType(rightOpData, this.tempSyData, 4);
                                                                        if (this.ret != 0) {
                                                                            this.ret = 15;
                                                                        } else {
                                                                            if (rightOpData.type == 2) {
                                                                                rightOpData.type = 1;
                                                                                rightOpData.cdInt = (int) trunc(rightOpData.cdReal);
                                                                            }
                                                                            if (rightOpData.type != 1) {
                                                                                this.ret = 15;
                                                                            } else {
                                                                                if (this.ch == ' ') {
                                                                                    skipSpaces();
                                                                                }
                                                                                if (this.ch != ')') {
                                                                                    this.ret = 3;
                                                                                } else {
                                                                                    getChar();
                                                                                    if (this.hasExpDescription) {
                                                                                        addStringCaption(")");
                                                                                    }
                                                                                    if (this.hasMakeNiporlan) {
                                                                                        writeNiporlan("DATE");
                                                                                    }
                                                                                    syData.type = 6;
                                                                                    safeEncodeDate(syData.getValidcdDate(), syData.cdInt, leftOpData.cdInt, rightOpData.cdInt);
                                                                                    this.ret = 0;
                                                                                }
                                                                            }
                                                                        }
                                                                    }
                                                                }
                                                            }
                                                        }
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("YEAR")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("取年(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.getValidcdDate();
                                        this.tempSyData.type = 6;
                                        this.tempSyData.cdDate.clear();
                                        checkOpType(this.tempSyData, syData, 7);
                                        if (this.ret != 0) {
                                            this.ret = 18;
                                        } else if (syData.type != 6) {
                                            this.ret = 18;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("YEAR");
                                                }
                                                syData.type = 1;
                                                syData.cdInt = syData.getValidcdDate().get(1);
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("MONTH")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("取月(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.getValidcdDate();
                                        this.tempSyData.type = 6;
                                        this.tempSyData.cdDate.clear();
                                        checkOpType(this.tempSyData, syData, 7);
                                        if (this.ret != 0) {
                                            this.ret = 18;
                                        } else if (syData.type != 6) {
                                            this.ret = 18;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("MONTH");
                                                }
                                                syData.type = 1;
                                                syData.cdInt = syData.getValidcdDate().get(2) + 1;
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("DAY")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    getChar();
                                    if (this.hasExpDescription) {
                                        addStringCaption("取日(");
                                    }
                                    wholeExp(syData);
                                    if (this.ret == 0) {
                                        this.tempSyData.getValidcdDate();
                                        this.tempSyData.type = 6;
                                        this.tempSyData.cdDate.clear();
                                        checkOpType(this.tempSyData, syData, 7);
                                        if (this.ret != 0) {
                                            this.ret = 18;
                                        } else if (syData.type != 6) {
                                            this.ret = 18;
                                        } else {
                                            if (this.ch == ' ') {
                                                skipSpaces();
                                            }
                                            if (this.ch != ')') {
                                                this.ret = 3;
                                            } else {
                                                getChar();
                                                if (this.hasExpDescription) {
                                                    addStringCaption(")");
                                                }
                                                if (this.hasMakeNiporlan) {
                                                    writeNiporlan("DAY");
                                                }
                                                syData.type = 1;
                                                syData.cdInt = syData.getValidcdDate().get(5);
                                                this.ret = 0;
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("TODAY")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch == '(') {
                                    getChar();
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ')') {
                                        this.ret = 3;
                                    } else {
                                        getChar();
                                    }
                                }
                                if (this.hasExpDescription) {
                                    addStringCaption("今天");
                                }
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan("TODAY");
                                }
                                syData.type = 6;
                                syData.cdDate = new GregorianCalendar();
                                syData.cdDate.getTime().setTime(0L);
                                this.ret = 0;
                            } else if (this.tmpStr.equals("NULLBLOB")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch == '(') {
                                    getChar();
                                    if (this.ch == ' ') {
                                        skipSpaces();
                                    }
                                    if (this.ch != ')') {
                                        this.ret = 3;
                                    } else {
                                        getChar();
                                    }
                                }
                                if (this.hasExpDescription) {
                                    addStringCaption("空二进制");
                                }
                                syData.type = 8;
                                syData.isNull = true;
                                syData.cdObject = null;
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan((CommonData) syData);
                                }
                                this.ret = 0;
                            } else if (this.tmpStr.equals("LINKPLUS")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch != '(') {
                                    this.ret = 2;
                                } else {
                                    if (this.hasExpDescription) {
                                        addStringCaption(String.valueOf(this.tmpStr) + "(");
                                    }
                                    getChar();
                                    parseCellExp(syData);
                                    if (this.ret == 0) {
                                        if (this.hasExpDescription) {
                                            addCellCaption(syData.cdCell);
                                        }
                                        if (this.hasExpVision) {
                                            addCellVision(syData.cdCell);
                                        }
                                        if (this.hasMakeNiporlan) {
                                            writeNiporlan(syData.cdCell);
                                        }
                                        if (this.ch == ' ') {
                                            skipSpaces();
                                        }
                                        if (this.ch != ',') {
                                            this.ret = 14;
                                        } else {
                                            if (this.hasExpDescription) {
                                                addStringCaption(",");
                                            }
                                            getChar();
                                            wholeExp(leftOpData);
                                            if (this.ret == 0) {
                                                this.tempSyData.type = 1;
                                                this.tempSyData.cdInt = 1;
                                                checkOpType(leftOpData, this.tempSyData, 4);
                                                if (this.ret != 0) {
                                                    this.ret = 15;
                                                } else {
                                                    if (leftOpData.type == 2) {
                                                        leftOpData.type = 1;
                                                        leftOpData.cdInt = (int) trunc(leftOpData.cdReal);
                                                    }
                                                    if (leftOpData.type != 1) {
                                                        this.ret = 15;
                                                    } else {
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch == ',') {
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(",");
                                                            }
                                                            getChar();
                                                            wholeExp(rightOpData);
                                                            if (this.ret == 0) {
                                                                this.tempSyData.type = 1;
                                                                this.tempSyData.cdInt = 1;
                                                                checkOpType(rightOpData, this.tempSyData, 4);
                                                                if (this.ret != 0) {
                                                                    this.ret = 15;
                                                                } else {
                                                                    if (rightOpData.type == 2) {
                                                                        rightOpData.type = 1;
                                                                        rightOpData.cdInt = (int) trunc(rightOpData.cdReal);
                                                                    }
                                                                    if (rightOpData.type != 1) {
                                                                        this.ret = 15;
                                                                    }
                                                                }
                                                            }
                                                        } else {
                                                            rightOpData.type = 1;
                                                            rightOpData.cdInt = 0;
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan((CommonData) rightOpData);
                                                            }
                                                        }
                                                        if (this.ch == ' ') {
                                                            skipSpaces();
                                                        }
                                                        if (this.ch == ')') {
                                                            getChar();
                                                            if (this.hasExpDescription) {
                                                                addStringCaption(")");
                                                            }
                                                            if (this.hasMakeNiporlan) {
                                                                writeNiporlan("LINKPLUS");
                                                            }
                                                            this.ret = getLinkPlus(new LinkPlusEvent(this, syData.cdCell, leftOpData.cdInt, rightOpData.cdInt, syData.value));
                                                            if (this.ret != 0) {
                                                                return;
                                                            }
                                                            syData.assign(syData.value);
                                                            this.ret = 0;
                                                            return;
                                                        }
                                                        this.ret = 3;
                                                    }
                                                }
                                            }
                                        }
                                    }
                                }
                            } else if (this.tmpStr.equals("AUTOSUM") || this.tmpStr.equals("SUM") || this.tmpStr.equals("MAX") || this.tmpStr.equals("MIN") || this.tmpStr.equals("AVG") || this.tmpStr.equals("COUNT") || this.tmpStr.equals("FIRST") || this.tmpStr.equals("LAST")) {
                                if (this.ch == ' ') {
                                    skipSpaces();
                                }
                                if (this.ch == '(') {
                                    syData.type = 9;
                                    syData.cdCell.init();
                                    syData.cdCell.statMode = DataCell.statSignToInt(this.tmpStr);
                                    if (this.hasExpDescription) {
                                        addStringCaption(String.valueOf(this.tmpStr) + "(");
                                    }
                                    this.tmpStrBuffer.setLength(0);
                                    getChar();
                                    this.tmpInt = 0;
                                    this.tmpBool = false;
                                    int midBracket = 0;
                                    do {
                                        if (this.tmpInt <= 0 && midBracket <= 0 && !this.tmpBool && (this.ch == ')' || this.ch == ',')) {
                                            break;
                                        }
                                        this.tmpStrBuffer.append(this.ch);
                                        if (this.ch == '\"') {
                                            this.tmpBool = !this.tmpBool;
                                        }
                                        if (!this.tmpBool) {
                                            if (this.ch == '(') {
                                                this.tmpInt++;
                                            }
                                            if (this.ch == ')') {
                                                this.tmpInt--;
                                            }
                                            if (this.ch == '[') {
                                                midBracket++;
                                            }
                                            if (this.ch == ']') {
                                                midBracket--;
                                            }
                                        }
                                        getChar();
                                    } while (this.ch != 0);
                                    syData.cdCell.zbName = this.tmpStrBuffer.toString();
                                    if (this.hasExpDescription) {
                                        addStringCaption(syData.cdCell.zbName);
                                    }
                                    if (this.ch == ',') {
                                        this.tmpStrBuffer.setLength(0);
                                        getChar();
                                        this.tmpInt = 0;
                                        this.tmpBool = false;
                                        int midBracket2 = 0;
                                        do {
                                            if (this.tmpInt <= 0 && midBracket2 <= 0 && !this.tmpBool && this.ch == ')') {
                                                break;
                                            }
                                            this.tmpStrBuffer.append(this.ch);
                                            if (this.ch == '\"') {
                                                this.tmpBool = !this.tmpBool;
                                            }
                                            if (!this.tmpBool) {
                                                if (this.ch == '(') {
                                                    this.tmpInt++;
                                                }
                                                if (this.ch == ')') {
                                                    this.tmpInt--;
                                                }
                                                if (this.ch == '[') {
                                                    midBracket2++;
                                                }
                                                if (this.ch == ']') {
                                                    midBracket2--;
                                                }
                                            }
                                            getChar();
                                        } while (this.ch != 0);
                                        syData.cdCell.condition = this.tmpStrBuffer.toString();
                                        if (this.hasExpDescription) {
                                            addStringCaption(",");
                                        }
                                        if (this.hasExpDescription) {
                                            addStringCaption(syData.cdCell.condition);
                                        }
                                    }
                                    if (this.ch != ')') {
                                        this.ret = 3;
                                        return;
                                    }
                                    if (this.hasExpDescription) {
                                        addStringCaption(")");
                                    }
                                    getChar();
                                    this.ret = getStatData(syData.cdCell, syData.value);
                                    if (this.ret != 0) {
                                        return;
                                    }
                                    if (this.hasMakeNiporlan) {
                                        writeNiporlan(syData.cdCell);
                                    }
                                    syData.assign(syData.value);
                                    if (this.hasMakeNiporlan) {
                                        writeNiporlan("SUM");
                                    }
                                    this.ret = 0;
                                    return;
                                }
                                this.ret = 2;
                            }
                        }
                        this.ret = SY_INVALID_CHAR;
                        return;
                    }
                    parseCellExp(syData);
                    if (this.ret == 0) {
                        if (this.ch == ' ') {
                            skipSpaces();
                        }
                        if (this.ch == '&') {
                            getChar();
                            if (this.ch == ' ') {
                                skipSpaces();
                            }
                            parseCellExp(leftOpData);
                            if (this.ret != 0) {
                                this.ret = SY_CPLUS_BAD_USE;
                            } else if (syData.cdCell.isZB || leftOpData.cdCell.isZB) {
                                this.ret = SY_CPLUS_BAD_USE;
                            } else {
                                if (this.hasExpDescription) {
                                    addStringCaption(String.valueOf(syData.cdCell.toString()) + '&' + leftOpData.cdCell.toString());
                                }
                                if (this.hasExpVision) {
                                    addStringVision(String.valueOf(syData.cdCell.toString()) + '&' + leftOpData.cdCell.toString());
                                }
                                if (this.hasMakeNiporlan) {
                                    this.tempSyData.assign(syData);
                                    for (int r2 = syData.cdCell.row; r2 <= leftOpData.cdCell.row; r2++) {
                                        for (int c2 = syData.cdCell.col; c2 <= leftOpData.cdCell.col; c2++) {
                                            this.tempSyData.cdCell.row = r2;
                                            this.tempSyData.cdCell.col = c2;
                                            this.ret = getCellData(this.tempSyData.cdCell, this.tempSyData.value);
                                            if (this.ret != 0) {
                                                return;
                                            }
                                            writeNiporlan(this.tempSyData.cdCell);
                                            if (r2 != syData.cdCell.row || c2 != syData.cdCell.col) {
                                                writeNiporlan(1);
                                            }
                                        }
                                    }
                                }
                                checkOpType(syData, leftOpData, 6);
                                if (this.ret != 0) {
                                    this.ret = SY_CPLUS_BAD_USE;
                                } else {
                                    this.ret = 0;
                                }
                            }
                        } else {
                            if (this.hasExpDescription) {
                                addCellCaption(syData.cdCell);
                            }
                            if (this.hasExpVision) {
                                addCellVision(syData.cdCell);
                            }
                            if (this.hasMakeNiporlan) {
                                writeNiporlan(syData.cdCell);
                            }
                            this.ret = 0;
                        }
                    }
                }
            }
        } catch (NumberFormatException unused) {
            this.ret = SY_FUNC_BAD_PARAM;
        } finally {
            disposeSyntaxData(leftOpData);
            disposeSyntaxData(rightOpData);
        }
    }

    private void product(SyntaxData syData) {
        SyntaxData leftOpData = newSyntaxData();
        SyntaxData rightOpData = newSyntaxData();
        try {
            multor(leftOpData);
            if (this.ret == 0) {
                if (this.ch == ' ') {
                    skipSpaces();
                }
                while (true) {
                    if (this.ch == '*' || this.ch == '/') {
                        char saveCh = this.ch;
                        if (this.hasExpDescription) {
                            addStringCaption(this.ch);
                        }
                        getChar();
                        multor(rightOpData);
                        if (this.ret != 0) {
                            break;
                        }
                        if (saveCh == '*') {
                            checkOpType(leftOpData, rightOpData, 4);
                            if (this.hasMakeNiporlan && !this.inParseCell) {
                                writeNiporlan(4);
                            }
                        } else if (saveCh == '/') {
                            checkOpType(leftOpData, rightOpData, 5);
                            if (this.hasMakeNiporlan && !this.inParseCell) {
                                writeNiporlan(5);
                            }
                        }
                        if (this.ret != 0) {
                            break;
                        } else if (this.ch == ' ') {
                            skipSpaces();
                        }
                    } else {
                        syData.assign(leftOpData);
                        this.ret = 0;
                        return;
                    }
                }
            }
        } finally {
            disposeSyntaxData(leftOpData);
            disposeSyntaxData(rightOpData);
        }
    }

    private void subItem(SyntaxData syData) {
        SyntaxData leftOpData = newSyntaxData();
        SyntaxData rightOpData = newSyntaxData();
        try {
            int prefixsy = 0;
            if (this.ch == ' ') {
                skipSpaces();
            }
            if (this.ch == '+') {
                prefixsy = 0 + 1;
                rightOpData.type = 1;
                rightOpData.cdInt = 1;
                getChar();
                if (this.hasExpDescription) {
                    addStringCaption(OP_PLUS_NAME);
                }
            }
            if (this.ch == '-') {
                prefixsy += 2;
                rightOpData.type = 1;
                rightOpData.cdInt = -1;
                getChar();
                if (this.hasExpDescription) {
                    addStringCaption("-");
                }
            }
            if (prefixsy == 3) {
                this.ret = SY_OVELLAP_OPERATOR;
            } else {
                product(leftOpData);
                if (this.ret == 0) {
                    if (prefixsy == 2) {
                        checkOpType(leftOpData, rightOpData, 4);
                        if (this.ret == 0) {
                            if (this.hasMakeNiporlan && !this.inParseCell) {
                                writeNiporlan(3);
                            }
                        }
                    }
                    if (this.ch == ' ') {
                        skipSpaces();
                    }
                    while (true) {
                        if (this.ch == '+' || this.ch == '-') {
                            char saveCh = this.ch;
                            if (this.hasExpDescription) {
                                addStringCaption(saveCh);
                            }
                            getChar();
                            product(rightOpData);
                            if (this.ret != 0) {
                                break;
                            }
                            if (saveCh == '+') {
                                checkOpType(leftOpData, rightOpData, 1);
                                if (this.hasMakeNiporlan && !this.inParseCell) {
                                    writeNiporlan(1);
                                }
                            } else {
                                checkOpType(leftOpData, rightOpData, 2);
                                if (this.hasMakeNiporlan && !this.inParseCell) {
                                    writeNiporlan(2);
                                }
                            }
                            if (this.ret != 0) {
                                break;
                            } else if (this.ch == ' ') {
                                skipSpaces();
                            }
                        } else {
                            syData.assign(leftOpData);
                            this.ret = 0;
                            return;
                        }
                    }
                }
            }
        } finally {
            disposeSyntaxData(leftOpData);
            disposeSyntaxData(rightOpData);
        }
    }

    private void mainItem(SyntaxData syData) {
        SyntaxData leftOpData = newSyntaxData();
        SyntaxData rightOpData = newSyntaxData();
        try {
            subItem(leftOpData);
            if (this.ret == 0) {
                if (this.ch == ' ') {
                    skipSpaces();
                }
                if (isCompareChar(this.ch)) {
                    this.tmpStrBuffer.setLength(0);
                    if (isCompareChar(this.ch)) {
                        this.tmpStrBuffer.append(this.ch);
                        getChar();
                        while (isCompareChar(this.ch)) {
                            this.tmpStrBuffer.append(this.ch);
                            getChar();
                        }
                    } else {
                        this.tmpStrBuffer.append(this.ch);
                        getChar();
                        while (isSignChar(this.ch)) {
                            this.tmpStrBuffer.append(this.ch);
                            getChar();
                        }
                    }
                    this.tmpStr = this.tmpStrBuffer.toString();
                    if (this.tmpStr.equals("=") || this.tmpStr.equals(OP_EQU_CHINA_NAME)) {
                        if (this.hasExpDescription) {
                            addStringCaption("=");
                        }
                        subItem(rightOpData);
                        if (this.ret == 0) {
                            checkOpType(leftOpData, rightOpData, 7);
                            if (this.ret == 0) {
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan(7);
                                }
                            }
                        }
                    } else if (this.tmpStr.equals(OP_WEQU_NAME) || this.tmpStr.equals(OP_WEQU_CHINA_NAME)) {
                        if (this.hasExpDescription) {
                            addStringCaption(OP_WEQU_NAME);
                        }
                        subItem(rightOpData);
                        if (this.ret == 0) {
                            checkOpType(leftOpData, rightOpData, 8);
                            if (this.ret == 0) {
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan(8);
                                }
                            }
                        }
                    } else if (this.tmpStr.toString().equals(OP_NEQ_NAME) || this.tmpStr.toString().equals(OP_NEQ_CHINA_NAME)) {
                        if (this.hasExpDescription) {
                            addStringCaption(OP_NEQ_NAME);
                        }
                        subItem(rightOpData);
                        if (this.ret == 0) {
                            checkOpType(leftOpData, rightOpData, 9);
                            if (this.ret == 0) {
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan(9);
                                }
                            }
                        }
                    } else if (this.tmpStr.equals(OP_GLT_NAME) || this.tmpStr.equals(OP_GLT_CHINA_NAME)) {
                        if (this.hasExpDescription) {
                            addStringCaption(OP_GLT_NAME);
                        }
                        subItem(rightOpData);
                        if (this.ret == 0) {
                            checkOpType(leftOpData, rightOpData, 10);
                            if (this.ret == 0) {
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan(10);
                                }
                            }
                        }
                    } else if (this.tmpStr.equals(OP_BLT_NAME) || this.tmpStr.equals(OP_BLT_CHINA_NAME)) {
                        if (this.hasExpDescription) {
                            addStringCaption(OP_BLT_NAME);
                        }
                        subItem(rightOpData);
                        if (this.ret == 0) {
                            checkOpType(leftOpData, rightOpData, 11);
                            if (this.ret == 0) {
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan(11);
                                }
                            }
                        }
                    } else if (this.tmpStr.equals(OP_GLE_NAME) || this.tmpStr.equals(OP_GLE_CHINA_NAME)) {
                        if (this.hasExpDescription) {
                            addStringCaption(OP_GLE_NAME);
                        }
                        subItem(rightOpData);
                        if (this.ret == 0) {
                            checkOpType(leftOpData, rightOpData, 12);
                            if (this.ret == 0) {
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan(12);
                                }
                            }
                        }
                    } else if (this.tmpStr.equals(OP_BLE_NAME) || this.tmpStr.equals(OP_BLE_CHINA_NAME)) {
                        if (this.hasExpDescription) {
                            addStringCaption(OP_BLE_NAME);
                        }
                        subItem(rightOpData);
                        if (this.ret == 0) {
                            checkOpType(leftOpData, rightOpData, 13);
                            if (this.ret == 0) {
                                if (this.hasMakeNiporlan) {
                                    writeNiporlan(13);
                                }
                            }
                        }
                    } else {
                        this.ret = SY_INVALID_CHAR;
                        this.expi = (this.expi - this.tmpStr.length()) - 1;
                        getChar();
                    }
                }
                syData.assign(leftOpData);
                this.ret = 0;
            }
        } finally {
            disposeSyntaxData(leftOpData);
            disposeSyntaxData(rightOpData);
        }
    }

    /* JADX WARN: Code restructure failed: missing block: B:26:0x010f, code lost:
    
        r6.assign(r0);
        r5.ret = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x0135, code lost:
    
        return;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private void simpleExp(com.jiuqi.syntax.SyntaxData r6) {
        /*
            Method dump skipped, instructions count: 310
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.syntax.SyntaxParser.simpleExp(com.jiuqi.syntax.SyntaxData):void");
    }

    /* JADX WARN: Code restructure failed: missing block: B:26:0x010f, code lost:
    
        r6.assign(r0);
        r5.ret = 0;
     */
    /* JADX WARN: Code restructure failed: missing block: B:28:0x0135, code lost:
    
        return;
     */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private void wholeExp(com.jiuqi.syntax.SyntaxData r6) {
        /*
            Method dump skipped, instructions count: 310
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.syntax.SyntaxParser.wholeExp(com.jiuqi.syntax.SyntaxData):void");
    }

    /* JADX WARN: Code restructure failed: missing block: B:112:0x04d5, code lost:
    
        r5.ret = com.jiuqi.syntax.SyntaxParser.SY_OVERLAP_KIND;
     */
    /* JADX WARN: Code restructure failed: missing block: B:197:0x06b6, code lost:
    
        r5.ret = com.jiuqi.syntax.SyntaxParser.SY_OVERLAP_KIND;
     */
    /* JADX WARN: Removed duplicated region for block: B:100:0x04c1 A[Catch: all -> 0x0782, TryCatch #0 {all -> 0x0782, blocks: (B:3:0x000c, B:5:0x0022, B:6:0x0026, B:8:0x002f, B:10:0x0039, B:15:0x004b, B:16:0x008c, B:18:0x0066, B:21:0x0082, B:24:0x0096, B:26:0x00aa, B:27:0x00b8, B:29:0x00c1, B:31:0x00d9, B:32:0x00dd, B:34:0x00e7, B:35:0x0128, B:37:0x0102, B:40:0x011e, B:43:0x0132, B:45:0x0159, B:46:0x015d, B:48:0x0166, B:49:0x01f0, B:51:0x01f9, B:53:0x06e0, B:55:0x0200, B:57:0x020d, B:58:0x0211, B:268:0x021a, B:289:0x0224, B:270:0x022e, B:271:0x0255, B:273:0x025e, B:275:0x0245, B:277:0x0265, B:286:0x026e, B:279:0x0278, B:282:0x0293, B:61:0x029a, B:63:0x02a4, B:65:0x02ad, B:214:0x039e, B:215:0x03b9, B:263:0x03a9, B:217:0x03c3, B:220:0x03cd, B:222:0x03e1, B:223:0x03e5, B:256:0x03ef, B:261:0x03f9, B:258:0x0403, B:226:0x0414, B:228:0x0426, B:230:0x0430, B:232:0x0439, B:98:0x04b4, B:100:0x04c1, B:102:0x04cb, B:104:0x04df, B:105:0x06d3, B:108:0x06dc, B:112:0x04d5, B:114:0x04f2, B:116:0x0504, B:118:0x050d, B:119:0x0511, B:176:0x051a, B:121:0x0524, B:123:0x0531, B:124:0x0535, B:126:0x0546, B:127:0x055d, B:129:0x0566, B:131:0x054d, B:133:0x056d, B:145:0x0576, B:135:0x0580, B:136:0x0603, B:138:0x060d, B:139:0x061c, B:143:0x062d, B:141:0x0637, B:147:0x0587, B:149:0x0590, B:150:0x05a7, B:152:0x05b0, B:154:0x0597, B:156:0x05b7, B:160:0x05c0, B:158:0x05ca, B:162:0x05e1, B:164:0x05ea, B:166:0x05f3, B:168:0x05fc, B:170:0x05d1, B:177:0x0650, B:181:0x065c, B:185:0x0666, B:183:0x0670, B:186:0x0683, B:190:0x068d, B:188:0x0697, B:191:0x06a2, B:193:0x06ac, B:195:0x06c0, B:197:0x06b6, B:235:0x0442, B:238:0x0451, B:240:0x045b, B:241:0x0461, B:244:0x0468, B:247:0x04a0, B:253:0x047f, B:249:0x04aa, B:68:0x02b6, B:71:0x02c5, B:81:0x02d4, B:73:0x02de, B:76:0x02ef, B:83:0x02f6, B:88:0x030a, B:89:0x0310, B:210:0x0317, B:91:0x0329, B:93:0x0332, B:94:0x0336, B:96:0x0347, B:199:0x0351, B:200:0x037c, B:207:0x036c, B:202:0x0386, B:205:0x0390, B:291:0x06e9, B:293:0x06f2, B:294:0x06f6, B:296:0x06ff, B:297:0x0707, B:299:0x0714, B:300:0x0718, B:302:0x0721, B:303:0x076f, B:306:0x0175, B:308:0x0181, B:310:0x0192, B:312:0x019b, B:313:0x019f, B:315:0x01a8, B:316:0x01b1, B:318:0x01d4, B:320:0x01e5, B:321:0x01dc, B:322:0x0189, B:323:0x0730, B:325:0x0756, B:326:0x075a, B:328:0x0763, B:329:0x00b1), top: B:2:0x000c }] */
    /* JADX WARN: Removed duplicated region for block: B:107:0x06dc A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:110:0x06e0 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:114:0x04f2 A[Catch: all -> 0x0782, TryCatch #0 {all -> 0x0782, blocks: (B:3:0x000c, B:5:0x0022, B:6:0x0026, B:8:0x002f, B:10:0x0039, B:15:0x004b, B:16:0x008c, B:18:0x0066, B:21:0x0082, B:24:0x0096, B:26:0x00aa, B:27:0x00b8, B:29:0x00c1, B:31:0x00d9, B:32:0x00dd, B:34:0x00e7, B:35:0x0128, B:37:0x0102, B:40:0x011e, B:43:0x0132, B:45:0x0159, B:46:0x015d, B:48:0x0166, B:49:0x01f0, B:51:0x01f9, B:53:0x06e0, B:55:0x0200, B:57:0x020d, B:58:0x0211, B:268:0x021a, B:289:0x0224, B:270:0x022e, B:271:0x0255, B:273:0x025e, B:275:0x0245, B:277:0x0265, B:286:0x026e, B:279:0x0278, B:282:0x0293, B:61:0x029a, B:63:0x02a4, B:65:0x02ad, B:214:0x039e, B:215:0x03b9, B:263:0x03a9, B:217:0x03c3, B:220:0x03cd, B:222:0x03e1, B:223:0x03e5, B:256:0x03ef, B:261:0x03f9, B:258:0x0403, B:226:0x0414, B:228:0x0426, B:230:0x0430, B:232:0x0439, B:98:0x04b4, B:100:0x04c1, B:102:0x04cb, B:104:0x04df, B:105:0x06d3, B:108:0x06dc, B:112:0x04d5, B:114:0x04f2, B:116:0x0504, B:118:0x050d, B:119:0x0511, B:176:0x051a, B:121:0x0524, B:123:0x0531, B:124:0x0535, B:126:0x0546, B:127:0x055d, B:129:0x0566, B:131:0x054d, B:133:0x056d, B:145:0x0576, B:135:0x0580, B:136:0x0603, B:138:0x060d, B:139:0x061c, B:143:0x062d, B:141:0x0637, B:147:0x0587, B:149:0x0590, B:150:0x05a7, B:152:0x05b0, B:154:0x0597, B:156:0x05b7, B:160:0x05c0, B:158:0x05ca, B:162:0x05e1, B:164:0x05ea, B:166:0x05f3, B:168:0x05fc, B:170:0x05d1, B:177:0x0650, B:181:0x065c, B:185:0x0666, B:183:0x0670, B:186:0x0683, B:190:0x068d, B:188:0x0697, B:191:0x06a2, B:193:0x06ac, B:195:0x06c0, B:197:0x06b6, B:235:0x0442, B:238:0x0451, B:240:0x045b, B:241:0x0461, B:244:0x0468, B:247:0x04a0, B:253:0x047f, B:249:0x04aa, B:68:0x02b6, B:71:0x02c5, B:81:0x02d4, B:73:0x02de, B:76:0x02ef, B:83:0x02f6, B:88:0x030a, B:89:0x0310, B:210:0x0317, B:91:0x0329, B:93:0x0332, B:94:0x0336, B:96:0x0347, B:199:0x0351, B:200:0x037c, B:207:0x036c, B:202:0x0386, B:205:0x0390, B:291:0x06e9, B:293:0x06f2, B:294:0x06f6, B:296:0x06ff, B:297:0x0707, B:299:0x0714, B:300:0x0718, B:302:0x0721, B:303:0x076f, B:306:0x0175, B:308:0x0181, B:310:0x0192, B:312:0x019b, B:313:0x019f, B:315:0x01a8, B:316:0x01b1, B:318:0x01d4, B:320:0x01e5, B:321:0x01dc, B:322:0x0189, B:323:0x0730, B:325:0x0756, B:326:0x075a, B:328:0x0763, B:329:0x00b1), top: B:2:0x000c }] */
    /* JADX WARN: Removed duplicated region for block: B:138:0x060d A[Catch: all -> 0x0782, TryCatch #0 {all -> 0x0782, blocks: (B:3:0x000c, B:5:0x0022, B:6:0x0026, B:8:0x002f, B:10:0x0039, B:15:0x004b, B:16:0x008c, B:18:0x0066, B:21:0x0082, B:24:0x0096, B:26:0x00aa, B:27:0x00b8, B:29:0x00c1, B:31:0x00d9, B:32:0x00dd, B:34:0x00e7, B:35:0x0128, B:37:0x0102, B:40:0x011e, B:43:0x0132, B:45:0x0159, B:46:0x015d, B:48:0x0166, B:49:0x01f0, B:51:0x01f9, B:53:0x06e0, B:55:0x0200, B:57:0x020d, B:58:0x0211, B:268:0x021a, B:289:0x0224, B:270:0x022e, B:271:0x0255, B:273:0x025e, B:275:0x0245, B:277:0x0265, B:286:0x026e, B:279:0x0278, B:282:0x0293, B:61:0x029a, B:63:0x02a4, B:65:0x02ad, B:214:0x039e, B:215:0x03b9, B:263:0x03a9, B:217:0x03c3, B:220:0x03cd, B:222:0x03e1, B:223:0x03e5, B:256:0x03ef, B:261:0x03f9, B:258:0x0403, B:226:0x0414, B:228:0x0426, B:230:0x0430, B:232:0x0439, B:98:0x04b4, B:100:0x04c1, B:102:0x04cb, B:104:0x04df, B:105:0x06d3, B:108:0x06dc, B:112:0x04d5, B:114:0x04f2, B:116:0x0504, B:118:0x050d, B:119:0x0511, B:176:0x051a, B:121:0x0524, B:123:0x0531, B:124:0x0535, B:126:0x0546, B:127:0x055d, B:129:0x0566, B:131:0x054d, B:133:0x056d, B:145:0x0576, B:135:0x0580, B:136:0x0603, B:138:0x060d, B:139:0x061c, B:143:0x062d, B:141:0x0637, B:147:0x0587, B:149:0x0590, B:150:0x05a7, B:152:0x05b0, B:154:0x0597, B:156:0x05b7, B:160:0x05c0, B:158:0x05ca, B:162:0x05e1, B:164:0x05ea, B:166:0x05f3, B:168:0x05fc, B:170:0x05d1, B:177:0x0650, B:181:0x065c, B:185:0x0666, B:183:0x0670, B:186:0x0683, B:190:0x068d, B:188:0x0697, B:191:0x06a2, B:193:0x06ac, B:195:0x06c0, B:197:0x06b6, B:235:0x0442, B:238:0x0451, B:240:0x045b, B:241:0x0461, B:244:0x0468, B:247:0x04a0, B:253:0x047f, B:249:0x04aa, B:68:0x02b6, B:71:0x02c5, B:81:0x02d4, B:73:0x02de, B:76:0x02ef, B:83:0x02f6, B:88:0x030a, B:89:0x0310, B:210:0x0317, B:91:0x0329, B:93:0x0332, B:94:0x0336, B:96:0x0347, B:199:0x0351, B:200:0x037c, B:207:0x036c, B:202:0x0386, B:205:0x0390, B:291:0x06e9, B:293:0x06f2, B:294:0x06f6, B:296:0x06ff, B:297:0x0707, B:299:0x0714, B:300:0x0718, B:302:0x0721, B:303:0x076f, B:306:0x0175, B:308:0x0181, B:310:0x0192, B:312:0x019b, B:313:0x019f, B:315:0x01a8, B:316:0x01b1, B:318:0x01d4, B:320:0x01e5, B:321:0x01dc, B:322:0x0189, B:323:0x0730, B:325:0x0756, B:326:0x075a, B:328:0x0763, B:329:0x00b1), top: B:2:0x000c }] */
    /* JADX WARN: Removed duplicated region for block: B:141:0x0637 A[Catch: all -> 0x0782, TryCatch #0 {all -> 0x0782, blocks: (B:3:0x000c, B:5:0x0022, B:6:0x0026, B:8:0x002f, B:10:0x0039, B:15:0x004b, B:16:0x008c, B:18:0x0066, B:21:0x0082, B:24:0x0096, B:26:0x00aa, B:27:0x00b8, B:29:0x00c1, B:31:0x00d9, B:32:0x00dd, B:34:0x00e7, B:35:0x0128, B:37:0x0102, B:40:0x011e, B:43:0x0132, B:45:0x0159, B:46:0x015d, B:48:0x0166, B:49:0x01f0, B:51:0x01f9, B:53:0x06e0, B:55:0x0200, B:57:0x020d, B:58:0x0211, B:268:0x021a, B:289:0x0224, B:270:0x022e, B:271:0x0255, B:273:0x025e, B:275:0x0245, B:277:0x0265, B:286:0x026e, B:279:0x0278, B:282:0x0293, B:61:0x029a, B:63:0x02a4, B:65:0x02ad, B:214:0x039e, B:215:0x03b9, B:263:0x03a9, B:217:0x03c3, B:220:0x03cd, B:222:0x03e1, B:223:0x03e5, B:256:0x03ef, B:261:0x03f9, B:258:0x0403, B:226:0x0414, B:228:0x0426, B:230:0x0430, B:232:0x0439, B:98:0x04b4, B:100:0x04c1, B:102:0x04cb, B:104:0x04df, B:105:0x06d3, B:108:0x06dc, B:112:0x04d5, B:114:0x04f2, B:116:0x0504, B:118:0x050d, B:119:0x0511, B:176:0x051a, B:121:0x0524, B:123:0x0531, B:124:0x0535, B:126:0x0546, B:127:0x055d, B:129:0x0566, B:131:0x054d, B:133:0x056d, B:145:0x0576, B:135:0x0580, B:136:0x0603, B:138:0x060d, B:139:0x061c, B:143:0x062d, B:141:0x0637, B:147:0x0587, B:149:0x0590, B:150:0x05a7, B:152:0x05b0, B:154:0x0597, B:156:0x05b7, B:160:0x05c0, B:158:0x05ca, B:162:0x05e1, B:164:0x05ea, B:166:0x05f3, B:168:0x05fc, B:170:0x05d1, B:177:0x0650, B:181:0x065c, B:185:0x0666, B:183:0x0670, B:186:0x0683, B:190:0x068d, B:188:0x0697, B:191:0x06a2, B:193:0x06ac, B:195:0x06c0, B:197:0x06b6, B:235:0x0442, B:238:0x0451, B:240:0x045b, B:241:0x0461, B:244:0x0468, B:247:0x04a0, B:253:0x047f, B:249:0x04aa, B:68:0x02b6, B:71:0x02c5, B:81:0x02d4, B:73:0x02de, B:76:0x02ef, B:83:0x02f6, B:88:0x030a, B:89:0x0310, B:210:0x0317, B:91:0x0329, B:93:0x0332, B:94:0x0336, B:96:0x0347, B:199:0x0351, B:200:0x037c, B:207:0x036c, B:202:0x0386, B:205:0x0390, B:291:0x06e9, B:293:0x06f2, B:294:0x06f6, B:296:0x06ff, B:297:0x0707, B:299:0x0714, B:300:0x0718, B:302:0x0721, B:303:0x076f, B:306:0x0175, B:308:0x0181, B:310:0x0192, B:312:0x019b, B:313:0x019f, B:315:0x01a8, B:316:0x01b1, B:318:0x01d4, B:320:0x01e5, B:321:0x01dc, B:322:0x0189, B:323:0x0730, B:325:0x0756, B:326:0x075a, B:328:0x0763, B:329:0x00b1), top: B:2:0x000c }] */
    /* JADX WARN: Removed duplicated region for block: B:142:0x062d A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:290:0x06e9 A[SYNTHETIC] */
    /* JADX WARN: Removed duplicated region for block: B:51:0x01f9 A[Catch: all -> 0x0782, TryCatch #0 {all -> 0x0782, blocks: (B:3:0x000c, B:5:0x0022, B:6:0x0026, B:8:0x002f, B:10:0x0039, B:15:0x004b, B:16:0x008c, B:18:0x0066, B:21:0x0082, B:24:0x0096, B:26:0x00aa, B:27:0x00b8, B:29:0x00c1, B:31:0x00d9, B:32:0x00dd, B:34:0x00e7, B:35:0x0128, B:37:0x0102, B:40:0x011e, B:43:0x0132, B:45:0x0159, B:46:0x015d, B:48:0x0166, B:49:0x01f0, B:51:0x01f9, B:53:0x06e0, B:55:0x0200, B:57:0x020d, B:58:0x0211, B:268:0x021a, B:289:0x0224, B:270:0x022e, B:271:0x0255, B:273:0x025e, B:275:0x0245, B:277:0x0265, B:286:0x026e, B:279:0x0278, B:282:0x0293, B:61:0x029a, B:63:0x02a4, B:65:0x02ad, B:214:0x039e, B:215:0x03b9, B:263:0x03a9, B:217:0x03c3, B:220:0x03cd, B:222:0x03e1, B:223:0x03e5, B:256:0x03ef, B:261:0x03f9, B:258:0x0403, B:226:0x0414, B:228:0x0426, B:230:0x0430, B:232:0x0439, B:98:0x04b4, B:100:0x04c1, B:102:0x04cb, B:104:0x04df, B:105:0x06d3, B:108:0x06dc, B:112:0x04d5, B:114:0x04f2, B:116:0x0504, B:118:0x050d, B:119:0x0511, B:176:0x051a, B:121:0x0524, B:123:0x0531, B:124:0x0535, B:126:0x0546, B:127:0x055d, B:129:0x0566, B:131:0x054d, B:133:0x056d, B:145:0x0576, B:135:0x0580, B:136:0x0603, B:138:0x060d, B:139:0x061c, B:143:0x062d, B:141:0x0637, B:147:0x0587, B:149:0x0590, B:150:0x05a7, B:152:0x05b0, B:154:0x0597, B:156:0x05b7, B:160:0x05c0, B:158:0x05ca, B:162:0x05e1, B:164:0x05ea, B:166:0x05f3, B:168:0x05fc, B:170:0x05d1, B:177:0x0650, B:181:0x065c, B:185:0x0666, B:183:0x0670, B:186:0x0683, B:190:0x068d, B:188:0x0697, B:191:0x06a2, B:193:0x06ac, B:195:0x06c0, B:197:0x06b6, B:235:0x0442, B:238:0x0451, B:240:0x045b, B:241:0x0461, B:244:0x0468, B:247:0x04a0, B:253:0x047f, B:249:0x04aa, B:68:0x02b6, B:71:0x02c5, B:81:0x02d4, B:73:0x02de, B:76:0x02ef, B:83:0x02f6, B:88:0x030a, B:89:0x0310, B:210:0x0317, B:91:0x0329, B:93:0x0332, B:94:0x0336, B:96:0x0347, B:199:0x0351, B:200:0x037c, B:207:0x036c, B:202:0x0386, B:205:0x0390, B:291:0x06e9, B:293:0x06f2, B:294:0x06f6, B:296:0x06ff, B:297:0x0707, B:299:0x0714, B:300:0x0718, B:302:0x0721, B:303:0x076f, B:306:0x0175, B:308:0x0181, B:310:0x0192, B:312:0x019b, B:313:0x019f, B:315:0x01a8, B:316:0x01b1, B:318:0x01d4, B:320:0x01e5, B:321:0x01dc, B:322:0x0189, B:323:0x0730, B:325:0x0756, B:326:0x075a, B:328:0x0763, B:329:0x00b1), top: B:2:0x000c }] */
    /* JADX WARN: Removed duplicated region for block: B:55:0x0200 A[Catch: all -> 0x0782, TryCatch #0 {all -> 0x0782, blocks: (B:3:0x000c, B:5:0x0022, B:6:0x0026, B:8:0x002f, B:10:0x0039, B:15:0x004b, B:16:0x008c, B:18:0x0066, B:21:0x0082, B:24:0x0096, B:26:0x00aa, B:27:0x00b8, B:29:0x00c1, B:31:0x00d9, B:32:0x00dd, B:34:0x00e7, B:35:0x0128, B:37:0x0102, B:40:0x011e, B:43:0x0132, B:45:0x0159, B:46:0x015d, B:48:0x0166, B:49:0x01f0, B:51:0x01f9, B:53:0x06e0, B:55:0x0200, B:57:0x020d, B:58:0x0211, B:268:0x021a, B:289:0x0224, B:270:0x022e, B:271:0x0255, B:273:0x025e, B:275:0x0245, B:277:0x0265, B:286:0x026e, B:279:0x0278, B:282:0x0293, B:61:0x029a, B:63:0x02a4, B:65:0x02ad, B:214:0x039e, B:215:0x03b9, B:263:0x03a9, B:217:0x03c3, B:220:0x03cd, B:222:0x03e1, B:223:0x03e5, B:256:0x03ef, B:261:0x03f9, B:258:0x0403, B:226:0x0414, B:228:0x0426, B:230:0x0430, B:232:0x0439, B:98:0x04b4, B:100:0x04c1, B:102:0x04cb, B:104:0x04df, B:105:0x06d3, B:108:0x06dc, B:112:0x04d5, B:114:0x04f2, B:116:0x0504, B:118:0x050d, B:119:0x0511, B:176:0x051a, B:121:0x0524, B:123:0x0531, B:124:0x0535, B:126:0x0546, B:127:0x055d, B:129:0x0566, B:131:0x054d, B:133:0x056d, B:145:0x0576, B:135:0x0580, B:136:0x0603, B:138:0x060d, B:139:0x061c, B:143:0x062d, B:141:0x0637, B:147:0x0587, B:149:0x0590, B:150:0x05a7, B:152:0x05b0, B:154:0x0597, B:156:0x05b7, B:160:0x05c0, B:158:0x05ca, B:162:0x05e1, B:164:0x05ea, B:166:0x05f3, B:168:0x05fc, B:170:0x05d1, B:177:0x0650, B:181:0x065c, B:185:0x0666, B:183:0x0670, B:186:0x0683, B:190:0x068d, B:188:0x0697, B:191:0x06a2, B:193:0x06ac, B:195:0x06c0, B:197:0x06b6, B:235:0x0442, B:238:0x0451, B:240:0x045b, B:241:0x0461, B:244:0x0468, B:247:0x04a0, B:253:0x047f, B:249:0x04aa, B:68:0x02b6, B:71:0x02c5, B:81:0x02d4, B:73:0x02de, B:76:0x02ef, B:83:0x02f6, B:88:0x030a, B:89:0x0310, B:210:0x0317, B:91:0x0329, B:93:0x0332, B:94:0x0336, B:96:0x0347, B:199:0x0351, B:200:0x037c, B:207:0x036c, B:202:0x0386, B:205:0x0390, B:291:0x06e9, B:293:0x06f2, B:294:0x06f6, B:296:0x06ff, B:297:0x0707, B:299:0x0714, B:300:0x0718, B:302:0x0721, B:303:0x076f, B:306:0x0175, B:308:0x0181, B:310:0x0192, B:312:0x019b, B:313:0x019f, B:315:0x01a8, B:316:0x01b1, B:318:0x01d4, B:320:0x01e5, B:321:0x01dc, B:322:0x0189, B:323:0x0730, B:325:0x0756, B:326:0x075a, B:328:0x0763, B:329:0x00b1), top: B:2:0x000c }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private void parseCellExp(com.jiuqi.syntax.SyntaxData r6) {
        /*
            Method dump skipped, instructions count: 1948
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.syntax.SyntaxParser.parseCellExp(com.jiuqi.syntax.SyntaxData):void");
    }

    private void expSubCheck(SyntaxData syData, SyntaxData leftOpData) {
        this.expi = 0;
        getChar();
        if (this.estimateType == 1) {
            if (this.ch == ' ') {
                skipSpaces();
            }
            this.tmpStrBuffer.setLength(0);
            while (isLetterChar(this.ch)) {
                this.tmpStrBuffer.append(this.ch);
                getChar();
            }
            this.tmpStr = this.tmpStrBuffer.toString();
            if (this.tmpStr.equalsIgnoreCase("CALL")) {
                wholeExp(syData);
                if (this.ret == 0 && this.ch != 0) {
                    this.ret = SY_EXIST_SPARE_CHAR;
                    return;
                }
                return;
            }
            this.expi = 0;
            getChar();
            parseCellExp(syData);
            if (this.ret != 0) {
                return;
            }
            if (this.ch == ' ') {
                skipSpaces();
            }
            if (this.ch != '=') {
                this.ret = 13;
                return;
            }
            if (this.hasMakeNiporlan) {
                writeNiporlan(syData.cdCell);
            }
            getChar();
            wholeExp(leftOpData);
            if (this.ret != 0) {
                return;
            }
            checkOpType(syData, leftOpData, 17);
            if (this.ret != 0) {
                return;
            }
            if (this.hasMakeNiporlan) {
                writeNiporlan(17);
            }
            if (this.ch != 0) {
                this.ret = SY_EXIST_SPARE_CHAR;
                return;
            }
            return;
        }
        wholeExp(syData);
        if (this.ret != 0) {
            return;
        }
        if (this.ch != 0) {
            this.ret = SY_EXIST_SPARE_CHAR;
            return;
        }
        if (this.estimateType == 0) {
            if (syData.type != 5) {
                this.ret = 19;
                return;
            }
            if (this.hasExpVisionBanlance) {
                List splitList = new ArrayList();
                splitExp(this.expStr, splitList);
                for (int i = 0; i < splitList.size(); i++) {
                    String exptemp = (String) splitList.get(i);
                    this.tmpStr = makeLeftExp(exptemp);
                    if (!this.tmpStr.equals("")) {
                        addStringVision(String.valueOf(this.tmpStr) + "//左");
                    }
                    this.tmpStr = makeRightExp(exptemp);
                    if (!this.tmpStr.equals("")) {
                        addStringVision(String.valueOf(this.tmpStr) + "//右");
                    }
                    this.tmpStr = makeBanlanceExp(exptemp);
                    if (!this.tmpStr.equals("")) {
                        addStringVision(String.valueOf(this.tmpStr) + "//差额");
                    }
                }
                return;
            }
            return;
        }
        switch (syData.type) {
            case 9:
                syData.assign(syData.value);
                return;
            default:
                return;
        }
    }

    /* JADX WARN: Removed duplicated region for block: B:35:0x0191 A[Catch: all -> 0x0459, TryCatch #2 {all -> 0x0459, blocks: (B:16:0x0078, B:18:0x0084, B:20:0x0098, B:25:0x00a9, B:27:0x00c6, B:28:0x00cf, B:30:0x00e3, B:32:0x0101, B:33:0x015c, B:35:0x0191, B:36:0x01ab, B:38:0x01b9, B:41:0x01c1, B:43:0x01c7, B:44:0x01d8, B:46:0x01df, B:47:0x01e8, B:49:0x01f0, B:50:0x0211, B:52:0x0218, B:53:0x0226, B:55:0x0242, B:56:0x025f, B:59:0x0278, B:61:0x0281, B:64:0x0289, B:66:0x028f, B:67:0x02a0, B:69:0x02a7, B:71:0x02c8, B:73:0x02cf, B:74:0x02dd, B:76:0x02e4, B:78:0x02eb, B:79:0x02f3, B:81:0x02fb, B:83:0x0302, B:84:0x030a, B:86:0x0311, B:88:0x0325, B:89:0x0342, B:92:0x0363, B:94:0x036c, B:97:0x0374, B:99:0x037a, B:100:0x038b, B:102:0x0392, B:104:0x03b3, B:106:0x03ba, B:107:0x03c8, B:109:0x03cf, B:111:0x03d6, B:112:0x03de, B:114:0x03e6, B:116:0x03ed, B:117:0x0422, B:119:0x0429, B:120:0x0436, B:122:0x043e, B:126:0x039c, B:128:0x03a3, B:130:0x03b2, B:131:0x0357, B:135:0x03f8, B:137:0x03ff, B:139:0x0406, B:140:0x040b, B:142:0x0413, B:144:0x041a, B:146:0x02b1, B:148:0x02b8, B:150:0x02c7, B:151:0x0274, B:153:0x01fa, B:155:0x0201, B:157:0x0210, B:158:0x010a, B:160:0x013d, B:161:0x0146, B:163:0x0153, B:164:0x0449), top: B:15:0x0078, inners: #0, #1, #3 }] */
    /* JADX WARN: Removed duplicated region for block: B:43:0x01c7 A[Catch: all -> 0x0459, TryCatch #2 {all -> 0x0459, blocks: (B:16:0x0078, B:18:0x0084, B:20:0x0098, B:25:0x00a9, B:27:0x00c6, B:28:0x00cf, B:30:0x00e3, B:32:0x0101, B:33:0x015c, B:35:0x0191, B:36:0x01ab, B:38:0x01b9, B:41:0x01c1, B:43:0x01c7, B:44:0x01d8, B:46:0x01df, B:47:0x01e8, B:49:0x01f0, B:50:0x0211, B:52:0x0218, B:53:0x0226, B:55:0x0242, B:56:0x025f, B:59:0x0278, B:61:0x0281, B:64:0x0289, B:66:0x028f, B:67:0x02a0, B:69:0x02a7, B:71:0x02c8, B:73:0x02cf, B:74:0x02dd, B:76:0x02e4, B:78:0x02eb, B:79:0x02f3, B:81:0x02fb, B:83:0x0302, B:84:0x030a, B:86:0x0311, B:88:0x0325, B:89:0x0342, B:92:0x0363, B:94:0x036c, B:97:0x0374, B:99:0x037a, B:100:0x038b, B:102:0x0392, B:104:0x03b3, B:106:0x03ba, B:107:0x03c8, B:109:0x03cf, B:111:0x03d6, B:112:0x03de, B:114:0x03e6, B:116:0x03ed, B:117:0x0422, B:119:0x0429, B:120:0x0436, B:122:0x043e, B:126:0x039c, B:128:0x03a3, B:130:0x03b2, B:131:0x0357, B:135:0x03f8, B:137:0x03ff, B:139:0x0406, B:140:0x040b, B:142:0x0413, B:144:0x041a, B:146:0x02b1, B:148:0x02b8, B:150:0x02c7, B:151:0x0274, B:153:0x01fa, B:155:0x0201, B:157:0x0210, B:158:0x010a, B:160:0x013d, B:161:0x0146, B:163:0x0153, B:164:0x0449), top: B:15:0x0078, inners: #0, #1, #3 }] */
    /* JADX WARN: Removed duplicated region for block: B:44:0x01d8 A[Catch: all -> 0x01f9, all -> 0x0459, TRY_ENTER, TryCatch #1 {all -> 0x01f9, blocks: (B:38:0x01b9, B:44:0x01d8, B:46:0x01df, B:47:0x01e8, B:49:0x01f0), top: B:37:0x01b9, outer: #2 }] */
    /*
        Code decompiled incorrectly, please refer to instructions dump.
        To view partially-correct code enable 'Show inconsistent code' option in preferences
    */
    private void expCheck(com.jiuqi.syntax.SyntaxData r6) {
        /*
            Method dump skipped, instructions count: 1139
            To view this dump change 'Code comments level' option to 'DEBUG'
        */
        throw new UnsupportedOperationException("Method not decompiled: com.jiuqi.syntax.SyntaxParser.expCheck(com.jiuqi.syntax.SyntaxData):void");
    }

    public static void main1(String[] args) {
        System.out.println("Start Syntax Testing!");
        SyntaxParser parser = new SyntaxParser();
        CommonData resultData = new CommonData();
        parser.hasExpDescription = true;
        parser.hasExpVision = true;
        parser.hasMakeNiporlan = true;
        System.out.println("start:" + (System.currentTimeMillis() / 1000));
        int ret = parser.attract(" floatcopy        ( '11111' , '222 \"\" 222', '4444' , '5555' ,1, true)", resultData);
        System.out.println("end:" + (System.currentTimeMillis() / 1000));
        System.out.println("ret:" + ret);
        if (ret != 0) {
            System.out.println("error message:" + parser.getErrorMessage());
        }
        System.out.println("expstr:" + parser.getExpStr());
        System.out.println("IF expstr:" + parser.getExpStrIfPart());
        System.out.println("THEN expstr:" + parser.getExpStrThenPart());
        System.out.println("ELSE expstr:" + parser.getExpStrElsePart());
        System.out.println("expi:" + parser.expi);
        System.out.println("expDescription:" + parser.getExpDescription());
        System.out.println("expVision:" + parser.getExpVision());
        System.out.println("result.type:" + resultData.type);
        System.out.println("result value:" + resultData.toString());
        System.out.println("<niporlan start!>");
        System.out.print("niporlan if's count:");
        System.out.println(parser.niporlan.ifItems == null ? 0 : parser.niporlan.ifItems.size());
        System.out.println("niporlan then's count:" + parser.niporlan.thenItems.size());
        System.out.print("niporlan else's count:");
        System.out.println(parser.niporlan.elseItems == null ? 0 : parser.niporlan.elseItems.size());
        resultData.type = 0;
        resultData.cdString = "";
        parser.attract(parser.getNiporlan(), resultData);
        System.out.println("result.type:" + resultData.type);
        System.out.println("result value:" + resultData.toString());
        CommonTransJavaScriptListener listenter = new CommonTransJavaScriptListener();
        System.out.print("JavaScript:");
        System.out.println(parser.transNiporlanToJavaScript(parser.niporlan, false, listenter));
    }
}
